(
	function( $ ) {
		'use strict';

		var MakeaholicPopupPlugin = function( $el, options ) {
			this.ACTIVE_CLASS = 'open';

			this.init = function() {
				var plugin = this;

				$el.on( 'click', '.popup-overlay, .button-close-popup', function( e ) {
					e.preventDefault();
					e.stopPropagation();

					plugin.close();
				} );
			};

			this.open = function() {
				var plugin = this;

				$( '.makeaholic-popup' ).MakeaholicPopup( 'close' );

				$el.addClass( plugin.ACTIVE_CLASS );
			};

			this.close = function() {
				var plugin = this;

				$el.removeClass( plugin.ACTIVE_CLASS );
			};
		};

		$.fn.MakeaholicPopup = function( methodOrOptions ) {
			var method = (
				typeof methodOrOptions === 'string'
			) ? methodOrOptions : undefined;

			if ( method ) {
				var MakeaholicPopups = [];

				this.each( function() {
					var $el = $( this );
					var MakeaholicPopup = $el.data( 'MakeaholicPopup' );
					MakeaholicPopups.push( MakeaholicPopup );
				} );

				var args = (
					arguments.length > 1
				) ? Array.prototype.slice.call( arguments, 1 ) : undefined;

				var results = [];

				this.each( function( index ) {
					var MakeaholicPopup = MakeaholicPopups[ index ];

					if ( ! MakeaholicPopup ) {
						console.warn( '$.MakeaholicPopup not instantiated yet' );
						console.info( this );
						results.push( undefined );
						return;
					}

					if ( typeof MakeaholicPopup[ method ] === 'function' ) {
						var result = MakeaholicPopup[ method ].apply( MakeaholicPopup, args );
						results.push( result );
					} else {
						console.warn( 'Method \'' + method + '\' not defined in $.MakeaholicPopup' );
					}
				} );

				return (
					results.length > 1
				) ? results : results[ 0 ];
			} else {
				var options = (
					typeof methodOrOptions === 'object'
				) ? methodOrOptions : undefined;

				return this.each( function() {
					var $el = $( this );
					var MakeaholicPopup = new MakeaholicPopupPlugin( $el, options );

					$el.data( 'MakeaholicPopup', MakeaholicPopup );

					MakeaholicPopup.init();
				} );
			}
		};
	}( jQuery )
);
(
	function( $ ) {
		'use strict';

		$( document ).ready( function() {
			var messages = $makeaholicLogin.validatorMessages;

			jQuery.extend( jQuery.validator.messages, {
				required: messages.required,
				remote: messages.remote,
				email: messages.email,
				url: messages.url,
				date: messages.date,
				dateISO: messages.dateISO,
				number: messages.number,
				digits: messages.digits,
				creditcard: messages.creditcard,
				equalTo: messages.equalTo,
				accept: messages.accept,
				maxlength: jQuery.validator.format( messages.maxlength ),
				minlength: jQuery.validator.format( messages.minlength ),
				rangelength: jQuery.validator.format( messages.rangelength ),
				range: jQuery.validator.format( messages.range ),
				max: jQuery.validator.format( messages.max ),
				min: jQuery.validator.format( messages.min )
			} );

			var $body = $( 'body' );
			var $popupPreLoader = $( '#popup-pre-loader' );
			var $popupLogin = $( '#popup-user-login' );
			var $popupRegister = $( '#popup-user-register' );
			var $popupLostPassword = $( '#popup-user-lost-password' );


			$( '.makeaholic-popup' ).MakeaholicPopup();

			$body.on( 'click', '.open-popup-login', function( e ) {
				e.preventDefault();
				e.stopPropagation();

				handlerLogin();
			} );

			$body.on( 'click', '.open-popup-register', function( e ) {
				e.preventDefault();
				e.stopPropagation();

				handlerRegister();
			} );

			$body.on( 'click', '.open-popup-lost-password', function( e ) {
				e.preventDefault();
				e.stopPropagation();

				handlerLostPassword();
			} );

			$body.on( 'click', '.btn-pw-toggle', function( e ) {
				e.preventDefault();
				e.stopPropagation();

				var groupField = $( this ).parent( '.form-input-password' );
				var pwField = groupField.children( 'input' );

				if ( 'password' === pwField.attr( 'type' ) ) {
					pwField.attr( 'type', 'text' );
					groupField.addClass( 'show-pw' );
				} else {
					pwField.attr( 'type', 'password' );
					groupField.removeClass( 'show-pw' );
				}
			} );

			function handlerLogin() {
				if ( $popupLogin.hasClass( 'popup-loaded' ) ) {
					$popupLogin.MakeaholicPopup( 'open' );
				} else {
					$.ajax( {
						url: $makeaholic.ajaxurl,
						type: 'GET',
						cache: false,
						dataType: 'html',
						data: {
							action: 'makeaholic_lazy_load_template',
							template: $popupLogin.data( 'template' )
						},
						success: function( response ) {
							$popupLogin.find( '.popup-content-inner' ).html( response );
							$popupLogin.addClass( 'popup-loaded' );
							$popupLogin.MakeaholicPopup( 'open' );

							// Remove inline css.
							$popupLogin.find( '.mo-openid-app-icons .mo_btn-social' ).removeAttr( 'style' );
							$popupLogin.find( '.mo-openid-app-icons .mo_btn-social .mofa' ).removeAttr( 'style' );
							$popupLogin.find( '.mo-openid-app-icons .mo_btn-social svg' ).removeAttr( 'style' );

							var $loginForm = $popupLogin.find( '#makeaholic-login-form' );
							$loginForm.validate( {
								rules: {
									user_login: {
										required: true
									},
									password: {
										required: true,
									}
								},
								submitHandler: function( form ) {
									var $form = $( form );

									$.ajax( {
										url: $makeaholic.ajaxurl,
										type: 'POST',
										cache: false,
										dataType: 'json',
										data: $form.serialize(),
										success: function( response ) {
											if ( ! response.success ) {
												$form.find( '.form-response-messages' ).html( response.data.messages ).addClass( 'error' ).show();
											} else {
												$form.find( '.form-response-messages' ).html( response.data.messages ).addClass( 'success' ).show();

												if ( '' !== response.data.redirect_url ) {
													window.location.href = response.data.redirect_url;
												} else {
													location.reload();
												}
											}
										},
										beforeSend: function() {
											$form.find( '.form-response-messages' ).html( '' ).removeClass( 'error success' ).hide();
											$form.find( 'button[type="submit"]' ).addClass( 'updating-icon' );
										},
										complete: function() {
											$form.find( 'button[type="submit"]' ).removeClass( 'updating-icon' );
										}
									} );
								}
							} );
						},
						error: function( MLHttpRequest, textStatus, errorThrown ) {
							console.log( errorThrown );
						},
						beforeSend: function() {
							$( '.makeaholic-popup' ).MakeaholicPopup( 'close' );
							$popupPreLoader.addClass( 'open' );
						},
						complete: function() {
							$popupPreLoader.removeClass( 'open' );
						}
					} );
				}
			}

			function handlerRegister() {
				if ( $popupRegister.hasClass( 'popup-loaded' ) ) {
					$popupRegister.MakeaholicPopup( 'open' );
				} else {
					$.ajax( {
						url: $makeaholic.ajaxurl,
						type: 'GET',
						cache: false,
						dataType: 'html',
						data: {
							action: 'makeaholic_lazy_load_template',
							template: $popupRegister.data( 'template' )
						},
						success: function( response ) {
							$popupRegister.find( '.popup-content-inner' ).html( response );
							$popupRegister.addClass( 'popup-loaded' );
							$popupRegister.MakeaholicPopup( 'open' );

							var $registerForm = $popupRegister.find( '#makeaholic-register-form' );
							$registerForm.validate( {
								rules: {
									fullname: {
										required: true,
									},
									username: {
										required: true,
										minlength: 4,
									},
									email: {
										required: true,
										email: true
									},
									password: {
										required: true,
										minlength: 8,
										maxlength: 30
									},
								},
								submitHandler: function( form ) {
									var $form = $( form );

									$.ajax( {
										url: $makeaholic.ajaxurl,
										type: 'POST',
										cache: false,
										dataType: 'json',
										data: $form.serialize(),
										success: function( response ) {
											console.log( response );
											if ( ! response.success ) {
												$form.find( '.form-response-messages' ).html( response.data.messages ).addClass( 'error' ).show();
											} else {
												$form.find( '.form-response-messages' ).html( response.data.messages ).addClass( 'success' ).show();
												location.reload();
											}
										},
										beforeSend: function() {
											$form.find( '.form-response-messages' ).html( '' ).removeClass( 'error success' ).hide();
											$form.find( 'button[type="submit"]' ).addClass( 'updating-icon' );
										},
										complete: function() {
											$form.find( 'button[type="submit"]' ).removeClass( 'updating-icon' );
										}
									} );
								}
							} );
						},
						error: function( MLHttpRequest, textStatus, errorThrown ) {
							console.log( errorThrown );
						},
						beforeSend: function() {
							$( '.makeaholic-popup' ).MakeaholicPopup( 'close' );
							$popupPreLoader.addClass( 'open' );
						},
						complete: function() {
							$popupPreLoader.removeClass( 'open' );
						}
					} );
				}
			}

			function handlerLostPassword() {
				if ( $popupLostPassword.hasClass( 'popup-loaded' ) ) {
					$popupLostPassword.MakeaholicPopup( 'open' );
				} else {
					$.ajax( {
						url: $makeaholic.ajaxurl,
						type: 'GET',
						cache: false,
						dataType: 'html',
						data: {
							action: 'makeaholic_lazy_load_template',
							template: $popupLostPassword.data( 'template' )
						},
						success: function( response ) {
							$popupLostPassword.find( '.popup-content-inner' ).html( response );
							$popupLostPassword.addClass( 'popup-loaded' );
							$popupLostPassword.MakeaholicPopup( 'open' );

							var $lostPasswordForm = $popupLostPassword.find( '#makeaholic-lost-password-form' );
							$lostPasswordForm.submit( function( e ) {
								e.preventDefault();

								var $form = $( this );

								$.ajax( {
									type: 'post',
									url: $makeaholic.ajaxurl,
									dataType: 'json',
									data: $form.serialize(),
									success: function( response ) {
										if ( ! response.success ) {
											$form.find( '.form-response-messages' ).html( response.data.messages ).addClass( 'error' ).show();
										} else {
											$form.find( '.form-response-messages' ).html( response.data.messages ).addClass( 'success' ).show();
										}
									},
									beforeSend: function() {
										$form.find( '.form-response-messages' ).html( '' ).removeClass( 'error success' ).hide();
										$form.find( 'button[type="submit"]' ).addClass( 'updating-icon' );
									},
									complete: function() {
										$form.find( 'button[type="submit"]' ).removeClass( 'updating-icon' );
									}
								} );
							} );
						},
						error: function( MLHttpRequest, textStatus, errorThrown ) {
							console.log( errorThrown );
						},
						beforeSend: function() {
							$( '.makeaholic-popup' ).MakeaholicPopup( 'close' );
							$popupPreLoader.addClass( 'open' );
						},
						complete: function() {
							$popupPreLoader.removeClass( 'open' );
						}
					} );
				}
			}
		} );

	}( jQuery )
);
