/**
 * Functions for archive pages.
 */
(
	function( $ ) {
		'use strict';

		var $body = $( 'body' );

		$( document ).ready( function() {
			initArchiveStickyToolbars();
			initArchiveTopFilters();
			initArchiveLayoutSwitcher();
		} );

		function initArchiveStickyToolbars() {
			if ( '1' !== $makeaholicWoo.shopToolbarsSticky ) {
				return;
			}

			var $toolbars = $( '#archive-shop-actions' );

			if ( 0 >= $toolbars.length ) {
				return;
			}

			var offsetTop = $toolbars.offset().top;
			var $pageHeader = $( '#page-header-inner' );
			var $adminBar = $( '#wpadminbar' );

			offsetTop += 40; // Toolbar height;

			$( window ).on( 'scroll', function() {
				var top = 0;

				if ( $body.hasClass( 'header-pinned' ) ) {
					top += $pageHeader.outerHeight();
				}

				if ( $adminBar.length > 0 && window.innerWidth > 600 ) {
					top += $adminBar.outerHeight();
				}

				var st = $( this ).scrollTop();

				if ( st > offsetTop ) {
					$toolbars.addClass( 'sticky' );
					$toolbars.children( '.archive-shop-actions-inner' ).css( 'top', top + 'px' );
				} else {
					$toolbars.removeClass( 'sticky' );
					$toolbars.children( '.archive-shop-actions-inner' ).css( 'top', 0 );
				}
			} );
		}

		function initArchiveTopFilters() {
			var $filterBtn = $( '#btn-toggle-archive-top-filters' );
			var $filterWidgets = $( '#archive-top-filter-widgets' );

			if ( $filterBtn.length <= 0 || $filterWidgets.length <= 0 ) {
				return;
			}

			var $toolbarAction = $( '#archive-shop-actions' );
			var offsetTop = $toolbarAction.offset().top - 100;

			$filterWidgets.removeClass( 'filters-opened' ).stop().hide();
			$filterWidgets.find( '.widget' ).children().not( '.widget-title' ).wrap( '<div class="widget-content" />' );

			$filterWidgets.find( '.filter-swatch' ).removeClass( 'hint--bounce hint--top' );

			$filterBtn.on( 'click', function( e ) {
				e.preventDefault();

				if ( $( this ).hasClass( 'active' ) ) {
					$( this ).removeClass( 'active' );
					$filterWidgets.removeClass( 'filters-opened' ).stop().slideUp( 350, function() {
						$( 'html, body' ).animate( { scrollTop: offsetTop }, 300 );
					} );
				} else {
					$( this ).addClass( 'active' );
					$filterWidgets.addClass( 'filters-opened' ).stop().slideDown( 350, function() {
						$( 'html, body' ).animate( { scrollTop: offsetTop }, 300 );
					} );
				}

				setTimeout( function() {
					$filterWidgets.find( '.widget' ).children( '.widget-content' ).perfectScrollbar( { suppressScrollX: true } );
				}, 500 );
			} );
		}

		function initArchiveLayoutSwitcher() {
			var $layoutSwitcher = $( '#archive-layout-switcher' );

			$( 'input[type=radio]', $layoutSwitcher ).on( 'change', function() {
				$( this ).parent( '.switcher-item' ).siblings().removeClass( 'loading' );
				$( this ).parent().addClass( 'loading' );

				$( this ).closest( 'form' ).submit();
			} );

			$layoutSwitcher.on( 'submit', function( e ) {
				e.preventDefault();

				var data = $( this ).serialize();

				$.ajax( {
					url: $makeaholic.ajaxurl,
					type: 'POST',
					data: data,
					dataType: 'json',
					success: function( results ) {
						location.reload();
					},
					error: function( MLHttpRequest, textStatus, errorThrown ) {
						console.log( errorThrown );
					},
				} );

				return false;
			} );
		}

	}( jQuery )
);
