(
	function( $ ) {
		'use strict';

		var $body = $( 'body' );

		$( document ).ready( function() {
			initFlyCart();
		} );

		function initFlyCart() {
			var $miniCart = $( '#mini-cart' );
			var $popupFlyCart = $( '#popup-fly-cart' );

			$miniCart.on( 'click', function( evt ) {
				evt.preventDefault();

				$body.addClass( 'popup-fly-cart-opened' );

				/**
				 * Sometime ajax get fragments has canceled.
				 * So we try reloading cart content.
				 */
				if ( $popupFlyCart.find( '.widget_shopping_cart_content' ).children().length <= 0 ) {
					block_loading();
					cart_reload();
				}
			} );

			$( '#btn-close-fly-cart' ).on( 'click', function( evt ) {
				evt.preventDefault();

				$body.removeClass( 'popup-fly-cart-opened' );
			} );

			$popupFlyCart.on( 'click', function( e ) {
				if ( e.target !== this ) {
					return;
				}

				$body.removeClass( 'popup-fly-cart-opened' );
			} );

			$( document ).on( 'wc_fragments_loaded', function() {
				unblock_loading();
			} );

			$( document ).on( 'wc_fragments_refreshed', function() {
				unblock_loading();
			} );

			$popupFlyCart.on( 'submit', '.form-fly-cart-coupon', update_coupon );

			$popupFlyCart.on( 'click', '.fly-cart-remove-coupon', remove_coupon );

			var timeout;
			$popupFlyCart.on( 'change', '.qty', function() {
				var $qty = $( this );

				if ( timeout !== undefined ) {
					clearTimeout( timeout );
				}

				timeout = setTimeout( function() {
					var itemKey = $qty.attr( 'name' );
					var itemQty = $qty.val();

					update_quantity( itemKey, itemQty );
				}, 1000 );
			} );

			function update_quantity( cart_item_key, cart_item_qty ) {
				var data = {
					action: 'makeaholic_update_product_quantity',
					cart_item_key: cart_item_key,
					cart_item_qty: cart_item_qty,
					security: $makeaholic.nonce,
				};

				$.ajax( {
					url: $makeaholic.ajaxurl,
					type: 'POST',
					cache: false,
					dataType: 'json',
					data: data,
					success: function( response ) {
						cart_reload();

						$( document.body ).trigger( 'makeaholic_update_qty', [ cart_item_key, cart_item_qty ] );
					},
					beforeSend: function() {
						block_loading();
					},
					complete: function() {

					}
				} );
			}

			function update_coupon() {
				var coupon_code = $( this ).find( 'input[name="coupon_code"]' ).val();

				var data = {
					coupon_code: coupon_code,
					security: $makeaholicWoo.apply_coupon_nonce
				};

				$.ajax( {
					type: 'POST',
					url: woocommerce_params.wc_ajax_url.toString().replace( '%%endpoint%%', 'apply_coupon' ),
					data: data,
					dataType: 'html',
					success: function( response ) {
						$popupFlyCart.find( '.fly-cart-messages' ).html( response );
						$( document.body ).trigger( 'applied_coupon', [ coupon_code ] );
					},
					beforeSend: function() {
						block_loading();
					},
					complete: function() {
						cart_reload();
					}
				} );

				return false;
			}

			function remove_coupon( evt ) {
				evt.preventDefault();

				var coupon = $( evt.currentTarget ).attr( 'data-coupon' );

				var data = {
					security: $makeaholicWoo.remove_coupon_nonce,
					coupon: coupon
				};

				$.ajax( {
					type: 'POST',
					url: woocommerce_params.wc_ajax_url.toString().replace( '%%endpoint%%', 'remove_coupon' ),
					data: data,
					dataType: 'html',
					success: function( response ) {
						$popupFlyCart.find( '.fly-cart-messages' ).html( response );
						$( document.body ).trigger( 'removed_coupon', [ coupon ] );
					},
					beforeSend: function() {
						block_loading();
					},
					complete: function() {
						cart_reload();
					}
				} );
			}

			function cart_reload() {
				$( document.body ).trigger( 'wc_fragment_refresh' );
			}

			function block_loading() {
				$popupFlyCart.addClass( 'loading' );
			}

			function unblock_loading() {
				$popupFlyCart.removeClass( 'loading' );
			}
		}
	}( jQuery )
);
