<?php

namespace Makeaholic_Elementor;

defined( 'ABSPATH' ) || exit;

class Widget_Init {

	private static $_instance = null;

	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}

		return self::$_instance;
	}

	public function initialize() {
		add_action( 'elementor/elements/categories_registered', [ $this, 'add_elementor_widget_categories' ] );

		// Registered Widgets.
		add_action( 'elementor/widgets/register', [ $this, 'init_widgets' ] );

		add_action( 'elementor/frontend/after_register_scripts', [ $this, 'after_register_scripts' ] );
		add_action( 'elementor/frontend/after_register_styles', [ $this, 'after_register_styles' ] );

		add_action( 'elementor/editor/after_enqueue_scripts', [ $this, 'enqueue_editor_scripts' ] );

		add_action( 'wp_ajax_get_product_tabs', [ $this, 'get_product_tab_content' ] );
		add_action( 'wp_ajax_nopriv_get_product_tabs', [ $this, 'get_product_tab_content' ] );

		// Modify original widgets settings.
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/original/modify-base.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/original/section.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/original/column.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/original/accordion.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/original/animated-headline.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/original/counter.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/original/form.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/original/heading.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/original/icon-box.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/original/progress.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/original/countdown.php' );
	}

	public function get_product_tab_content() {
		$source = isset( $_POST['source'] ) ? $_POST['source'] : 'latest';
		$number = isset( $_POST['number'] ) ? $_POST['number'] : 10;
		$layout = isset( $_POST['layout'] ) ? $_POST['layout'] : 'grid';
		$style  = isset( $_POST['style'] ) ? $_POST['style'] : $layout . '-01';

		/**
		 * Important Note:
		 * Used wpdb instead WP_Query because WP_Query auto appended logged author id & their post IDs.
		 * This happening only on admin_ajax
		 */

		global $wpdb;

		$product_post_type = 'product';

		$sql_select   = "SELECT {$wpdb->posts}.* FROM {$wpdb->posts}";
		$sql_join     = '';
		$sql_group_by = '';
		$sql_orderby  = " ORDER BY {$wpdb->posts}.post_date DESC";
		$sql_where    = " WHERE {$wpdb->posts}.post_type = '{$product_post_type}' AND {$wpdb->posts}.post_status = 'publish' ";
		$sql_limit    = " LIMIT 0, {$number}";

		switch ( $source ) {
			case 'trending' :
				$sql_join     = " INNER JOIN {$wpdb->postmeta} ON ( {$wpdb->posts}.ID = {$wpdb->postmeta}.post_id )";
				$sql_where    .= " AND ( {$wpdb->postmeta}.meta_key = 'views')";
				$sql_orderby  = " ORDER BY {$wpdb->postmeta}.meta_value+0 DESC";
				$sql_group_by = " GROUP BY {$wpdb->posts}.ID";
				break;
			case 'on_sale' :
				$sql_join     = " INNER JOIN {$wpdb->postmeta} ON ( {$wpdb->posts}.ID = {$wpdb->postmeta}.post_id )";
				$sql_where    .= " AND ( {$wpdb->postmeta}.meta_key = '_sale_price')";
				$sql_orderby  = " ORDER BY {$wpdb->postmeta}.meta_value+0 DESC";
				$sql_group_by = " GROUP BY {$wpdb->posts}.ID";
				break;
			case 'best_selling':
				$sql_join     = " INNER JOIN {$wpdb->postmeta} ON ( {$wpdb->posts}.ID = {$wpdb->postmeta}.post_id )";
				$sql_where    .= " AND ( {$wpdb->postmeta}.meta_key = 'total_sales')";
				$sql_orderby  = " ORDER BY {$wpdb->postmeta}.meta_value+0 DESC";
				$sql_group_by = " GROUP BY {$wpdb->posts}.ID";
				break;
			case 'top_rated':
				$sql_join     = " INNER JOIN {$wpdb->postmeta} ON ( {$wpdb->posts}.ID = {$wpdb->postmeta}.post_id )";
				$sql_where    .= " AND ( {$wpdb->postmeta}.meta_key = '_wc_average_rating')";
				$sql_orderby  = " ORDER BY {$wpdb->postmeta}.meta_value+0 DESC";
				$sql_group_by = " GROUP BY {$wpdb->posts}.ID";
				break;
			case 'featured' :
				$tax_query     = new \WP_Tax_Query( [
					'relation' => 'AND',
					array(
						'taxonomy' => 'product_visibility',
						'field'    => 'slug',
						'terms'    => [ 'featured' ],
					),
				] );
				$tax_query_sql = $tax_query->get_sql( $wpdb->posts, 'ID' );

				$sql_join     = $tax_query_sql['join'];
				$sql_where    .= $tax_query_sql['where'];
				$sql_group_by = " GROUP BY {$wpdb->posts}.ID";
				break;
			case 'by_category' :
				$tax_query     = new \WP_Tax_Query( [
					'tax_query' => [
						'relation' => 'AND',
						array(
							'taxonomy' => 'product_cat',
							'terms'    => $_POST['term_id'],
						),
					],
				] );
				$tax_query_sql = $tax_query->get_sql( $wpdb->posts, 'ID' );

				$sql_join     = $tax_query_sql['join'];
				$sql_where    .= $tax_query_sql['where'];
				$sql_group_by = " GROUP BY {$wpdb->posts}.ID";
				break;
		}

		// WPML Compatible.
		if ( defined( 'ICL_LANGUAGE_CODE' ) ) {
			$sql_join  .= " LEFT JOIN {$wpdb->prefix}icl_translations AS wpml_translations ON ($wpdb->posts.ID = wpml_translations.element_id) AND wpml_translations.element_type = 'post_product'";
			$sql_where .= " AND wpml_translations.language_code = '" . ICL_LANGUAGE_CODE . "'";
		}

		$sql           = "{$sql_select} {$sql_join} {$sql_where} {$sql_group_by} {$sql_orderby} {$sql_limit}";
		$query_results = $wpdb->get_results( $sql, OBJECT );

		$success = false;

		if ( is_array( $query_results ) && count( $query_results ) ) :
			ob_start();

			global $post;

			foreach ( $query_results as $post ) :
				setup_postdata( $post );

				/**
				 * Hook: woocommerce_shop_loop.
				 *
				 * @hooked WC_Structured_Data::generate_product_data() - 10
				 */
				do_action( 'woocommerce_shop_loop' );

				wc_get_template_part( 'content-product', $style );
				?>
			<?php endforeach; ?>
			<?php
			wp_reset_postdata();

			$template = ob_get_clean();
			$template = preg_replace( '~>\s+<~', '><', $template );
			$success  = true;
		else :
			$template = esc_html__( 'Sorry, we can not find any products for this search.', 'makeaholic' );
			$success  = false;
		endif;

		$response = [
			'success'  => $success,
			'template' => $template,
		];

		echo json_encode( $response );

		wp_die();
	}

	/**
	 * Register scripts for widgets.
	 */
	public function after_register_scripts() {
		$min = \Makeaholic_Enqueue::instance()->get_min_suffix();

		// Fix Wordpress old version not registered this script.
		if ( ! wp_script_is( 'imagesloaded', 'registered' ) ) {
			wp_register_script( 'imagesloaded', MAKEAHOLIC_THEME_URI . '/assets/libs/imagesloaded/imagesloaded.min.js', array( 'jquery' ), null, true );
		}

		wp_register_script( 'circle-progress', MAKEAHOLIC_THEME_URI . '/assets/libs/circle-progress/circle-progress.min.js', array( 'jquery' ), null, true );
		wp_register_script( 'makeaholic-widget-circle-progress', MAKEAHOLIC_ELEMENTOR_URI . '/assets/js/widgets/widget-circle-progress.js', array(
			'jquery',
			'circle-progress',
		), null, true );

		wp_register_script( 'makeaholic-swiper-wrapper', MAKEAHOLIC_THEME_URI . "/assets/js/swiper-wrapper{$min}.js", array( 'swiper' ), MAKEAHOLIC_THEME_VERSION, true );
		wp_register_script( 'makeaholic-group-widget-carousel', MAKEAHOLIC_ELEMENTOR_URI . '/assets/js/widgets/group-widget-carousel.js', array(
			'jquery',
			'swiper',
			'makeaholic-swiper-wrapper',
		), null, true );
		$makeaholic_swiper_js = array(
			'prevText' => esc_html__( 'Prev', 'makeaholic' ),
			'nextText' => esc_html__( 'Next', 'makeaholic' ),
		);
		wp_localize_script( 'makeaholic-swiper-wrapper', '$makeaholicSwiper', $makeaholic_swiper_js );

		wp_register_script( 'isotope-masonry', MAKEAHOLIC_THEME_URI . "/assets/js/isotope.pkgd{$min}.js", array( 'jquery' ), MAKEAHOLIC_THEME_VERSION, true );
		wp_register_script( 'isotope-packery', MAKEAHOLIC_THEME_URI . '/assets/libs/packery-mode/packery-mode.pkgd.js', array( 'jquery' ), MAKEAHOLIC_THEME_VERSION, true );

		wp_register_script( 'makeaholic-grid-layout', MAKEAHOLIC_THEME_ASSETS_URI . "/js/grid-layout{$min}.js", array(
			'jquery',
			'imagesloaded',
			'matchheight',
			'isotope-masonry',
			'isotope-packery',
		), null, true );
		wp_register_script( 'makeaholic-grid-query', MAKEAHOLIC_ELEMENTOR_URI . '/assets/js/widgets/grid-query.js', array( 'jquery' ), null, true );

		wp_register_script( 'makeaholic-widget-grid-post', MAKEAHOLIC_ELEMENTOR_URI . '/assets/js/widgets/widget-grid-post.js', array( 'makeaholic-grid-layout' ), null, true );
		wp_register_script( 'makeaholic-group-widget-grid', MAKEAHOLIC_ELEMENTOR_URI . '/assets/js/widgets/group-widget-grid.js', array( 'makeaholic-grid-layout' ), null, true );

		wp_register_script( 'makeaholic-widget-google-map', MAKEAHOLIC_ELEMENTOR_URI . '/assets/js/widgets/widget-google-map.js', array( 'jquery' ), null, true );

		wp_register_script( 'vivus', MAKEAHOLIC_ELEMENTOR_URI . '/assets/libs/vivus/vivus.js', array( 'jquery' ), null, true );
		wp_register_script( 'makeaholic-widget-icon-box', MAKEAHOLIC_ELEMENTOR_URI . '/assets/js/widgets/widget-icon-box.js', array(
			'jquery',
			'vivus',
		), null, true );

		wp_register_script( 'makeaholic-widget-flip-box', MAKEAHOLIC_ELEMENTOR_URI . '/assets/js/widgets/widget-flip-box.js', array(
			'jquery',
			'imagesloaded',
		), null, true );

		wp_register_script( 'makeaholic-widget-accordion', MAKEAHOLIC_ELEMENTOR_URI . '/assets/js/widgets/widget-accordion.js', array(
			'jquery',
		), null, true );

		wp_register_script( 'makeaholic-widget-tabs', MAKEAHOLIC_ELEMENTOR_URI . '/assets/js/widgets/widget-tabs.js', array(
			'jquery',
		), null, true );

		wp_register_script( 'makeaholic-marquee-list', MAKEAHOLIC_ELEMENTOR_URI . '/assets/js/widgets/widget-marquee-list.js', array(
			'jquery',
		), null, true );

		wp_register_script( 'makeaholic-widget-gallery-justified-content', MAKEAHOLIC_ELEMENTOR_URI . '/assets/js/widgets/widget-gallery-justified-content.js', array(
			'justifiedGallery',
		), null, true );

		wp_register_script( 'countdown', MAKEAHOLIC_ELEMENTOR_URI . '/assets/libs/jquery.countdown/js/jquery.countdown.min.js', array( 'jquery' ), MAKEAHOLIC_THEME_VERSION, true );
		wp_register_script( 'makeaholic-product-carousel-countdown', MAKEAHOLIC_ELEMENTOR_URI . '/assets/js/widgets/widget-product-carousel-countdown.js', array(
			'jquery',
			'countdown',
			'swiper',
			'makeaholic-swiper-wrapper',
		), null, true );

		wp_register_script( 'makeaholic-widget-countdown', MAKEAHOLIC_ELEMENTOR_URI . '/assets/js/widgets/widget-countdown.js', array(
			'jquery',
			'countdown',
		), null, true );
	}

	/**
	 * enqueue scripts in editor mode.
	 */
	public function enqueue_editor_scripts() {
		wp_enqueue_script( 'makeaholic-elementor-editor', MAKEAHOLIC_ELEMENTOR_URI . '/assets/js/editor.js', array( 'jquery' ), null, true );
	}

	/**
	 * Register styles for widgets.
	 */
	public function after_register_styles() {

	}

	/**
	 * @param \Elementor\Elements_Manager $elements_manager
	 *
	 * Add category.
	 */
	function add_elementor_widget_categories( $elements_manager ) {
		$elements_manager->add_category( 'makeaholic', [
			'title' => esc_html__( 'By Makeaholic', 'makeaholic' ),
			'icon'  => 'fa fa-plug',
		] );
	}

	/**
	 * Init Widgets
	 *
	 * Include widgets files and register them
	 *
	 * @param \Elementor\Widgets_Manager $widget_manager
	 *
	 * @since  1.0.0
	 *
	 * @access public
	 * @throws \Exception
	 */
	public function init_widgets( $widget_manager ) {
		// Include Widget files.
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/base.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/form/form-base.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/posts/posts-base.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/carousel/carousel-base.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/carousel/posts-carousel-base.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/carousel/terms-carousel-base.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/carousel/static-carousel.php' );

		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/accordion.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/blockquote.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/button.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/button-scroll.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/button-popup-video.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/circle-progress-chart.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/google-map.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/heading.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/icon.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/icon-box.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/image-box.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/image-layers.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/image-gallery.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/gallery-justified-content.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/banner.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/shapes.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/flip-box.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/attribute-list.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/gradation.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/timeline.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/countdown.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/list.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/marquee-list.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/pricing-table.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/twitter.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/team-member.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/social-networks.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/popup-video.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/separator.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/table.php' );
		//makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/full-page.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/tabs.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/view-demo.php' );

		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/grid/grid-base.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/grid/static-grid.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/grid/client-logo.php' );

		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/posts/blog.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/posts/blog-category.php' );

		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/testimonial-grid.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/carousel/testimonial-carousel.php' );

		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/carousel/team-member-carousel.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/carousel/image-carousel.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/carousel/modern-carousel.php' );
		makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/carousel/modern-slider.php' );

		// Register Widgets.
		$widget_manager->register( new Widget_Accordion() );
		$widget_manager->register( new Widget_Blockquote() );
		$widget_manager->register( new Widget_Button() );
		$widget_manager->register( new Widget_Button_Scroll() );
		$widget_manager->register( new Widget_Button_Popup_Video() );
		$widget_manager->register( new Widget_Client_Logo() );
		$widget_manager->register( new Widget_Circle_Progress_Chart() );
		$widget_manager->register( new Widget_Google_Map() );
		$widget_manager->register( new Widget_Heading() );
		$widget_manager->register( new Widget_Icon() );
		$widget_manager->register( new Widget_Icon_Box() );
		$widget_manager->register( new Widget_Image_Box() );
		$widget_manager->register( new Widget_Image_Layers() );
		$widget_manager->register( new Widget_Image_Gallery() );
		$widget_manager->register( new Widget_Image_Carousel() );
		$widget_manager->register( new Widget_Gallery_Justified_Content() );
		$widget_manager->register( new Widget_Banner() );
		$widget_manager->register( new Widget_Shapes() );
		$widget_manager->register( new Widget_Modern_Carousel() );
		$widget_manager->register( new Widget_Modern_Slider() );
		$widget_manager->register( new Widget_Flip_Box() );
		$widget_manager->register( new Widget_Blog() );
		$widget_manager->register( new Widget_Blog_Category() );
		$widget_manager->register( new Widget_Attribute_List() );
		$widget_manager->register( new Widget_List() );
		$widget_manager->register( new Widget_Marquee_List() );
		$widget_manager->register( new Widget_Gradation() );
		$widget_manager->register( new Widget_Countdown() );
		$widget_manager->register( new Widget_Timeline() );
		$widget_manager->register( new Widget_Pricing_Table() );
		$widget_manager->register( new Widget_Twitter() );
		$widget_manager->register( new Widget_Team_Member() );
		$widget_manager->register( new Widget_Team_Member_Carousel() );
		$widget_manager->register( new Widget_Testimonial_Carousel() );
		$widget_manager->register( new Widget_Testimonial_Grid() );
		$widget_manager->register( new Widget_Social_Networks() );
		$widget_manager->register( new Widget_Popup_Video() );
		$widget_manager->register( new Widget_Separator() );
		$widget_manager->register( new Widget_Table() );
		//$widget_manager->register( new Widget_Full_Page() );
		$widget_manager->register( new Widget_View_Demo() );
		$widget_manager->register( new Widget_Tabs() );

		/**
		 * Include & Register Dependency Widgets.
		 */

		if ( \Makeaholic_Woo::instance()->is_activated() ) {
			makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/woocommerce/button-add-to-cart.php' );
			makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/woocommerce/product.php' );
			makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/woocommerce/product-grid-tabs.php' );
			makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/woocommerce/product-carousel-tabs.php' );
			makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/woocommerce/product-list.php' );
			makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/woocommerce/product-carousel.php' );
			makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/woocommerce/feature-product-carousel.php' );
			makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/woocommerce/product-carousel-countdown.php' );
			makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/woocommerce/feature-product.php' );
			makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/woocommerce/product-banner.php' );
			makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/woocommerce/product-categories-grid.php' );
			makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/woocommerce/product-categories-carousel.php' );
			makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/woocommerce/product-categories-list.php' );
			makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/woocommerce/product-category-banner.php' );
			makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/woocommerce/shop-reviews.php' );

			$widget_manager->register( new Widget_Button_Add_To_Cart() );
			$widget_manager->register( new Widget_Product() );
			$widget_manager->register( new Widget_Product_Tabs() );
			$widget_manager->register( new Widget_Carousel_Product_Tabs() );
			$widget_manager->register( new Widget_Product_List() );
			$widget_manager->register( new Widget_Product_Carousel() );
			$widget_manager->register( new Widget_Feature_Product_Carousel() );
			$widget_manager->register( new Widget_Product_Carousel_Countdown() );
			$widget_manager->register( new Widget_Product_Category_Carousel() );
			$widget_manager->register( new Widget_Feature_Product() );
			$widget_manager->register( new Widget_Product_Banner() );
			$widget_manager->register( new Widget_Product_Categories_Grid() );
			$widget_manager->register( new Widget_Product_Categories_List() );
			$widget_manager->register( new Widget_Product_Category_Banner() );
			$widget_manager->register( new Widget_Shop_Reviews() );

			if ( class_exists( 'woo_brands' ) ) {
				makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/woocommerce/product-brands.php' );
				$widget_manager->register( new Widget_Product_Brands() );
			}
		}

		if ( function_exists( 'mc4wp_get_forms' ) ) {
			makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/form/mailchimp-form.php' );

			$widget_manager->register( new Widget_Mailchimp_Form() );
		}

		if ( defined( 'WPCF7_VERSION' ) ) {
			makeaholic_require_file_once( MAKEAHOLIC_ELEMENTOR_DIR . '/widgets/form/contact-form-7.php' );

			$widget_manager->register( new Widget_Contact_Form_7() );
		}
	}
}

Widget_Init::instance()->initialize();
