<?php

namespace Makeaholic_Elementor;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Background;

defined( 'ABSPATH' ) || exit;

class Widget_Blockquote extends Base {

	public function get_name() {
		return 'tm-blockquote';
	}

	public function get_title() {
		return esc_html__( 'Blockquote', 'makeaholic' );
	}

	public function get_icon_part() {
		return 'eicon-blockquote';
	}

	public function get_keywords() {
		return [ 'blockquote', 'quote', 'paragraph', 'testimonial', 'text' ];
	}

	protected function register_controls() {
		$this->add_layout_section();

		$this->add_content_section();

		$this->add_box_style_section();
	}

	private function add_layout_section() {
		$this->start_controls_section( 'layout_section', [
			'label' => esc_html__( 'Layout', 'makeaholic' ),
		] );

		$this->add_control( 'style', [
			'label'   => esc_html__( 'Style', 'makeaholic' ),
			'type'    => Controls_Manager::SELECT,
			'options' => array(
				'style-01' => '01',
			),
			'default' => 'style-01',
		] );

		$this->end_controls_section();
	}

	private function add_content_section() {
		$this->start_controls_section( 'blockquote_section', [
			'label' => esc_html__( 'BlockQuote', 'makeaholic' ),
		] );

		$this->add_control( 'blockquote_content', [
			'label'       => esc_html__( 'Text', 'makeaholic' ),
			'type'        => Controls_Manager::TEXTAREA,
			'dynamic'     => [
				'active' => true,
			],
			'placeholder' => esc_html__( 'Enter your quote', 'makeaholic' ),
			'default'     => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.', 'makeaholic' ),
		] );

		$this->add_control( 'author_name', [
			'label'     => esc_html__( 'Author', 'makeaholic' ),
			'type'      => Controls_Manager::TEXT,
			'dynamic'   => [
				'active' => true,
			],
			'default'   => esc_html__( 'John Doe', 'makeaholic' ),
			'separator' => 'after',
		] );

		$this->add_control( 'author_position', [
			'label'     => esc_html__( 'Position', 'makeaholic' ),
			'type'      => Controls_Manager::TEXT,
			'dynamic'   => [
				'active' => true,
			],
			'default'   => esc_html__( 'Founder, CEO', 'makeaholic' ),
			'separator' => 'after',
		] );

		$this->end_controls_section();
	}

	private function add_box_style_section() {
		$this->start_controls_section( 'box_style_section', [
			'label' => esc_html__( 'Box', 'makeaholic' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_responsive_control( 'text_align', [
			'label'     => esc_html__( 'Alignment', 'makeaholic' ),
			'type'      => Controls_Manager::CHOOSE,
			'options'   => Widget_Utils::get_control_options_text_align_full(),
			'selectors' => [
				'{{WRAPPER}}' => 'text-align: {{VALUE}};',
			],
		] );

		$this->add_responsive_control( 'box_padding', [
			'label'      => esc_html__( 'Padding', 'makeaholic' ),
			'type'       => Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%', 'em' ],
			'selectors'  => [
				'{{WRAPPER}}' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		] );

		$this->add_responsive_control( 'box_max_width', [
			'label'      => esc_html__( 'Max Width', 'makeaholic' ),
			'type'       => Controls_Manager::SLIDER,
			'default'    => [
				'unit' => 'px',
			],
			'size_units' => [ 'px', '%' ],
			'range'      => [
				'%'  => [
					'min' => 1,
					'max' => 100,
				],
				'px' => [
					'min' => 1,
					'max' => 1600,
				],
			],
			'selectors'  => [
				'{{WRAPPER}}' => 'max-width: {{SIZE}}{{UNIT}};',
			],
		] );

		$this->add_group_control( Group_Control_Background::get_type(), [
			'name'     => 'box',
			'selector' => '{{WRAPPER}}',
		] );

		$this->add_group_control( Group_Control_Advanced_Border::get_type(), [
			'name'     => 'box_border',
			'selector' => '{{WRAPPER}}',
		] );

		$this->add_group_control( Group_Control_Box_Shadow::get_type(), [
			'name'     => 'box',
			'selector' => '{{WRAPPER}}',
		] );

		$this->add_control( 'blockquote_icon_style', [
			'label'     => esc_html__( 'Blockquote Icon', 'makeaholic' ),
			'type'      => Controls_Manager::HEADING,
			'separator' => 'before',
		] );

		$this->add_control( 'blockquote_icon_color', [
			'label'     => esc_html__( 'Color', 'makeaholic' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .blockquote-icon svg path' => 'fill: {{VALUE}};',
			],
		] );

		$this->add_control( 'blockquote_content_style', [
			'label'     => esc_html__( 'Blockquote Content', 'makeaholic' ),
			'type'      => Controls_Manager::HEADING,
			'separator' => 'before',
		] );

		$this->add_control( 'blockquote_content_color', [
			'label'     => esc_html__( 'Color', 'makeaholic' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .blockquote-content' => 'color: {{VALUE}};',
			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'blockquote_content_typography',
			'label'    => esc_html__( 'Typography', 'makeaholic' ),
			'selector' => '{{WRAPPER}} .blockquote-content',
		] );

		$this->add_responsive_control( 'blockquote_content_spacing_top', [
			'label'     => esc_html__( 'Spacing Top', 'makeaholic' ),
			'type'      => Controls_Manager::SLIDER,
			'range'     => [
				'px' => [
					'min' => 0,
					'max' => 500,
				],
			],
			'selectors' => [
				'{{WRAPPER}} .blockquote-content' => 'margin-top: {{SIZE}}{{UNIT}};',
			],
		] );

		$this->add_responsive_control( 'blockquote_content_spacing_bottom', [
			'label'     => esc_html__( 'Spacing Bottom', 'makeaholic' ),
			'type'      => Controls_Manager::SLIDER,
			'range'     => [
				'px' => [
					'min' => 0,
					'max' => 500,
				],
			],
			'selectors' => [
				'{{WRAPPER}} .blockquote-content' => 'margin-bottom: {{SIZE}}{{UNIT}};',
			],
		] );

		$this->add_control( 'author_name_heading', [
			'label'     => esc_html__( 'Author Name', 'makeaholic' ),
			'type'      => Controls_Manager::HEADING,
			'separator' => 'before',
		] );

		$this->add_control( 'author_name_color', [
			'label'     => esc_html__( 'Color', 'makeaholic' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .author-name' => 'color: {{VALUE}};',
			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'author_name_typography',
			'label'    => esc_html__( 'Typography', 'makeaholic' ),
			'selector' => '{{WRAPPER}} .author-name',
		] );

		$this->add_control( 'author_position_heading', [
			'label'     => esc_html__( 'Author Position', 'makeaholic' ),
			'type'      => Controls_Manager::HEADING,
			'separator' => 'before',
		] );

		$this->add_control( 'author_position_color', [
			'label'     => esc_html__( 'Color', 'makeaholic' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .author-position' => 'color: {{VALUE}};',
			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'author_position_typography',
			'label'    => esc_html__( 'Typography', 'makeaholic' ),
			'selector' => '{{WRAPPER}} .author-position',
		] );


		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings_for_display();

		$this->add_render_attribute( 'wrapper', 'class', 'tm-blockquote' );
		$this->add_render_attribute( 'wrapper', 'class', $settings['style'] );
		$this->add_render_attribute( 'blockquote_content', 'class', 'blockquote-content' );
		$this->add_render_attribute( 'author_name', 'class', 'author-name' );
		$this->add_render_attribute( 'author_position', 'class', 'author-position' );
		?>
		<blockquote <?php $this->print_attributes_string( 'wrapper' ); ?>>
			<div class="blockquote-icon">
				<svg width="42" height="31" viewBox="0 0 42 31" fill="none" xmlns="http://www.w3.org/2000/svg">
					<path
						d="M33.3 14.45C31.2 14.45 29.25 15.2 27.75 16.55C29.55 10.85 33.45 6.19999 39.45 1.1L38.7 0.349996C30.3 7.1 25.2 14.45 25.2 22.55C25.2 27.05 28.8 30.65 33.3 30.65C37.8 30.65 41.4 27.05 41.4 22.55C41.4 18.05 37.8 14.45 33.3 14.45ZM8.1 14.45C6 14.45 4.05 15.2 2.7 16.55C4.35 10.85 8.25 6.19999 14.25 1.1L13.5 0.349996C5.1 7.1 4.24683e-07 14.45 4.24683e-07 22.55C4.24683e-07 27.05 3.6 30.65 8.1 30.65C12.6 30.65 16.2 27.05 16.2 22.55C16.2 18.05 12.6 14.45 8.1 14.45Z"
						fill="#E8C8B3"/>
				</svg>
			</div>
			<p <?php $this->print_render_attribute_string( 'blockquote_content' ) ?>>
				<?php echo wp_kses( $settings['blockquote_content'], 'makeaholic-default' ); ?>
			</p>
			<?php if ( ! empty( $settings['author_name'] ) ) : ?>
				<div class="blockquote-footer">
					<cite <?php $this->print_render_attribute_string( 'author_name' ); ?>>
						<?php echo esc_html( $settings['author_name'] ); ?>
					</cite>
					<?php if ( ! empty( $settings['author_position'] ) ) : ?>
						<span <?php $this->print_render_attribute_string( 'author_position' ); ?>>
							<?php echo esc_html( $settings['author_position'] ); ?>
						</span>
					<?php endif ?>
				</div>
			<?php endif ?>
		</blockquote>
		<?php
	}

	protected function content_template() {
		// @formatter:off
		?>
		<blockquote class="tm-blockquote">
			<div class="blockquote-icon">
				<svg width="42" height="31" viewBox="0 0 42 31" fill="none" xmlns="http://www.w3.org/2000/svg">
					<path
						d="M33.3 14.45C31.2 14.45 29.25 15.2 27.75 16.55C29.55 10.85 33.45 6.19999 39.45 1.1L38.7 0.349996C30.3 7.1 25.2 14.45 25.2 22.55C25.2 27.05 28.8 30.65 33.3 30.65C37.8 30.65 41.4 27.05 41.4 22.55C41.4 18.05 37.8 14.45 33.3 14.45ZM8.1 14.45C6 14.45 4.05 15.2 2.7 16.55C4.35 10.85 8.25 6.19999 14.25 1.1L13.5 0.349996C5.1 7.1 4.24683e-07 14.45 4.24683e-07 22.55C4.24683e-07 27.05 3.6 30.65 8.1 30.65C12.6 30.65 16.2 27.05 16.2 22.55C16.2 18.05 12.6 14.45 8.1 14.45Z"
						fill="#E8C8B3"/>
				</svg>
			</div>
			<p class="blockquote-content" data-elementor-setting-key="blockquote_content">
				{{{ settings.blockquote_content }}}
			</p>
			<# if ( settings.author_name ) { #>
				<div class="blockquote-footer">
					<# if ( settings.author_name ) { #>
						<cite class="author-name" data-elementor-setting-key="author_name">{{{ settings.author_name }}}</cite>
						<# if ( settings.author_position ) { #>
							<span class="author-position" data-elementor-setting-key="author_position">{{{ settings.author_position }}}</span>
						<# } #>
					<# } #>
				</div>
			<# } #>
		</blockquote>
		<?php
		// @formatter:off
	}
}
