<?php

namespace Makeaholic_Elementor;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Utils;

defined( 'ABSPATH' ) || exit;

class Widget_Countdown extends Base {

	public function get_name() {
		return 'tm-countdown';
	}

	public function get_title() {
		return esc_html__( 'Countdown', 'makeaholic' );
	}

	public function get_icon_part() {
		return 'eicon-countdown';
	}

	public function get_keywords() {
		return [ 'countdown' ];
	}

	public function get_script_depends() {
		return [ 'makeaholic-widget-countdown' ];
	}

	protected function register_controls() {
		$this->add_countdown_settings_section();

		$this->add_countdown_styling_section();
	}

	private function add_countdown_settings_section() {
		$this->start_controls_section( 'countdown_section', [
			'label' => esc_html__( 'Countdown', 'makeaholic' ),
		] );

		$this->add_control( 'style', [
			'label'       => esc_html__( 'Style', 'makeaholic' ),
			'type'        => Controls_Manager::SELECT,
			'options'     => array(
				'01' => esc_html__( 'Style 01', 'makeaholic' ),
			),
			'default'     => '01',
			'render_type' => 'template',
		] );

		$this->add_control( 'countdown_type', [
			'label'   => esc_html__( 'Type', 'makeaholic' ),
			'type'    => Controls_Manager::SELECT,
			'options' => [
				'due_date' => esc_html__( 'Due Date', 'makeaholic' ),
				'daily'    => esc_html__( 'Daily', 'makeaholic' ),
			],
			'default' => 'due_date',
		] );

		$this->add_control( 'due_date', [
			'label'       => esc_html__( 'Due Date', 'makeaholic' ),
			'type'        => Controls_Manager::DATE_TIME,
			'default'     => gmdate( 'Y-m-d H:i', strtotime( '+1 month' ) + ( get_option( 'gmt_offset' ) * HOUR_IN_SECONDS ) ),
			/* translators: %s: Time zone. */
			'description' => sprintf( __( 'Date set according to your timezone: %s.', 'makeaholic' ), Utils::get_timezone_string() ),
			'condition'   => [
				'countdown_type' => 'due_date',
			],
		] );

		$this->add_control( 'hide_countdown_text', [
			'label'        => esc_html__( 'Hide Text', 'makeaholic' ),
			'type'         => Controls_Manager::SWITCHER,
			'prefix_class' => 'makeaholic-hide-countdown-text-',
		] );

		$this->add_control( 'countdown_days_text', [
			'label'       => esc_html__( 'Days Text', 'makeaholic' ),
			'description' => esc_html__( 'Leave blank to use default text', 'makeaholic' ),
			'type'        => Controls_Manager::TEXT,
		] );

		$this->add_control( 'countdown_hours_text', [
			'label'       => esc_html__( 'Hours Text', 'makeaholic' ),
			'description' => esc_html__( 'Leave blank to use default text', 'makeaholic' ),
			'type'        => Controls_Manager::TEXT,
		] );

		$this->add_control( 'countdown_minutes_text', [
			'label'       => esc_html__( 'Minutes Text', 'makeaholic' ),
			'description' => esc_html__( 'Leave blank to use default text', 'makeaholic' ),
			'type'        => Controls_Manager::TEXT,
		] );

		$this->add_control( 'countdown_seconds_text', [
			'label'       => esc_html__( 'Seconds Text', 'makeaholic' ),
			'description' => esc_html__( 'Leave blank to use default text', 'makeaholic' ),
			'type'        => Controls_Manager::TEXT,
		] );

		$this->end_controls_section();
	}

	private function add_countdown_styling_section() {
		$this->start_controls_section( 'countdown_style_section', [
			'label' => esc_html__( 'Countdown Styling', 'makeaholic' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_responsive_control( 'countdown_max_width', [
			'label'          => esc_html__( 'Width', 'makeaholic' ),
			'type'           => Controls_Manager::SLIDER,
			'default'        => [
				'unit' => 'px',
			],
			'tablet_default' => [
				'unit' => 'px',
			],
			'mobile_default' => [
				'unit' => 'px',
			],
			'size_units'     => [ 'px', '%' ],
			'range'          => [
				'%'  => [
					'min' => 1,
					'max' => 100,
				],
				'px' => [
					'min' => 1,
					'max' => 1600,
				],
			],
			'selectors'      => [
				'{{WRAPPER}} .countdown' => 'width: {{SIZE}}{{UNIT}};',
			],
		] );

		$this->add_responsive_control( 'countdown_alignment', [
			'label'                => esc_html__( 'Alignment', 'makeaholic' ),
			'label_block'          => false,
			'type'                 => Controls_Manager::CHOOSE,
			'options'              => Widget_Utils::get_control_options_horizontal_alignment(),
			'selectors_dictionary' => [
				'left'  => 'flex-start',
				'right' => 'flex-end',
			],
			'selectors'            => [
				'{{WRAPPER}} .countdown-wrap' => 'display: flex; justify-content: {{VALUE}}',
			],
		] );

		$this->add_control( 'countdown_number_hr', [
			'label'     => esc_html__( 'Number', 'makeaholic' ),
			'type'      => Controls_Manager::HEADING,
			'separator' => 'before',
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'countdown_number_typography',
			'label'    => esc_html__( 'Typography', 'makeaholic' ),
			'selector' => '{{WRAPPER}} .countdown .number',
		] );

		$this->add_control( 'countdown_number_color', [
			'label'     => esc_html__( 'Number', 'makeaholic' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .countdown .number' => 'color: {{VALUE}};',
			],
		] );

		$this->add_control( 'countdown_text_hr', [
			'label'     => esc_html__( 'Text', 'makeaholic' ),
			'type'      => Controls_Manager::HEADING,
			'separator' => 'before',
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'countdown_text_typography',
			'label'    => esc_html__( 'Text Typography', 'makeaholic' ),
			'selector' => '{{WRAPPER}} .countdown .text',
		] );

		$this->add_control( 'countdown_text_color', [
			'label'     => esc_html__( 'Text', 'makeaholic' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .countdown .text' => 'color: {{VALUE}};',
			],
		] );

		$this->add_responsive_control( 'countdown_text_top_spacing', [
			'label'     => esc_html__( 'Spacing', 'makeaholic' ),
			'type'      => Controls_Manager::SLIDER,
			'range'     => [
				'px' => [
					'min' => 0,
					'max' => 50,
				],
			],
			'selectors' => [
				'{{WRAPPER}} .countdown .text' => 'margin-top: {{SIZE}}{{UNIT}};',
			],
		] );

		$this->add_control( 'countdown_divider_hr', [
			'label'     => esc_html__( 'Text', 'makeaholic' ),
			'type'      => Controls_Manager::HEADING,
			'separator' => 'before',
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'countdown_divider_typography',
			'label'    => esc_html__( 'Divider Typography', 'makeaholic' ),
			'selector' => '{{WRAPPER}} .countdown .divider',
		] );

		$this->add_control( 'countdown_divider_color', [
			'label'     => esc_html__( 'Divider', 'makeaholic' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .countdown .divider' => 'color: {{VALUE}};',
			],
		] );

		$this->add_responsive_control( 'countdown_divider_width', [
			'label'          => esc_html__( 'Width', 'makeaholic' ),
			'type'           => Controls_Manager::SLIDER,
			'default'        => [
				'unit' => 'px',
			],
			'tablet_default' => [
				'unit' => 'px',
			],
			'mobile_default' => [
				'unit' => 'px',
			],
			'size_units'     => [ 'px', '%' ],
			'range'          => [
				'%'  => [
					'min' => 1,
					'max' => 100,
				],
				'px' => [
					'min' => 1,
					'max' => 100,
				],
			],
			'selectors'      => [
				'{{WRAPPER}} .countdown .divider' => 'width: {{SIZE}}{{UNIT}};',
			],
		] );

		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings_for_display();

		$days_text    = ! empty( $settings['countdown_days_text'] ) ? $settings['countdown_days_text'] : __( 'Days', 'makeaholic' );
		$hours_text   = ! empty( $settings['countdown_hours_text'] ) ? $settings['countdown_hours_text'] : __( 'Hours', 'makeaholic' );
		$minutes_text = ! empty( $settings['countdown_minutes_text'] ) ? $settings['countdown_minutes_text'] : __( 'Minutes', 'makeaholic' );
		$seconds_text = ! empty( $settings['countdown_seconds_text'] ) ? $settings['countdown_seconds_text'] : __( 'Seconds', 'makeaholic' );

		if ( defined( 'MAKEAHOLIC_DEMO_SITE' ) && true === MAKEAHOLIC_DEMO_SITE ) {
			$datetime = $this->get_sample_countdown_date();
		} else {
			switch ( $settings['countdown_type'] ) {
				case 'due_date':
					$due_date = $settings['due_date'];
					// Handle timezone ( we need to set GMT time )
					$gmt      = get_gmt_from_date( $due_date . ':00' );
					$datetime = date( 'm/d/Y H:i:s', strtotime( $gmt ) );
					break;
				case 'daily':
					$now      = strtotime( current_time( 'm/d/Y H:i:s' ) );
					$endOfDay = strtotime( "tomorrow", $now ) - 1;

					$datetime = date( 'm/d/Y H:i:s', $endOfDay );
					break;
			}
		}

		if ( ! $datetime ) {
			return;
		}

		$this->add_render_attribute( 'countdown', [
			'class'             => 'countdown',
			'data-date'         => $datetime,
			'data-days-text'    => $days_text,
			'data-hours-text'   => $hours_text,
			'data-minutes-text' => $minutes_text,
			'data-seconds-text' => $seconds_text,
		] );

		$this->add_render_attribute( 'countdown-wrap', [
			'class' => 'makeaholic-countdown makeaholic-box',
		] );
		?>
		<div <?php $this->print_render_attribute_string( 'countdown-wrap' ); ?>>
			<div class="countdown-wrap">
				<div <?php $this->print_render_attribute_string( 'countdown' ); ?>></div>
			</div>
		</div>
		<?php
	}

	private function get_sample_countdown_date() {
		$date = date( 'm/d/Y H:i:s', strtotime( '+1 month', strtotime( date( 'm/d/Y H:i:s' ) ) ) );

		return $date;
	}
}
