<?php

namespace Makeaholic_Elementor;

use Elementor\Controls_Manager;
use Elementor\Repeater;
use Elementor\Group_Control_Typography;

defined( 'ABSPATH' ) || exit;

class Widget_Marquee_List extends Carousel_Base {

	public function get_name() {
		return 'tm-marquee-list';
	}

	public function get_title() {
		return esc_html__( 'Marquee List', 'makeaholic' );
	}

	public function get_icon_part() {
		return 'eicon-bullet-list';
	}

	public function get_keywords() {
		return [ 'marquee', 'icon list', 'icon', 'list' ];
	}

	public function get_script_depends() {
		return [ 'makeaholic-group-widget-carousel' ];
	}

	protected function register_controls() {
		$this->add_list_section();

		$this->add_styling_section();

		$this->add_text_style_section();

		$this->add_icon_style_section();
	}

	private function add_list_section() {
		$this->start_controls_section( 'list_section', [
			'label' => esc_html__( 'Icon List', 'makeaholic' ),
		] );

		$this->add_responsive_control( 'swiper_items', [
			'label'          => esc_html__( 'Slides Per View', 'makeaholic' ),
			'type'           => Controls_Manager::HIDDEN,
			'default'        => 'auto',
			'tablet_default' => 'auto',
			'mobile_default' => 'auto',
		] );

		$this->add_responsive_control( 'swiper_gutter', [
			'label'   => esc_html__( 'Space Between', 'makeaholic' ),
			'type'    => Controls_Manager::NUMBER,
			'min'     => 0,
			'max'     => 200,
			'step'    => 1,
			'default' => 15,
		] );

		$this->add_control( 'swiper_speed', [
			'label'   => esc_html__( 'Duration', 'makeaholic' ),
			'type'    => Controls_Manager::NUMBER,
			'default' => 4000,
		] );

		$this->add_control( 'icon', [
			'label'       => esc_html__( 'Default Icon', 'makeaholic' ),
			'description' => esc_html__( 'Choose default icon for all items.', 'makeaholic' ),
			'type'        => Controls_Manager::ICONS,
		] );

		$this->add_control( 'icon_vertical_alignment', [
			'label'                => esc_html__( 'Icon Alignment', 'makeaholic' ),
			'type'                 => Controls_Manager::CHOOSE,
			'options'              => Widget_Utils::get_control_options_vertical_alignment(),
			'default'              => 'middle',
			'selectors_dictionary' => [
				'top'    => 'flex-start',
				'middle' => 'center',
				'bottom' => 'flex-end',
			],
			'selectors'            => [
				'{{WRAPPER}} .list-header' => 'align-items: {{VALUE}}',
			],
		] );

		$repeater = new Repeater();

		$repeater->add_control( 'text', [
			'label'       => esc_html__( 'Text', 'makeaholic' ),
			'type'        => Controls_Manager::TEXTAREA,
			'default'     => esc_html__( 'Text', 'makeaholic' ),
			'label_block' => true,
		] );

		$repeater->add_control( 'icon', [
			'label' => esc_html__( 'Icon', 'makeaholic' ),
			'type'  => Controls_Manager::ICONS,
		] );

		$repeater->add_control( 'link', [
			'label'       => esc_html__( 'Link', 'makeaholic' ),
			'type'        => Controls_Manager::URL,
			'dynamic'     => [
				'active' => true,
			],
			'placeholder' => esc_html__( 'https://your-link.com', 'makeaholic' ),
		] );

		$this->add_control( 'items', [
			'label'       => esc_html__( 'Items', 'makeaholic' ),
			'type'        => Controls_Manager::REPEATER,
			'fields'      => $repeater->get_controls(),
			'default'     => [
				[
					'text' => esc_html__( 'List Item #1', 'makeaholic' ),
				],
				[
					'text' => esc_html__( 'List Item #2', 'makeaholic' ),
				],
				[
					'text' => esc_html__( 'List Item #3', 'makeaholic' ),
				],
			],
			'title_field' => '{{{ elementor.helpers.renderIcon( this, icon, {}, "i", "panel" ) || \'<i class="{{ icon }}" aria-hidden="true"></i>\' }}} {{{ text }}}',
		] );

		$this->end_controls_section();
	}

	private function add_styling_section() {
		$this->start_controls_section( 'styling_section', [
			'label' => esc_html__( 'Styling', 'makeaholic' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'width', [
			'label'      => esc_html__( 'Width', 'makeaholic' ),
			'type'       => Controls_Manager::SLIDER,
			'size_units' => [ '%', 'px' ],
			'range'      => [
				'%'  => [
					'max'  => 100,
					'step' => 1,
				],
				'px' => [
					'max'  => 1000,
					'step' => 1,
				],
			],
			'selectors'  => [
				'{{WRAPPER}} .makeaholic-marquee-list' => 'width: {{SIZE}}{{UNIT}};',
			],
		] );

		$this->add_control(
			'separator_line',
			[
				'label'                => esc_html__( 'Separator Line', 'makeaholic' ),
				'type'                 => Controls_Manager::SWITCHER,
				'label_on'             => esc_html__( 'Show', 'makeaholic' ),
				'label_off'            => esc_html__( 'Hide', 'makeaholic' ),
				'default'              => 'yes',
				'selectors_dictionary' => [
					'yes' => 'block',
					''    => 'none',
				],
				'selectors'            => [
					'{{WRAPPER}} .makeaholic-marquee-list .item + .item:before' => 'display: {{VALUE}}',
				],
			]
		);

		$this->end_controls_section();
	}

	private function add_text_style_section() {
		$this->start_controls_section( 'text_style_section', [
			'label' => esc_html__( 'Text', 'makeaholic' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'text_typography',
			'label'    => esc_html__( 'Typography', 'makeaholic' ),
			'selector' => '{{WRAPPER}} .text',
		] );

		$this->start_controls_tabs( 'text_style_tabs' );

		$this->start_controls_tab( 'text_style_normal_tab', [
			'label' => esc_html__( 'Normal', 'makeaholic' ),
		] );

		$this->add_group_control( Group_Control_Text_Gradient::get_type(), [
			'name'     => 'text',
			'selector' => '{{WRAPPER}} .text',
		] );

		$this->end_controls_tab();

		$this->start_controls_tab( 'text_style_hover_tab', [
			'label' => esc_html__( 'Hover', 'makeaholic' ),
		] );

		$this->add_group_control( Group_Control_Text_Gradient::get_type(), [
			'name'     => 'hover_text',
			'selector' => '{{WRAPPER}} .link:hover .text',
		] );

		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->end_controls_section();
	}

	private function add_icon_style_section() {
		$this->start_controls_section( 'icon_style_section', [
			'label' => esc_html__( 'Icon', 'makeaholic' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_responsive_control( 'icon_space', [
			'label'     => esc_html__( 'Spacing', 'makeaholic' ),
			'type'      => Controls_Manager::SLIDER,
			'range'     => [
				'px' => [
					'min' => 0,
					'max' => 100,
				],
			],
			'selectors' => [
				'{{WRAPPER}} .icon' => 'margin-right: {{SIZE}}{{UNIT}};',
			],
		] );

		$this->add_responsive_control( 'icon_size', [
			'label'     => esc_html__( 'Size', 'makeaholic' ),
			'type'      => Controls_Manager::SLIDER,
			'range'     => [
				'px' => [
					'min' => 3,
					'max' => 20,
				],
			],
			'selectors' => [
				'{{WRAPPER}} .icon' => 'font-size: {{SIZE}}{{UNIT}};',
			],
		] );

		$this->add_responsive_control( 'min_width', [
			'label'          => esc_html__( 'Min Width', 'makeaholic' ),
			'type'           => Controls_Manager::SLIDER,
			'default'        => [
				'unit' => 'px',
			],
			'tablet_default' => [
				'unit' => 'px',
			],
			'mobile_default' => [
				'unit' => 'px',
			],
			'size_units'     => [ 'px', '%' ],
			'range'          => [
				'%'  => [
					'min' => 1,
					'max' => 100,
				],
				'px' => [
					'min' => 0,
					'max' => 100,
				],
			],
			'selectors'      => [
				'{{WRAPPER}} .icon' => 'min-width: {{SIZE}}{{UNIT}};',
			],
		] );

		$this->start_controls_tabs( 'icon_style_tabs' );

		$this->start_controls_tab( 'icon_style_normal_tab', [
			'label' => esc_html__( 'Normal', 'makeaholic' ),
		] );

		$this->add_group_control( Group_Control_Text_Gradient::get_type(), [
			'name'     => 'icon',
			'selector' => '{{WRAPPER}} .icon',
		] );

		$this->add_control( 'icon_marker_color', [
			'label'     => esc_html__( 'Icon Marker', 'makeaholic' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}}.makeaholic-list-style-icon-border .icon' => 'border-color: {{VALUE}};',
			],
			'condition' => [
				'style' => [
					'icon-border',
				],
			],
		] );

		$this->end_controls_tab();

		$this->start_controls_tab( 'icon_style_hover_tab', [
			'label' => esc_html__( 'Hover', 'makeaholic' ),
		] );

		$this->add_group_control( Group_Control_Text_Gradient::get_type(), [
			'name'     => 'hover_icon',
			'selector' => '{{WRAPPER}} .link:hover .icon',
		] );

		$this->add_control( 'hover_icon_marker_color', [
			'label'     => esc_html__( 'Icon Marker', 'makeaholic' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}}.makeaholic-list-style-icon-border .link:hover .icon' => 'border-color: {{VALUE}};',
			],
			'condition' => [
				'style' => [
					'icon-border',
				],
			],
		] );

		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->end_controls_section();
	}

	protected function update_slider_settings( $settings, $slider_settings ) {
		$slider_settings = [
			'class' => [ 'tm-swiper tm-slider-widget' ],
		];

		$items_settings  = $this->parse_slider_responsive_settings( $settings, 'swiper_items', 'items' );
		$gutter_settings = $this->parse_slider_responsive_settings( $settings, 'swiper_gutter', 'gutter' );

		$slider_settings += $items_settings + $gutter_settings;

		$slider_settings['data-nav']               = '0';
		$slider_settings['data-pagination']        = '0';
		$slider_settings['data-centered']          = '1';
		$slider_settings['data-loop']              = '1';
		$slider_settings['data-simulate-touch']    = '0';
		$slider_settings['data-allow-touch-move '] = '0';

		if ( ! empty( $settings['swiper_speed'] ) ) {
			$slider_settings['data-speed'] = $settings['swiper_speed'];
		}

		$slider_settings['data-autoplay'] = '1';

		return $slider_settings;
	}

	protected function render() {
		$settings = $this->get_settings_for_display();

		$classes = [
			'makeaholic-marquee-list',
			'yes' == $settings['separator_line'] ? 'makeaholic-marquee-list--enable-separator' : '',
		];

		$this->add_render_attribute( 'wrapper', 'class', $classes );

		?>
		<div <?php $this->print_attributes_string( 'wrapper' ); ?>>
			<?php $this->print_slider( $settings ); ?>
		</div>
		<?php
	}

	protected function print_slides( array $settings ) {
		$global_icon_html = '';
		if ( ! empty ( $settings['icon']['value'] ) ) {
			$global_icon_html = '<div class="makeaholic-icon icon">' . $this->get_render_icon( $settings, $settings['icon'], [ 'aria-hidden' => 'true' ], false, 'icon' ) . '</div>';
		}
		foreach ( $settings['items'] as $key => $item ) {
			$item_key = 'item_' . $item['_id'];
			$this->add_render_attribute( $item_key, 'class', 'item swiper-slide' );
			$link_tag      = 'div';
			$item_link_key = 'item_link_' . $item['_id'];
			$this->add_render_attribute( $item_link_key, 'class', 'link' );
			if ( ! empty( $item['link']['url'] ) ) {
				$link_tag = 'a';
				$this->add_link_attributes( $item_link_key, $item['link'] );
			}
			?>
			<div <?php $this->print_attributes_string( $item_key ); ?>>
				<?php printf( '<%1$s %2$s>', $link_tag, $this->get_render_attribute_string( $item_link_key ) ); ?>
				<div class="list-header">
					<?php if ( ! empty( $item['icon']['value'] ) ) { ?>
						<div class="makeaholic-icon icon">
							<?php $this->render_icon( $settings, $item['icon'], [ 'aria-hidden' => 'true' ], false, 'icon' ); ?>
						</div>
					<?php } else { ?>
						<?php echo '' . $global_icon_html; ?>
					<?php } ?>
					<div class="text-wrap">
						<?php if ( isset( $item['text'] ) ) { ?>
							<div class="text">
								<?php echo wp_kses_post( $item['text'] ); ?>
							</div>
						<?php } ?>
					</div>
				</div>
				<?php printf( '</%1$s>', $link_tag ); ?>
			</div>
			<?php
		}
	}
}
