<?php

namespace Makeaholic_Elementor;

use Elementor\Controls_Manager;
use Elementor\Repeater;
use Elementor\Group_Control_Typography;

defined( 'ABSPATH' ) || exit;

class Widget_Tabs extends Base {
	public function get_name() {
		return 'tm-tabs';
	}

	public function get_title() {
		return esc_html__( 'Tabs', 'makeaholic' );
	}

	public function get_icon_part() {
		return 'eicon-tabs';
	}

	public function get_keywords() {
		return [ 'modern', 'accordion', 'tabs', 'toggle' ];
	}

	public function get_script_depends() {
		return [ 'makeaholic-widget-tabs' ];
	}

	protected function register_controls() {
		$this->add_tabs_content_section();

		$this->add_tabs_style_section();

		$this->add_tab_content_style_section();
	}

	private function add_tabs_content_section() {
		$this->start_controls_section( 'tabs_section', [
			'label' => esc_html__( 'Tabs', 'makeaholic' ),
		] );

		$repeater = new Repeater();

		$repeater->add_control(
			'tab_title_heading',
			[
				'label' => __( 'Tab Title', 'makeaholic' ),
				'type'  => Controls_Manager::HEADING,
			]
		);

		$repeater->add_control( 'tab_title', [
			'label'       => esc_html__( 'Title', 'makeaholic' ),
			'type'        => Controls_Manager::TEXT,
			'default'     => esc_html__( 'Title', 'makeaholic' ),
			'label_block' => true,
			'dynamic'     => [
				'active' => true,
			],
		] );

		$repeater->add_control( 'tab_title_image', [
			'label'   => esc_html__( 'Image', 'makeaholic' ),
			'type'    => Controls_Manager::MEDIA,
			'default' => [],
		] );

		$repeater->add_control(
			'tab_content_heading',
			[
				'label'     => __( 'Tab Content', 'makeaholic' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$repeater->add_control( 'tab_content', [
			'label'      => esc_html__( 'Content', 'makeaholic' ),
			'type'       => Controls_Manager::WYSIWYG,
			'default'    => esc_html__( 'Tab Content', 'makeaholic' ),
			'show_label' => false,
		] );

		$this->add_control( 'tabs', [
			'label'       => esc_html__( 'Items', 'makeaholic' ),
			'type'        => Controls_Manager::REPEATER,
			'fields'      => $repeater->get_controls(),
			'default'     => [
				[
					'tab_title'   => esc_html__( 'Tab #1', 'makeaholic' ),
					'tab_content' => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper.', 'makeaholic' ),
				],
				[
					'tab_title'   => esc_html__( 'Tab #2', 'makeaholic' ),
					'tab_content' => esc_html__( 'Sed ut perspiciatis unde omnis iste natus error sit voluptatem accusantium doloremque.', 'makeaholic' ),
				],
				[
					'tab_title'   => esc_html__( 'Tab #3', 'makeaholic' ),
					'tab_content' => esc_html__( 'Nemo enim ipsam voluptatem quia voluptas sit aspernatur aut odit aut fugit, sed quia consequuntur.', 'makeaholic' ),
				],
			],
			'title_field' => '{{{ tab_title }}}',
		] );

		$this->add_control( 'view', [
			'label'   => esc_html__( 'View', 'makeaholic' ),
			'type'    => Controls_Manager::HIDDEN,
			'default' => 'traditional',
		] );

		$this->add_control( 'tabs_layout', [
			'label'     => __( 'Layout', 'makeaholic' ),
			'type'      => Controls_Manager::SELECT,
			'default'   => 'horizontal',
			'options'   => [
				'horizontal'         => esc_html__( 'Horizontal', 'makeaholic' ),
				'horizontal-reverse' => esc_html__( 'Horizontal Reverse', 'makeaholic' ),
			],
			'separator' => 'before',
		] );

		$this->end_controls_section();
	}

	private function add_tabs_style_section() {
		$this->start_controls_section( 'tabs_style_section', [
			'label' => esc_html__( 'Tabs', 'makeaholic' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'tab_title_horizontal_alignment', [
			'label'       => esc_html__( 'Alignment', 'makeaholic' ),
			'label_block' => false,
			'type'        => Controls_Manager::CHOOSE,
			'options'     => Widget_Utils::get_control_options_text_align(),
			'default'     => 'center',
			'toggle'      => false,
			'selectors'   => [
				'{{WRAPPER}} .makeaholic-tabs__header-wrap' => 'text-align: {{VALUE}}',
			],
		] );

		$this->add_responsive_control( 'tab_title_spacing',
			[
				'label'      => esc_html__( 'Spacing', 'makeaholic' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range'      => [
					'px' => [
						'min' => 0,
						'max' => 200,
					],
				],
				'default'    => [],
				'selectors'  => [
					'{{WRAPPER}} .makeaholic-tabs--horizontal .makeaholic-tabs__header-wrap'         => 'margin-bottom: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .makeaholic-tabs--horizontal-reverse .makeaholic-tabs__header-wrap' => 'margin-top: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control( 'item_gutter',
			[
				'label'      => esc_html__( 'Gutter', 'makeaholic' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range'      => [
					'px' => [
						'min' => 0,
						'max' => 200,
					],
				],
				'default'    => [],
				'selectors'  => [
					'{{WRAPPER}} .tab-title + .tab-title' => 'margin-left: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'tab_title_typography',
			'label'    => esc_html__( 'Typography', 'makeaholic' ),
			'selector' => '{{WRAPPER}} .makeaholic-tabs .tab-title__text',
		] );

		$this->start_controls_tabs( 'tab_title_style_tabs' );

		$this->start_controls_tab( 'tab_title_style_normal_tab', [
			'label' => esc_html__( 'Normal', 'makeaholic' ),
		] );
		$this->add_control( 'tab_title_color', [
			'label'     => esc_html__( 'Color', 'makeaholic' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .makeaholic-tabs .tab-title__text' => 'color: {{VALUE}};',
			],
		] );
		$this->end_controls_tab();

		$this->start_controls_tab( 'tab_title_style_hover_tab', [
			'label' => esc_html__( 'Hover', 'makeaholic' ),
		] );
		$this->add_control( 'tab_title_hover_color', [
			'label'     => esc_html__( 'Color', 'makeaholic' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .makeaholic-tabs .tab-title:hover .tab-title__text' => 'color: {{VALUE}};',
			],
		] );
		$this->end_controls_tab();

		$this->start_controls_tab( 'tab_title_style_active_tab', [
			'label' => esc_html__( 'Active', 'makeaholic' ),
		] );
		$this->add_control( 'tab_title_active_color', [
			'label'     => esc_html__( 'Color', 'makeaholic' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .makeaholic-tabs .tab-title.active .tab-title__text' => 'color: {{VALUE}};',
			],
		] );
		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->add_control(
			'image_style_heading',
			[
				'label'     => __( 'Image', 'makeaholic' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control( 'image_hover_type', [
			'label'   => esc_html__( 'Hover Type', 'makeaholic' ),
			'type'    => Controls_Manager::SELECT,
			'options' => [
				''          => esc_html__( 'None', 'makeaholic' ),
				'grayscale' => esc_html__( 'Grayscale to normal', 'makeaholic' ),
				'opacity'   => esc_html__( 'Opacity to normal', 'makeaholic' ),
				'faded'     => esc_html__( 'Normal to opacity', 'makeaholic' ),
			],
			'default' => '',
		] );

		$this->add_responsive_control( 'image_spacing',
			[
				'label'      => esc_html__( 'Spacing', 'makeaholic' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range'      => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default'    => [],
				'selectors'  => [
					'{{WRAPPER}} .tab-title__image' => 'margin-top : {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();
	}

	private function add_tab_content_style_section() {
		$this->start_controls_section( 'tab_content_style_section', [
			'label' => esc_html__( 'Content', 'makeaholic' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_responsive_control( 'tab_content_text_align', [
			'label'     => esc_html__( 'Text Align', 'makeaholic' ),
			'type'      => Controls_Manager::CHOOSE,
			'options'   => Widget_Utils::get_control_options_text_align(),
			'default'   => 'center',
			'selectors' => [
				'{{WRAPPER}} .tab-content' => 'text-align: {{VALUE}};',
			],
		] );

		$this->add_responsive_control( 'content_height',
			[
				'label'      => esc_html__( 'Height', 'makeaholic' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range'      => [
					'px' => [
						'min' => 0,
						'max' => 1000,
					],
				],
				'default'    => [],
				'selectors'  => [
					'{{WRAPPER}} .tab-content' => 'min-height: {{SIZE}}{{UNIT}};',
				],
				'condition'  => [
					'tabs_layout' => 'horizontal-reverse',
				],
			]
		);

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'tab_content_typography',
			'label'    => esc_html__( 'Typography', 'makeaholic' ),
			'selector' => '{{WRAPPER}} .makeaholic-tabs .tab-content',
		] );

		$this->add_control( 'tab_content_color', [
			'label'     => esc_html__( 'Color', 'makeaholic' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .makeaholic-tabs .tab-content' => 'color: {{VALUE}};',
			],
		] );

		$this->add_responsive_control(
			'tab_content_padding',
			[
				'label'      => esc_html__( 'Padding', 'makeaholic' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors'  => [
					'{{WRAPPER}} .makeaholic-tabs .tab-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings_for_display();

		// Do nothing if there is not any items.
		if ( empty( $settings['tabs'] ) || count( $settings['tabs'] ) <= 0 ) {
			return;
		}

		$wrapper_classes = [
			'makeaholic-tabs',
			'makeaholic-tabs--' . $settings['tabs_layout'],
		];

		if ( $settings['image_hover_type'] ) {
			$wrapper_classes[] = 'makeaholic-tabs--image-hover-' . $settings['image_hover_type'];
		}

		$this->add_render_attribute( 'wrapper', 'class', $wrapper_classes );
		$this->add_render_attribute( 'tabs_header_wrapper', 'class', 'makeaholic-tabs__header' );
		$this->add_render_attribute( 'tabs_content_wrapper', 'class', 'makeaholic-tabs__content' );
		?>
		<div <?php $this->print_attributes_string( 'wrapper' ); ?>>
			<div class="makeaholic-tabs__header-wrap">
				<div <?php $this->print_attributes_string( 'tabs_header_wrapper' ); ?>>
					<?php
					foreach ( $settings['tabs'] as $index => $item ) {
						$loop = $index + 1;

						$tab_title_setting_key = $this->get_repeater_setting_key( 'tab_title', 'tabs', $index );

						$this->add_render_attribute( $tab_title_setting_key, [
							'class'    => [ 'tab-title' ],
							'data-tab' => $loop,
						] );

						if ( empty( $item['tab_title'] ) ) {
							$this->add_render_attribute( $tab_title_setting_key, 'class', 'tab-title--no-text' );
						}

						if ( 1 === $loop ) {
							$this->add_render_attribute( $tab_title_setting_key, 'class', 'active' );
						}

						?>
						<div <?php $this->print_attributes_string( $tab_title_setting_key ); ?>>
							<?php if ( $item['tab_title'] ) : ?>
								<span class="tab-title__text"><?php echo esc_html( $item['tab_title'] ); ?></span>
							<?php endif; ?>

							<?php if ( ! empty( $item['tab_title_image'] ) && $item['tab_title_image']['url'] ) : ?>
								<span class="tab-title__image">
								<img src="<?php echo esc_url( $item['tab_title_image']['url'] ) ?>"
								     alt="<?php echo esc_html( $item['tab_title'] ); ?>">
							</span>
							<?php endif; ?>
						</div>
						<?php
					}
					?>
				</div>
			</div>

			<div <?php $this->print_attributes_string( 'tabs_content_wrapper' ); ?>>
				<?php
				foreach ( $settings['tabs'] as $index => $item ) {
					$loop = $index + 1;

					$tab_content_setting_key = $this->get_repeater_setting_key( 'tab_content', 'tabs', $index );

					$this->add_render_attribute( $tab_content_setting_key, [
						'class'    => [ 'tab-content' ],
						'data-tab' => $loop,
					] );

					if ( 1 === $loop ) {
						$this->add_render_attribute( $tab_content_setting_key, 'class', 'active' );
					}

					$this->add_inline_editing_attributes( $tab_content_setting_key, 'advanced' );
					?>
					<div <?php $this->print_attributes_string( $tab_content_setting_key ); ?>>
						<?php echo '' . $this->parse_text_editor( $item['tab_content'] ); ?>
					</div>
					<?php
				}
				?>
			</div>

		</div>
		<?php
	}

	/**
	 * Render tabs widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since  2.9.0
	 * @access protected
	 */
	protected function content_template() {
		// @formatter:off
		?>
		<#
		view.addRenderAttribute( 'wrapper', 'class', [
			'makeaholic-tabs',
			'makeaholic-tabs--' + settings.tabs_layout
		] );

		if ( settings.image_hover_type ) {
			view.addRenderAttribute( 'wrapper', 'class', 'makeaholic-tabs--image-hover-' + settings.image_hover_type );
		}

		#>
		<div {{{ view.getRenderAttributeString( 'wrapper' ) }}}>
			<div class="makeaholic-tabs__header-wrap">
				<div class="makeaholic-tabs__header">
				<#
				_.each( settings.tabs, function( item, index ) {
					var tabCount = index + 1,
						tabTitleKey = view.getRepeaterSettingKey( 'tab_title', 'tabs', index );

					view.addRenderAttribute( tabTitleKey, {
						'class': [ 'tab-title' ],
						'data-tab': tabCount
					} );

					if ( ! settings.tab_title ) {
						view.addRenderAttribute( tabTitleKey, 'class', 'tab-title--no-text' );
					}

					if ( 1 === tabCount ) {
						view.addRenderAttribute( tabTitleKey, 'class', 'active' );
					}
					#>
					<div {{{ view.getRenderAttributeString( tabTitleKey ) }}}>
						<span class="tab-title__text">{{{ item.tab_title }}}</span>
						<# if ( item.tab_title_image.url ) { #>
							<span class="tab-title__image">
								<img src="{{ item.tab_title_image.url }}">
							</span>
						<# } #>
					</div>
					<#
				} );
				#>
				</div>
			</div>
			<div class="makeaholic-tabs__content">
			<#
			_.each( settings.tabs, function( item, index ) {
				var tabCount = index + 1,
					tabContentKey = view.getRepeaterSettingKey( 'tab_content', 'tabs', index );

				view.addRenderAttribute( tabContentKey, {
					'class': [ 'tab-content' ],
					'data-tab': tabCount
				} );

				if ( 1 === tabCount ) {
					view.addRenderAttribute( tabContentKey, 'class', 'active' );
				}

				view.addInlineEditingAttributes( tabContentKey, 'advanced' );
				#>
				<div {{{ view.getRenderAttributeString( tabContentKey ) }}}>{{{ item.tab_content }}}</div>
				<#
			} );
			#>
			</div>
		</div>
		<?php
		// @formatter:off
	}
}
