<?php

namespace Makeaholic_Elementor;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Repeater;
use Elementor\Utils;

defined( 'ABSPATH' ) || exit;

class Widget_View_Demo extends Base {

	private $current_item = null;
	private $current_key = null;

	public function get_name() {
		return 'tm-view-demo';
	}

	public function get_title() {
		return esc_html__( 'View Demo', 'makeaholic' );
	}

	public function get_icon_part() {
		return 'eicon-gallery-grid';
	}

	public function get_keywords() {
		return [ 'demo' ];
	}

	public function get_script_depends() {
		return [ 'makeaholic-group-widget-grid' ];
	}

	protected function get_current_item() {
		return $this->current_item;
	}

	protected function get_current_key() {
		return $this->current_key;
	}

	protected function register_controls() {
		$this->add_layout_section();

		$this->add_content_style_section();

		$this->add_grid_section();
	}

	private function add_layout_section() {
		$this->start_controls_section( 'layout_section', [
			'label' => esc_html__( 'Layout', 'makeaholic' ),
		] );

		$this->add_control( 'layout', [
			'label'   => esc_html__( 'Layout', 'makeaholic' ),
			'type'    => Controls_Manager::SELECT,
			'options' => [
				'grid'    => esc_html__( 'Grid', 'makeaholic' ),
				'masonry' => esc_html__( 'Masonry', 'makeaholic' ),
			],
			'default' => 'grid',
		] );

		$this->add_responsive_control( 'zigzag_height', [
			'label'     => esc_html__( 'Zigzag Height', 'makeaholic' ),
			'type'      => Controls_Manager::NUMBER,
			'step'      => 1,
			'condition' => [
				'layout' => 'masonry',
			],
		] );

		$this->add_control( 'zigzag_reversed', [
			'label'     => esc_html__( 'Zigzag Reversed?', 'makeaholic' ),
			'type'      => Controls_Manager::SWITCHER,
			'condition' => [
				'layout' => 'masonry',
			],
		] );

		$this->add_control( 'hover_effect', [
			'label'        => esc_html__( 'Hover Effect', 'makeaholic' ),
			'type'         => Controls_Manager::SELECT,
			'options'      => [
				''                    => esc_html__( 'None', 'makeaholic' ),
				'zoom-in'             => esc_html__( 'Zoom In', 'makeaholic' ),
				'zoom-out'            => esc_html__( 'Zoom Out', 'makeaholic' ),
				'move-up'             => esc_html__( 'Move Up', 'makeaholic' ),
				'move-up-drop-shadow' => esc_html__( 'Move Up - Drop Shadow', 'makeaholic' ),
			],
			'default'      => '',
			'prefix_class' => 'makeaholic-animation-',
		] );

		$this->add_control( 'arrow_icon', [
			'label'     => esc_html__( 'Arrow Icon', 'makeaholic' ),
			'type'      => Controls_Manager::MEDIA,
			'default'   => [
				'url' => '',
			],
			'separator' => 'before',
		] );

		$repeater = new Repeater();

		$repeater->add_control( 'image', [
			'label'   => esc_html__( 'Image', 'makeaholic' ),
			'type'    => Controls_Manager::MEDIA,
			'default' => [
				'url' => Utils::get_placeholder_image_src(),
			],
		] );

		$repeater->add_control( 'text', [
			'label'   => esc_html__( 'Text', 'makeaholic' ),
			'type'    => Controls_Manager::TEXT,
			'dynamic' => [
				'active' => true,
			],
		] );

		$repeater->add_control( 'link', [
			'label'         => esc_html__( 'Link', 'makeaholic' ),
			'type'          => Controls_Manager::URL,
			'placeholder'   => esc_html__( 'https://your-link.com', 'makeaholic' ),
			'show_external' => true,
			'default'       => [
				'url'         => '',
				'is_external' => false,
				'nofollow'    => false,
			],
		] );

		$repeater->add_control( 'badge', [
			'label'   => esc_html__( 'Badge', 'makeaholic' ),
			'type'    => Controls_Manager::SELECT,
			'default' => '',
			'options' => [
				''       => esc_html__( 'None', 'makeaholic' ),
				'new'    => esc_html__( 'New', 'makeaholic' ),
				'coming' => esc_html__( 'Coming Soon', 'makeaholic' ),
			],
		] );

		$placeholder_image_src = Utils::get_placeholder_image_src();

		$this->add_control( 'items', [
			'label'       => esc_html__( 'Items', 'makeaholic' ),
			'type'        => Controls_Manager::REPEATER,
			'fields'      => $repeater->get_controls(),
			'default'     => [
				[
					'image' => [ 'url' => $placeholder_image_src ],
				],
				[
					'image' => [ 'url' => $placeholder_image_src ],
				],
			],
			'title_field' => '{{{ text }}}',
			'separator'   => 'after',
		] );

		$this->end_controls_section();
	}

	private function add_grid_section() {
		$this->start_controls_section( 'grid_options_section', [
			'label' => esc_html__( 'Grid Options', 'makeaholic' ),
		] );

		$this->add_responsive_control( 'grid_columns', [
			'label'              => esc_html__( 'Columns', 'makeaholic' ),
			'type'               => Controls_Manager::NUMBER,
			'min'                => 1,
			'max'                => 12,
			'step'               => 1,
			'default'            => 3,
			'tablet_default'     => 2,
			'mobile_default'     => 1,
			'frontend_available' => true,
		] );

		$this->add_responsive_control( 'grid_gutter', [
			'label'   => esc_html__( 'Gutter', 'makeaholic' ),
			'type'    => Controls_Manager::NUMBER,
			'min'     => 0,
			'max'     => 200,
			'step'    => 1,
			'default' => 30,
		] );

		$this->end_controls_section();
	}

	private function add_content_style_section() {
		$this->start_controls_section( 'content_style_section', [
			'label' => esc_html__( 'Content', 'makeaholic' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_responsive_control( 'text_align', [
			'label'     => esc_html__( 'Text Align', 'makeaholic' ),
			'type'      => Controls_Manager::CHOOSE,
			'options'   => Widget_Utils::get_control_options_text_align_full(),
			'selectors' => [
				'{{WRAPPER}} .makeaholic-box' => 'text-align: {{VALUE}};',
			],
		] );

		$this->add_control( 'title_heading', [
			'label'     => esc_html__( 'Title', 'makeaholic' ),
			'type'      => Controls_Manager::HEADING,
			'separator' => 'before',
		] );

		$this->add_control( 'title_color', [
			'label'     => esc_html__( 'Color', 'makeaholic' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .heading' => 'color: {{VALUE}};',
			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'title_typography',
			'label'    => esc_html__( 'Typography', 'makeaholic' ),
			'selector' => '{{WRAPPER}} .heading',
		] );

		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings_for_display();

		if ( empty( $settings['items'] ) ) {
			return;
		}

		$this->add_render_attribute( 'grid-wrapper', 'class', 'makeaholic-grid-wrapper tm-view-demo' );

		$this->add_render_attribute( 'content-wrapper', 'class', 'makeaholic-grid lazy-grid' );

		if ( 'metro' === $settings['layout'] ) {
			$this->add_render_attribute( 'grid-wrapper', 'class', 'makeaholic-grid-metro' );
		}

		$grid_options = $this->get_grid_options( $settings );

		$this->add_render_attribute( 'grid-wrapper', 'data-grid', wp_json_encode( $grid_options ) );
		?>
		<div <?php $this->print_attributes_string( 'grid-wrapper' ); ?>>
			<div <?php $this->print_attributes_string( 'content-wrapper' ); ?>>
				<div class="grid-sizer"></div>

				<?php foreach ( $settings['items'] as $item ) : ?>
					<?php
					$item_id  = $item['_id'];
					$item_key = 'item_' . $item_id;

					$this->current_item = $item;
					$this->current_key  = $item_key;
					?>
					<div class="grid-item">
						<?php $this->print_grid_item(); ?>
					</div>
				<?php endforeach; ?>
			</div>
		</div>
		<?php
	}

	protected function print_grid_item() {
		$settings = $this->get_settings_for_display();

		$item     = $this->get_current_item();
		$item_key = $this->get_current_key();

		$box_tag = 'div';
		$box_key = $item_key . '_box';

		$this->add_render_attribute( $box_key, 'class', 'makeaholic-box' );

		if ( ! empty( $item['link']['url'] ) ) {
			$box_tag = 'a';

			$this->add_render_attribute( $box_key, 'class', 'link-secret' );
			$this->add_link_attributes( $box_key, $item['link'] );
		}

		if ( empty( $item['image'] ) || empty( $item['image']['url'] ) ) {
			$this->add_render_attribute( $box_key, 'class', 'no-thumb' );
		}
		?>
		<?php printf( '<%1$s %2$s>', $box_tag, $this->get_render_attribute_string( $box_key ) ); ?>

		<div class="image-wrap">
			<div class="makeaholic-image image">
				<?php echo \Makeaholic_Image::get_elementor_attachment( [
					'settings' => $item,
				] ); ?>
			</div>
		</div>

		<?php if ( ! empty( $item['badge'] ) ) : ?>
			<?php if ( 'coming' === $item['badge'] ) { ?>
				<div class="badge coming">
					<img
						src="<?php echo esc_url( MAKEAHOLIC_THEME_IMAGE_URI . '/soon-badge.png' ); ?>"
						alt="<?php esc_attr_e( 'Coming Soon', 'makeaholic' ); ?>"/>
				</div>
			<?php } elseif ( 'new' === $item['badge'] ) { ?>
				<div class="badge new">
					<img
						src="<?php echo esc_url( MAKEAHOLIC_THEME_IMAGE_URI . '/new-badge.png' ); ?>"
						alt="<?php esc_attr_e( 'New', 'makeaholic' ); ?>"/>
				</div>
			<?php } ?>
		<?php endif; ?>

		<?php if ( ! empty( $item['text'] ) ): ?>
			<div class="info">
				<h3 class="heading">
					<?php

					$icon = '';
					if ( $settings['arrow_icon'] && ! empty( $settings['arrow_icon']['url'] ) ) {
						$icon = sprintf(
							'<img src="%s" alt="%s">',
							$settings['arrow_icon']['url'],
							$item['text']
						);
					}

					echo esc_html( $item['text'] ) . $icon;
					?>
				</h3>
			</div>
		<?php endif; ?>

		<?php printf( '</%1$s>', $box_tag ); ?>
		<?php
	}

	protected function get_grid_options( array $settings ) {
		$grid_options = [];

		$grid_options['type'] = isset( $settings['layout'] ) ? $settings['layout'] : 'grid';

		if ( isset( $settings['metro_image_ratio'], $settings['metro_image_ratio']['size'] ) ) {
			$grid_options['ratio'] = $settings['metro_image_ratio']['size'];
		}

		// Columns.
		if ( ! empty( $settings['grid_columns'] ) ) {
			$grid_options['columns'] = $settings['grid_columns'];
		}

		if ( ! empty( $settings['grid_columns_tablet'] ) ) {
			$grid_options['columnsTablet'] = $settings['grid_columns_tablet'];
		}

		if ( ! empty( $settings['grid_columns_mobile'] ) ) {
			$grid_options['columnsMobile'] = $settings['grid_columns_mobile'];
		}

		// Gutter
		if ( isset( $settings['grid_gutter'] ) && '' !== $settings['grid_gutter'] ) {
			$grid_options['gutter'] = $settings['grid_gutter'];
		}

		if ( isset( $settings['grid_gutter_tablet'] ) && '' !== $settings['grid_gutter_tablet'] ) {
			$grid_options['gutterTablet'] = $settings['grid_gutter_tablet'];
		}

		if ( isset( $settings['grid_gutter_mobile'] ) && '' !== $settings['grid_gutter_mobile'] ) {
			$grid_options['gutterMobile'] = $settings['grid_gutter_mobile'];
		}

		// Zigzag height.
		if ( isset( $settings['zigzag_height'] ) && '' !== $settings['zigzag_height'] ) {
			$grid_options['zigzagHeight'] = $settings['zigzag_height'];
		}

		if ( isset( $settings['zigzag_height_tablet'] ) && '' !== $settings['zigzag_height_tablet'] ) {
			$grid_options['zigzagHeightTablet'] = $settings['zigzag_height_tablet'];
		}

		if ( isset( $settings['zigzag_height_mobile'] ) && '' !== $settings['zigzag_height_mobile'] ) {
			$grid_options['zigzagHeightMobile'] = $settings['zigzag_height_mobile'];
		}

		if ( ! empty( $settings['zigzag_reversed'] ) && 'yes' === $settings['zigzag_reversed'] ) {
			$grid_options['zigzagReversed'] = 1;
		}

		return $grid_options;
	}
}
