<?php

namespace Makeaholic_Elementor;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Image_Size;

defined( 'ABSPATH' ) || exit;

class Widget_Feature_Product extends Base {

	public function get_name() {
		return 'tm-feature-product';
	}

	public function get_title() {
		return esc_html__( 'Feature Product', 'makeaholic' );
	}

	public function get_icon_part() {
		return 'eicon-image-rollover';
	}

	public function get_keywords() {
		return [ 'feature', 'product' ];
	}

	protected function register_controls() {
		$this->add_layout_section();

		$this->add_thumbnail_styling_section();

		$this->add_caption_styling_section();

		$this->add_button_styling_section();
	}

	private function add_layout_section() {
		$this->start_controls_section( 'layout_section', [
			'label' => esc_html__( 'Layout', 'makeaholic' ),
		] );

		$this->add_control( 'style', [
			'label'       => esc_html__( 'Style', 'makeaholic' ),
			'type'        => Controls_Manager::SELECT,
			'options'     => array(
				'01' => esc_html__( 'Style 01', 'makeaholic' ),
			),
			'default'     => '01',
			'render_type' => 'template',
		] );

		$this->add_control( 'hover_effect', [
			'label'        => esc_html__( 'Hover Effect', 'makeaholic' ),
			'type'         => Controls_Manager::SELECT,
			'options'      => [
				''         => esc_html__( 'None', 'makeaholic' ),
				'zoom-in'  => esc_html__( 'Zoom In', 'makeaholic' ),
				'zoom-out' => esc_html__( 'Zoom Out', 'makeaholic' ),
			],
			'default'      => '',
			'prefix_class' => 'makeaholic-animation-',
		] );

		$this->add_control( 'product_id', [
			'label'        => esc_html__( 'Choose Product', 'makeaholic' ),
			'type'         => Module_Query_Base::AUTOCOMPLETE_CONTROL_ID,
			'label_block'  => true,
			'multiple'     => false,
			'autocomplete' => [
				'object' => Module_Query_Base::QUERY_OBJECT_POST,
				'query'  => [
					'post_type' => 'product',
				],
			],
		] );

		$this->add_control( 'show_category', [
			'label'        => esc_html__( 'Show Category', 'makeaholic' ),
			'type'         => Controls_Manager::SWITCHER,
			'return_value' => '1',
		] );

		$this->add_control( 'show_rating', [
			'label'        => esc_html__( 'Show Rating', 'makeaholic' ),
			'type'         => Controls_Manager::SWITCHER,
			'return_value' => '1',
			'default'      => '1',
		] );

		$this->add_control( 'image', [
			'label' => esc_html__( 'Custom Thumbnail', 'makeaholic' ),
			'type'  => Controls_Manager::MEDIA,
		] );

		$this->add_group_control( Group_Control_Image_Size::get_type(), [
			'name'    => 'image_size',
			'default' => 'full',
		] );

		$this->add_control( 'button_text', [
			'label' => esc_html__( 'Button Text', 'makeaholic' ),
			'type'  => Controls_Manager::TEXT,
		] );

		$this->end_controls_section();
	}

	private function add_thumbnail_styling_section() {
		$this->start_controls_section( 'thumbnail_styling_section', [
			'label' => esc_html__( 'Thumbnail', 'makeaholic' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_responsive_control( 'thumbnail_width', [
			'label'      => esc_html__( 'Width', 'makeaholic' ),
			'type'       => Controls_Manager::SLIDER,
			'default'    => [
				'unit' => 'px',
			],
			'size_units' => [ 'px', '%' ],
			'range'      => [
				'%'  => [
					'min' => 1,
					'max' => 100,
				],
				'px' => [
					'min' => 1,
					'max' => 1600,
				],
			],
			'selectors'  => [
				'{{WRAPPER}} .feature-product-thumbnail-wrap' => 'width: {{SIZE}}{{UNIT}};',
			],
		] );

		$this->end_controls_section();
	}

	private function add_caption_styling_section() {
		$this->start_controls_section( 'caption_styling_section', [
			'label' => esc_html__( 'Caption', 'makeaholic' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'title_heading', [
			'label'     => esc_html__( 'Title', 'makeaholic' ),
			'type'      => Controls_Manager::HEADING,
			'separator' => 'before',
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'title_typography',
			'label'    => esc_html__( 'Typography', 'makeaholic' ),
			'selector' => '{{WRAPPER}} .product-title',
		] );

		$this->add_control( 'title_color', [
			'label'     => esc_html__( 'Color', 'makeaholic' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .product-title' => 'color: {{VALUE}};',
			],
		] );

		$this->add_control( 'category_heading', [
			'label'     => esc_html__( 'Category', 'makeaholic' ),
			'type'      => Controls_Manager::HEADING,
			'separator' => 'before',
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'category_typography',
			'label'    => esc_html__( 'Typography', 'makeaholic' ),
			'selector' => '{{WRAPPER}} .product-category',
		] );

		$this->add_control( 'category_color', [
			'label'     => esc_html__( 'Color', 'makeaholic' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .product-category' => 'color: {{VALUE}};',
			],
		] );

		$this->end_controls_section();
	}

	private function add_button_styling_section() {
		$this->start_controls_section( 'button_styling_section', [
			'label' => esc_html__( 'Button', 'makeaholic' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->start_controls_tabs( 'button_colors_tabs' );

		$this->start_controls_tab( 'button_colors_normal_tab', [
			'label' => esc_html__( 'Normal', 'makeaholic' ),
		] );

		$this->add_control( 'button_text_color', [
			'label'     => esc_html__( 'Color', 'makeaholic' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .cart-button' => 'color: {{VALUE}};',
			],
		] );

		$this->add_control( 'button_text_background_color', [
			'label'     => esc_html__( 'Background', 'makeaholic' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .cart-button' => 'background-color: {{VALUE}};',
			],
		] );

		$this->end_controls_tab();

		$this->start_controls_tab( 'button_colors_hover_tab', [
			'label' => esc_html__( 'Hover', 'makeaholic' ),
		] );

		$this->add_control( 'hover_button_text_color', [
			'label'     => esc_html__( 'Color', 'makeaholic' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .cart-button:hover' => 'color: {{VALUE}};',
			],
		] );

		$this->add_control( 'hover_button_text_background_color', [
			'label'     => esc_html__( 'Background', 'makeaholic' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .cart-button:hover' => 'background-color: {{VALUE}};',
			],
		] );

		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings_for_display();

		if ( empty( $settings['product_id'] ) ) {
			return;
		}

		/**
		 * @var \WC_Product $product
		 */
		$product = wc_get_product( $settings['product_id'] );

		if ( empty( $product ) ) {
			return;
		}
		?>
		<div class="makeaholic-feature-product makeaholic-box">
			<div class="feature-product-thumbnail-wrap">
				<a class="makeaholic-image" href="<?php echo esc_url( $product->get_permalink() ); ?>">
					<?php if ( $settings['image']['url'] ) : ?>
						<?php echo \Makeaholic_Image::get_elementor_attachment( [
							'settings'       => $settings,
							'image_size_key' => 'image_size',
							'size_settings'  => $settings,
						] ); ?>
					<?php else: ?>
						<?php
						$size = \Makeaholic_Image::elementor_parse_image_size( $settings, 'full', 'image_size' );
						echo \Makeaholic_Woo::instance()->get_product_image( $product, $size );
						?>
					<?php endif; ?>
				</a>
				<?php $this->print_product_sale_badge( $product ); ?>
			</div>

			<div class="feature-product--content">
				<div class="feature-product--info">
					<?php $this->print_product_category( $product ); ?>

					<h3 class="product-title">
						<a href="<?php echo esc_url( $product->get_permalink() ); ?>"
						   class="link-in-title"><?php echo esc_html( $product->get_name() ); ?></a>
					</h3>

					<?php $this->print_product_rating( $product ); ?>
				</div>

				<?php $this->print_product_add_to_cart_button( $product ); ?>
			</div>
		</div>
		<?php
	}

	protected function print_product_category( \WC_Product $product ) {
		$settings = $this->get_settings_for_display();

		if ( empty( $settings['show_category'] ) ) {
			return;
		}

		$cats = $product->get_category_ids();
		if ( empty( $cats ) ) {
			return;
		}

		$first_cat = $cats[0];
		$cat       = get_term_by( 'id', $first_cat, 'product_cat' );

		if ( ! $cat instanceof \WP_Term ) {
			return;
		}

		$link = get_term_link( $cat );
		?>
		<div class="product-category">
			<a href="<?php echo esc_url( $link ) ?>"><?php echo esc_html( $cat->name ); ?></a>
		</div>
		<?php
	}

	protected function print_product_rating( \WC_Product $product ) {
		$settings = $this->get_settings_for_display();

		if ( empty( $settings['show_rating'] ) ) {
			return;
		}

		if ( ! wc_review_ratings_enabled() ) {
			return;
		}

		$average_rating = $product->get_average_rating();

		if ( 0 >= $average_rating ) {
			return;
		}

		$review_count = $product->get_review_count();

		$rating_text = sprintf( esc_html( _n( '%s review', '%s reviews', $review_count, 'makeaholic' ) ), '<span class="count">' . esc_html( $review_count ) . '</span>' );
		?>
		<div class="product-rating">
			<?php \Makeaholic_Templates::render_rating( $average_rating ); ?>
			<div class="review-count"><?php echo '' . $rating_text; ?></div>
		</div>
		<?php
	}

	protected function print_product_add_to_cart_button( \WC_Product $product ) {
		$settings = $this->get_settings_for_display();

		$add_to_cart_text = ! empty( $settings['button_text'] ) ? $settings['button_text'] : $product->add_to_cart_text();

		$button_class = implode(
			' ',
			array_filter(
				array(
					'cart-button',
					'product_type_' . $product->get_type(),
					$product->is_purchasable() && $product->is_in_stock() ? 'add_to_cart_button' : '',
					$product->supports( 'ajax_add_to_cart' ) && $product->is_purchasable() && $product->is_in_stock() ? 'ajax_add_to_cart' : '',
				)
			)
		);

		echo sprintf(
			'<a rel="nofollow" href="%s" data-quantity="%s" data-product_id="%s" data-product_sku="%s" class="%s">%s%s</a>',
			esc_url( $product->add_to_cart_url() ),
			1,
			esc_attr( $product->get_id() ),
			esc_attr( $product->get_sku() ),
			$button_class,
			esc_html( $add_to_cart_text ),
			$product->get_price_html()
		);
	}

	protected function print_product_sale_badge( \WC_Product $product ) {
		if ( ! $product->is_on_sale() ) {
			return;
		}

		$saving_amount = \Makeaholic_Woo::instance()->get_product_price_saving_amount( $product );

		if ( 0 >= $saving_amount ) {
			return;
		}
		?>
		<div class="feature-product--sale-badge">
			<span class="label"><?php esc_html_e( 'Save', 'makeaholic' ); ?></span>
			<?php echo wc_price( $saving_amount ); ?>
		</div>
		<?php
	}
}
