<?php

namespace Makeaholic_Elementor;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Css_Filter;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Typography;
use Elementor\Repeater;

defined( 'ABSPATH' ) || exit;

class Widget_Carousel_Product_Tabs extends Carousel_Base {

	private $tab_key = '';

	public function __construct( $data = [], $args = null ) {
		parent::__construct( $data, $args );

		wp_register_script( 'makeaholic-widget-carousel-product-tabs', MAKEAHOLIC_ELEMENTOR_URI . '/assets/js/widgets/widget-product-tabs.js', array(
			'makeaholic-tab-panel',
			'elementor-frontend',
			'makeaholic-swiper-wrapper',
			'makeaholic-grid-query',
		), null, true );
	}

	public function get_name() {
		return 'tm-carousel-product-tabs';
	}

	public function get_title() {
		return esc_html__( 'Product Carousel Tabs', 'makeaholic' );
	}

	public function get_icon_part() {
		return 'eicon-product-tabs';
	}

	public function get_keywords() {
		return [ 'product', 'tabs', 'product tabs', 'product carousel tabs', 'product slider tabs' ];
	}

	public function get_script_depends() {
		return [
			'makeaholic-widget-carousel-product-tabs',
		];
	}

	public function get_tab_key() {
		return $this->tab_key;
	}

	protected function get_post_type() {
		return 'product';
	}

	protected function register_controls() {
		$this->add_layout_section();

		$this->add_product_tabs_section();

		$this->add_tabs_style_section();

		parent::register_controls();

		$this->update_controls();
	}

	private function add_layout_section() {
		$this->start_controls_section( 'layout_section', [
			'label' => esc_html__( 'Layout', 'makeaholic' ),
		] );

		$this->add_control( 'style', [
			'label'   => esc_html__( 'Style', 'makeaholic' ),
			'type'    => Controls_Manager::SELECT,
			'options' => [
				'carousel-01' => esc_html__( 'Style 01', 'makeaholic' ),
				'carousel-02' => esc_html__( 'Style 02', 'makeaholic' ),
				'carousel-03' => esc_html__( 'Style 03', 'makeaholic' ),
			],
			'default' => 'carousel-01',
		] );

		$this->add_control( 'hover_effect', [
			'label'        => esc_html__( 'Hover Effect', 'makeaholic' ),
			'type'         => Controls_Manager::SELECT,
			'options'      => [
				''         => esc_html__( 'None', 'makeaholic' ),
				'zoom-in'  => esc_html__( 'Zoom In', 'makeaholic' ),
				'zoom-out' => esc_html__( 'Zoom Out', 'makeaholic' ),
			],
			'default'      => '',
			'prefix_class' => 'makeaholic-animation-',
		] );

		$this->add_control( 'thumbnail_default_size', [
			'label'        => esc_html__( 'Use Default Thumbnail Size', 'makeaholic' ),
			'type'         => Controls_Manager::SWITCHER,
			'default'      => '1',
			'return_value' => '1',
			'separator'    => 'before',
		] );

		$this->add_group_control( Group_Control_Image_Size::get_type(), [
			'name'      => 'thumbnail',
			'default'   => 'full',
			'condition' => [
				'thumbnail_default_size!' => '1',
			],
		] );

		$this->add_control( 'title_collapse', [
			'label'        => esc_html__( 'Title Collapse', 'makeaholic' ),
			'type'         => Controls_Manager::SWITCHER,
			'default'      => 'yes',
			'return_value' => 'yes',
			'separator'    => 'before',
			'prefix_class' => 'product-title-collapse-',
		] );

		$this->add_control( 'tabs_style', [
			'label'        => esc_html__( 'Tabs Style', 'makeaholic' ),
			'type'         => Controls_Manager::SELECT,
			'options'      => [
				'01' => '01',
				'02' => '02',
			],
			'default'      => '01',
			'prefix_class' => 'product-tabs-style-',
		] );

		$this->end_controls_section();
	}

	protected function add_product_tabs_section() {
		$this->start_controls_section( 'product_tabs_section', [
			'label' => esc_html__( 'Product Tabs', 'makeaholic' ),
		] );

		$this->add_control( 'number_posts', [
			'label'       => esc_html__( 'Number posts', 'makeaholic' ),
			'description' => esc_html__( 'Select number of products display on each of tab.', 'makeaholic' ),
			'type'        => Controls_Manager::NUMBER,
			'min'         => 1,
			'max'         => 30,
			'step'        => 1,
			'default'     => 8,
		] );

		$source_options = [
			'latest'       => esc_html__( 'All Products (Latest)', 'makeaholic' ),
			'trending'     => esc_html__( 'Trending Products', 'makeaholic' ),
			'on_sale'      => esc_html__( 'OnSale Products', 'makeaholic' ),
			'top_rated'    => esc_html__( 'Top Rated Products', 'makeaholic' ),
			'best_selling' => esc_html__( 'Best Selling Products', 'makeaholic' ),
			'featured'     => esc_html__( 'Featured Products', 'makeaholic' ),
			'by_category'  => esc_html__( 'By Category', 'makeaholic' ),
		];

		$categories = get_terms( [
			'taxonomy'   => $this->get_post_category(),
			'parent'     => 0,
			'hide_empty' => 0,
		] );

		$category_options = [];

		foreach ( $categories as $category ) {
			$category_options[ $category->term_id ] = $category->name;
		}

		$repeater = new Repeater();

		$repeater->add_control( 'title', [
			'label'       => esc_html__( 'Tab Title', 'makeaholic' ),
			'type'        => Controls_Manager::TEXT,
			'description' => esc_html__( 'Leave blank to use default.', 'makeaholic' ),
		] );

		$repeater->add_control( 'query_source', [
			'label'   => esc_html__( 'Source', 'makeaholic' ),
			'type'    => Controls_Manager::SELECT,
			'options' => $source_options,
			'default' => 'latest',
		] );

		$repeater->add_control( 'category', [
			'label'     => esc_html__( 'Category', 'makeaholic' ),
			'type'      => Controls_Manager::SELECT,
			'options'   => $category_options,
			'condition' => [
				'query_source' => 'by_category',
			],
		] );

		$this->add_control( 'tabs', [
			'label'       => esc_html__( 'Product Tabs', 'makeaholic' ),
			'type'        => Controls_Manager::REPEATER,
			'fields'      => $repeater->get_controls(),
			'title_field' => "{{{ title || MakeaholicElementor.helpers.getRepeaterSelectOptionText('tm-carousel-product-tabs', 'tabs', 'query_source', query_source) }}}",
			'default'     => [
				[
					'title'        => '',
					'query_source' => 'latest',
				],
			],
		] );

		$this->end_controls_section();
	}

	protected function get_post_category() {
		return 'product_cat';
	}

	private function add_tabs_style_section() {
		$this->start_controls_section( 'product_tabs_style_section', [
			'label' => esc_html__( 'Tabs Style', 'makeaholic' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_responsive_control( 'nav_tab_text_align', [
			'label'                => esc_html__( 'Alignment', 'makeaholic' ),
			'type'                 => Controls_Manager::CHOOSE,
			'options'              => Widget_Utils::get_control_options_text_align(),
			'selectors_dictionary' => [
				'left'  => 'start',
				'right' => 'end',
			],
			'default'              => '',
			'selectors'            => [
				'{{WRAPPER}} .makeaholic-nav-tabs' => 'text-align: {{VALUE}};',
			],
		] );

		$this->add_responsive_control( 'nav_tab_item_padding', [
			'label'      => esc_html__( 'Item Padding', 'makeaholic' ),
			'type'       => Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%', 'em' ],
			'selectors'  => [
				'{{WRAPPER}} .makeaholic-tabpanel > .makeaholic-nav-tabs li a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'nav_tab_item_typography',
			'label'    => esc_html__( 'Item Typography', 'makeaholic' ),
			'selector' => '{{WRAPPER}} .makeaholic-tabpanel > .makeaholic-nav-tabs li .nav-tab-title',
		] );

		$this->start_controls_tabs( 'nav_colors_tabs' );

		$this->start_controls_tab( 'nav_colors_normal', [
			'label' => esc_html__( 'Normal', 'makeaholic' ),
		] );

		$this->add_group_control( Group_Control_Text_Gradient::get_type(), [
			'name'     => 'nav_title',
			'selector' => '{{WRAPPER}} .makeaholic-tabpanel > .makeaholic-nav-tabs > li > a',
		] );

		$this->add_group_control( Group_Control_Background::get_type(), [
			'name'     => 'nav_background',
			'selector' => '{{WRAPPER}} .makeaholic-tabpanel > .makeaholic-nav-tabs > li > a',
		] );

		$this->end_controls_tab();

		$this->start_controls_tab( 'nav_colors_hover', [
			'label' => esc_html__( 'Hover', 'makeaholic' ),
		] );

		$this->add_group_control( Group_Control_Text_Gradient::get_type(), [
			'name'     => 'hover_nav_title',
			'selector' => '{{WRAPPER}} .makeaholic-tabpanel > .makeaholic-nav-tabs li a:hover',
		] );

		$this->add_group_control( Group_Control_Background::get_type(), [
			'name'     => 'hover_nav_background',
			'selector' => '{{WRAPPER}} .makeaholic-tabpanel > .makeaholic-nav-tabs li a:hover',
		] );

		$this->end_controls_tab();

		$this->start_controls_tab( 'nav_colors_active', [
			'label' => esc_html__( 'Active', 'makeaholic' ),
		] );

		$this->add_group_control( Group_Control_Text_Gradient::get_type(), [
			'name'     => 'active_nav_title',
			'selector' => '{{WRAPPER}} .makeaholic-tabpanel > .makeaholic-nav-tabs li.active a',
		] );

		$this->add_group_control( Group_Control_Background::get_type(), [
			'name'     => 'active_nav_background',
			'selector' => '{{WRAPPER}} .makeaholic-tabpanel > .makeaholic-nav-tabs li.active a',
		] );

		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->end_controls_section();
	}

	private function update_controls() {
		$this->update_responsive_control( 'swiper_items', [
			'default'        => '4',
			'tablet_default' => '2',
			'mobile_default' => '1',
		] );

		$this->update_responsive_control( 'swiper_gutter', [
			'default' => 30,
		] );
	}

	protected function render() {
		$settings = $this->get_settings_for_display();

		if ( empty( $settings['tabs'] ) ) {
			return;
		}

		$layout       = 'carousel';
		$product_tabs = $settings['tabs'];
		$number_posts = $settings['number_posts'];
		$style        = ! empty( $settings['style'] ) ? $settings['style'] : 'carousel-01';
		$tabs_key     = 'product_tabs';

		$this->add_render_attribute( $tabs_key, 'class', 'makeaholic-tabpanel makeaholic-tabpanel-horizontal product-tabs-style-' . $settings['tabs_style'] );
		?>
		<div <?php $this->print_render_attribute_string( $tabs_key ); ?>>
			<ul class="makeaholic-nav-tabs" role="tablist">
				<?php $loop_count = 0; ?>
				<?php foreach ( $product_tabs as $key => $product_tab ) : ?>
					<?php
					$tab_key       = "nav_tab_{$key}_";
					$this->tab_key = $tab_key;
					$loop_count++;

					$this->add_render_attribute( $tab_key, 'role', 'tab' );

					if ( 1 === $loop_count ) {
						$this->add_render_attribute( $tab_key, 'class', 'active' );
					}
					?>
					<li <?php $this->print_render_attribute_string( $tab_key ); ?>>
						<a href="javascript:void(0);">
							<span
								class="nav-tab-title secondary-font"><?php echo '' . $this->get_tab_title( $product_tab ); ?></span>
						</a>
					</li>
				<?php endforeach; ?>
			</ul>
			<div class="makeaholic-tab-content">
				<?php $loop_count = 0; ?>
				<?php foreach ( $product_tabs as $key => $product_tab ) : ?>
					<?php
					$tab_key       = "content_tab_{$key}_";
					$this->tab_key = $tab_key;
					$source        = $product_tab['query_source'];
					$loop_count++;
					$this->set_slider_key( 'slider_' . $key );

					$query = [
						'source' => $source,
						'number' => $number_posts,
						'layout' => $layout,
						'style'  => $style,
					];

					if ( 'by_category' === $source ) {
						$query['term_id'] = $product_tab['category'];
					}

					$this->add_render_attribute( $tab_key, 'class', 'tab-panel' );

					if ( 1 === $loop_count ) {
						$this->add_render_attribute( $tab_key, 'class', 'active' );
					}

					$this->add_render_attribute( $tab_key, 'data-query', wp_json_encode( $query ) );
					$this->add_render_attribute( $tab_key, 'data-layout', $layout );
					?>
					<div <?php $this->print_render_attribute_string( $tab_key ); ?>>
						<div class="tab-mobile-heading secondary-font">
							<?php echo '' . $this->get_tab_title( $product_tab ); ?>
						</div>
						<div class="tab-content">
							<?php
							$this->before_slider();

							$this->print_slider( $settings );

							$this->after_slider();
							?>
						</div>
					</div>
				<?php endforeach; ?>
			</div>
		</div>
		<?php
	}

	private function get_tab_title( $tab ) {
		if ( ! empty( $tab['title'] ) ) {
			return $tab['title'];
		}

		$text = '';

		switch ( $tab['query_source'] ) {
			case 'latest' :
				$text = esc_html__( 'All', 'makeaholic' );
				break;
			case 'trending' :
				$text = esc_html__( 'Trending', 'makeaholic' );
				break;
			case 'best_selling' :
				$text = esc_html__( 'Best Selling', 'makeaholic' );
				break;
			case 'top_rated' :
				$text = esc_html__( 'Top Rated', 'makeaholic' );
				break;
			case 'on_sale' :
				$text = esc_html__( 'On Sale', 'makeaholic' );
				break;
			case 'popular' :
				$text = esc_html__( 'Popularity', 'makeaholic' );
				break;
			case 'featured' :
				$text = esc_html__( 'Featured', 'makeaholic' );
				break;
			case 'by_category' :
				$term = get_term_by( 'id', $tab['category'], $this->get_post_category() );
				if ( ! empty( $term ) ) {
					$text = $term->name;
				}

				break;
			default :
				$text = $tab;
				break;
		}

		return $text;
	}

	public function before_slider() {
		$settings = $this->get_settings_for_display();

		$style = ! empty( $settings['style'] ) ? $settings['style'] : 'carousel-01';

		if ( in_array( $style, [ 'carousel-01', 'carousel-03' ], true ) ) {
			$this->add_render_attribute( $this->get_slider_key(), 'class', 'group-style-01' );
		}

		if ( in_array( $style, [ 'carousel-02' ], true ) ) {
			$this->add_render_attribute( $this->get_slider_key(), 'class', 'group-style-02' );
		}

		$this->add_render_attribute( $this->get_slider_key(), 'class', 'tm-tab-product-element makeaholic-product style-' . $style );
	}

	public function after_slider() {
		echo '<div class="makeaholic-grid-response-messages"></div>';
	}

	protected function print_slides( array $settings ) {
		$number_posts = $settings['number_posts'];
		?>
		<?php for ( $i = $number_posts; $i > 0; $i-- ): ?>
			<div class="swiper-slide">
				<?php $this->print_skeleton_loading_item(); ?>
			</div>
		<?php endfor; ?>
		<?php
	}

	private function print_skeleton_loading_item() {
		?>
		<div class="makeaholic-skeleton-card style-01">
			<div class="makeaholic-skeleton-item makeaholic-skeleton-image"></div>
			<div class="makeaholic-skeleton-item makeaholic-skeleton-title"></div>
			<div
				class="makeaholic-skeleton-item makeaholic-skeleton-description"></div>
		</div>
		<?php
	}
}
