<?php

namespace Makeaholic_Elementor;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Typography;

defined( 'ABSPATH' ) || exit;

class Widget_Product_Category_Carousel extends Terms_Carousel_Base {

	public function get_name() {
		return 'tm-product-category-carousel';
	}

	public function get_title() {
		return esc_html__( 'Product Categories Carousel', 'makeaholic' );
	}

	public function get_icon_part() {
		return 'eicon-posts-carousel';
	}

	public function get_keywords() {
		return [ 'product', 'product category', 'product categories', 'carousel' ];
	}

	public function before_slider() {
		$settings = $this->get_settings_for_display();

		$this->add_render_attribute( $this->get_slider_key(), 'class', 'makeaholic-product-categories style-' . $settings['style'] );
	}

	protected function get_taxonomy_name() {
		return 'product_cat';
	}

	protected function register_controls() {
		$this->add_layout_section();

		parent::register_controls();

		$this->update_controls();

		$this->add_cat_style_section();
	}

	private function add_layout_section() {
		$this->start_controls_section( 'layout_section', [
			'label' => esc_html__( 'Layout', 'makeaholic' ),
		] );

		$this->add_control( 'style', [
			'label'       => esc_html__( 'Style', 'makeaholic' ),
			'type'        => Controls_Manager::SELECT,
			'options'     => [
				'01' => esc_html__( '01', 'makeaholic' ),
				'02' => esc_html__( '02', 'makeaholic' ),
				'03' => esc_html__( '03', 'makeaholic' ),
			],
			'default'     => '01',
			'render_type' => 'template',
		] );

		$this->add_control( 'hover_effect', [
			'label'        => esc_html__( 'Hover Effect', 'makeaholic' ),
			'type'         => Controls_Manager::SELECT,
			'options'      => [
				''         => esc_html__( 'None', 'makeaholic' ),
				'zoom-in'  => esc_html__( 'Zoom In', 'makeaholic' ),
				'zoom-out' => esc_html__( 'Zoom Out', 'makeaholic' ),
			],
			'default'      => '',
			'prefix_class' => 'makeaholic-animation-',
		] );

		$this->add_control( 'thumbnail_default_size', [
			'label'        => esc_html__( 'Use Default Thumbnail Size', 'makeaholic' ),
			'type'         => Controls_Manager::SWITCHER,
			'default'      => '1',
			'return_value' => '1',
			'separator'    => 'before',
		] );

		$this->add_group_control(
			Group_Control_Image_Size::get_type(),
			[
				'name'      => 'thumbnail',
				'default'   => 'full',
				'condition' => [
					'thumbnail_default_size!' => '1',
				],
			]
		);

		$this->end_controls_section();
	}

	private function update_controls() {
		$this->update_responsive_control( 'swiper_items', [
			'default'        => '4',
			'tablet_default' => '3',
			'mobile_default' => '2',
		] );

		$this->update_responsive_control( 'swiper_gutter', [
			'default' => 30,
		] );
	}

	private function add_cat_style_section() {
		$this->start_controls_section( 'cat_style_section', [
			'label' => esc_html__( 'Style', 'makeaholic' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_group_control( Group_Control_Background::get_type(), [
			'name'     => 'background_box',
			'types'    => [ 'classic', 'gradient' ],
			'selector' => '{{WRAPPER}} .cat-wrap',
		] );

		$this->add_responsive_control( 'box_padding', [
			'label'      => esc_html__( 'Padding', 'makeaholic' ),
			'type'       => Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%', 'em' ],
			'selectors'  => [
				'{{WRAPPER}} .cat-wrap' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		] );

		$this->add_responsive_control( 'box_radius', [
			'label'      => esc_html__( 'Border box radius', 'makeaholic' ),
			'type'       => Controls_Manager::DIMENSIONS,
			'size_units' => 'px',
			'selectors'  => [
				'{{WRAPPER}} .cat-wrap' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		] );

		$this->add_responsive_control( 'text_align', [
			'label'     => esc_html__( 'Alignment', 'makeaholic' ),
			'type'      => Controls_Manager::CHOOSE,
			'options'   => Widget_Utils::get_control_options_text_align_full(),
			'selectors' => [
				'{{WRAPPER}} .cat-wrap' => 'text-align: {{VALUE}};',
			],
		] );

		$this->add_control( 'cat_name', [
			'label'     => esc_html__( 'Name', 'makeaholic' ),
			'type'      => Controls_Manager::HEADING,
			'separator' => 'before',
		] );

		$this->start_controls_tabs( 'cat_name_color_tabs' );

		$this->start_controls_tab( 'cat_name_color_normal_tab', [
			'label' => esc_html__( 'Normal', 'makeaholic' ),
		] );

		$this->add_control( 'cat_name_color', [
			'label'     => esc_html__( 'Color', 'makeaholic' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .category-name' => 'color: {{VALUE}};',
			],
		] );

		$this->add_control( 'cat_name_line_color', [
			'label'     => esc_html__( 'Line Color', 'makeaholic' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .category-name::after' => 'background-color: {{VALUE}};',
			],
			'condition' => [
				'style' => '02',
			],
		] );

		$this->end_controls_tab();

		$this->start_controls_tab( 'cat_name_color_hover_tab', [
			'label' => esc_html__( 'Hover', 'makeaholic' ),
		] );

		$this->add_control( 'cat_name_hover_color', [
			'label'     => esc_html__( 'Color', 'makeaholic' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .category-name:hover' => 'color: {{VALUE}};',
			],
		] );

		$this->add_control( 'cat_name_line_hover_color', [
			'label'     => esc_html__( 'Line Color', 'makeaholic' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .category-name:hover::after' => 'background-color: {{VALUE}};',
			],
			'condition' => [
				'style' => '02',
			],
		] );

		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'title_typography',
			'selector' => '{{WRAPPER}} .category-name',
		] );

		$this->add_responsive_control( 'cat_name_margin_bottom', [
			'label'      => esc_html__( 'Margin Bottom', 'makeaholic' ),
			'type'       => Controls_Manager::SLIDER,
			'default'    => [
				'unit' => 'px',
			],
			'size_units' => [ 'px', '%' ],
			'range'      => [
				'%'  => [
					'min' => 1,
					'max' => 100,
				],
				'px' => [
					'min' => 1,
					'max' => 1600,
				],
			],
			'selectors'  => [
				'{{WRAPPER}} .category-name' => 'margin-bottom: {{SIZE}}{{UNIT}};',
			],
		] );

		$this->add_control( 'cat_image', [
			'label'     => esc_html__( 'Image', 'makeaholic' ),
			'type'      => Controls_Manager::HEADING,
			'separator' => 'before',
		] );

		$this->add_responsive_control( 'cat_image_margin_bottom', [
			'label'      => esc_html__( 'Margin Bottom', 'makeaholic' ),
			'type'       => Controls_Manager::SLIDER,
			'default'    => [
				'unit' => 'px',
			],
			'size_units' => [ 'px', '%' ],
			'range'      => [
				'%'  => [
					'min' => 1,
					'max' => 100,
				],
				'px' => [
					'min' => 1,
					'max' => 1600,
				],
			],
			'selectors'  => [
				'{{WRAPPER}} .cat-image' => 'margin-bottom: {{SIZE}}{{UNIT}};',
			],
		] );

		$this->add_responsive_control( 'cat_image_radius', [
			'label'      => esc_html__( 'Image radius', 'makeaholic' ),
			'type'       => Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%' ],
			'selectors'  => [
				'{{WRAPPER}} .cat-image img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		] );

		$this->end_controls_section();
	}

	protected function print_slide() {
		$settings  = $this->get_settings_for_display();
		$slide_key = $this->get_current_key();
		$category  = $this->get_current_slide();

		$box_key = $slide_key . 'box';

		$link = get_term_link( $category );

		$this->add_render_attribute( $box_key, [
			'class' => 'cat-image makeaholic-box link-secret',
			'href'  => $link,
		] );

		$thumbnail_id = get_term_meta( $category->term_id, 'thumbnail_id', true );

		$count = $category->count;

		$style = $settings['style'];
		?>
		<div class="swiper-slide">
			<div class="cat-wrap makeaholic-box">
				<?php if ( in_array( $style, [ '02' ], true ) ) : ?>
					<h6 class="category-name">
						<a href="<?php echo esc_url( $link ); ?>"><?php echo esc_html( $category->name ); ?></a>
					</h6>
				<?php endif; ?>


				<div class="makeaholic-image">
					<a <?php $this->print_render_attribute_string( $box_key ); ?>>
						<?php if ( $thumbnail_id ) { ?>
							<?php $size = \Makeaholic_Image::elementor_parse_image_size( $settings, '260x320' ); ?>
							<?php \Makeaholic_Image::the_attachment_by_id( [
								'id'   => $thumbnail_id,
								'size' => $size,
							] ); ?>
						<?php } else { ?>
							<?php \Makeaholic_Templates::image_placeholder( 260, 320 ); ?>
						<?php } ?>
					</a>
				</div>

				<div class="category-info">
					<?php if ( ! in_array( $style, [ '02' ], true ) ) : ?>
						<h3 class="category-name">
							<a href="<?php echo esc_url( $link ); ?>"><?php echo esc_html( $category->name ); ?></a>
						</h3>
					<?php endif; ?>

					<div class="category-count">
						<span class="cat-count-number">
							<?php echo esc_html( $count ); ?>
						</span>

						<span class="cat-count-text">
							<?php echo esc_html( _n( 'item', 'items', $category->count, 'makeaholic' ) ); ?>
						</span>
					</div>
				</div>
			</div>
		</div>
		<?php
	}
}
