<?php

namespace Makeaholic_Elementor;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;

defined( 'ABSPATH' ) || exit;

class Widget_Product_Categories_List extends Base {

	const PRODUCT_CATEGORY = 'product_cat';
	private $terms = [];

	public function get_name() {
		return 'tm-product-categories-list';
	}

	public function get_title() {
		return esc_html__( 'Product Categories List', 'makeaholic' );
	}

	public function get_icon_part() {
		return 'eicon-bullet-list';
	}

	public function get_keywords() {
		return [ 'product', 'product category', 'product categories', 'list' ];
	}

	protected function register_controls() {
		$this->add_layout_section();

		$this->add_category_style_section();

		$this->add_count_style_section();

		$this->add_query_section();
	}

	private function add_layout_section() {
		$this->start_controls_section( 'product_categories_section', [
			'label' => esc_html__( 'Product Categories', 'makeaholic' ),
		] );

		$this->add_control( 'product_count_display', [
			'label'       => esc_html__( 'Product Count Display', 'makeaholic' ),
			'type'        => Controls_Manager::SELECT,
			'options'     => [
				'hide'             => esc_html__( 'Hide', 'makeaholic' ),
				'always_show'      => esc_html__( 'Always showing', 'makeaholic' ),
				'show_while_hover' => esc_html__( 'Showing while hover', 'makeaholic' ),
			],
			'default'     => 'show_while_hover',
			'label_block' => true,
		] );

		$this->add_control( 'alignment', [
			'label'     => esc_html__( 'Alignment', 'makeaholic' ),
			'type'      => Controls_Manager::CHOOSE,
			'options'   => Widget_Utils::get_control_options_text_align(),
			'default'   => 'center',
			'selectors' => [
				'{{WRAPPER}}' => 'text-align: {{VALUE}};',
			],
		] );

		$this->end_controls_section();
	}

	private function add_category_style_section() {
		$this->start_controls_section( 'category_style_section', [
			'label' => esc_html__( 'Category', 'makeaholic' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_responsive_control( 'category_spacing', [
			'label'      => esc_html__( 'Spacing', 'makeaholic' ),
			'type'       => Controls_Manager::SLIDER,
			'size_units' => [ 'px' ],
			'range'      => [
				'px' => [
					'max' => 100,
					'min' => 0,
				],
			],
			'selectors'  => [
				'{{WRAPPER}} .makeaholic-product-categories-list ul li + li' => 'margin-top: {{SIZE}}{{UNIT}}',
			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'category_typography',
			'global' => [
				'default' => Global_Typography::TYPOGRAPHY_ACCENT,
			],
			'selector' => '{{WRAPPER}} .makeaholic-product-categories-list ul a',
		] );

		$this->start_controls_tabs( 'category_style_tabs' );

		$this->start_controls_tab(
			'category_style_normal_tab',
			[
				'label' => __( 'Normal', 'makeaholic' ),
			]
		);

		$this->add_control( 'category_color', [
			'label'     => esc_html__( 'Color', 'makeaholic' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .makeaholic-product-categories-list ul a' => 'color: {{VALUE}};',
			],
		] );

		$this->end_controls_tab();

		$this->start_controls_tab(
			'category_style_hover_tab',
			[
				'label' => __( 'Hover', 'makeaholic' ),
			]
		);

		$this->add_control( 'category_hover_color', [
			'label'     => esc_html__( 'Color', 'makeaholic' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .makeaholic-product-categories-list ul li:hover a' => 'color: {{VALUE}};',
			],
		] );

		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->end_controls_section();
	}

	private function add_count_style_section() {
		$this->start_controls_section( 'count_style_section', [
			'label' => esc_html__( 'Category Count', 'makeaholic' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_responsive_control( 'category_count_width', [
			'label'      => esc_html__( 'Width', 'makeaholic' ),
			'type'       => Controls_Manager::SLIDER,
			'size_units' => [ 'px' ],
			'range'      => [
				'px' => [
					'max' => 100,
					'min' => 0,
				],
			],
			'selectors'  => [
				'{{WRAPPER}} .makeaholic-product-categories-list ul .category-count' =>
					'width: {{SIZE}}{{UNIT}};
				height: {{SIZE}}{{UNIT}};
				line-height: {{SIZE}}{{UNIT}}',
			],
		] );

		$this->add_responsive_control( 'category_count_pos_x', [
			'label'      => esc_html__( 'Position X', 'makeaholic' ),
			'type'       => Controls_Manager::SLIDER,
			'size_units' => [ 'px' ],
			'range'      => [
				'px' => [
					'max' => 100,
					'min' => 0,
				],
			],
			'selectors'  => [
				'{{WRAPPER}} .makeaholic-product-categories-list ul .category-count' => 'margin-left: {{SIZE}}{{UNIT}}',
			],
		] );

		$this->add_responsive_control( 'category_count_pos_y', [
			'label'      => esc_html__( 'Position Y', 'makeaholic' ),
			'type'       => Controls_Manager::SLIDER,
			'size_units' => [ 'px' ],
			'range'      => [
				'px' => [
					'max' => 100,
					'min' => -100,
				],
			],
			'selectors'  => [
				'{{WRAPPER}} .makeaholic-product-categories-list ul .category-count' => 'top: {{SIZE}}{{UNIT}}',
			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'category_count_typography',
			'global' => [
				'default' => Global_Typography::TYPOGRAPHY_ACCENT,
			],
			'selector' => '{{WRAPPER}} .makeaholic-product-categories-list ul .category-count',
		] );

		$this->add_control( 'category_count_color', [
			'label'     => esc_html__( 'Color', 'makeaholic' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .makeaholic-product-categories-list ul .category-count' => 'color: {{VALUE}};',
			],
		] );

		$this->end_controls_section();
	}

	private function add_query_section() {
		$this->start_controls_section( 'query_section', [
			'label' => esc_html__( 'Query', 'makeaholic' ),
		] );

		$this->add_control( 'source', [
			'label'       => esc_html__( 'Source', 'makeaholic' ),
			'type'        => Controls_Manager::SELECT,
			'options'     => [
				''                      => esc_html__( 'Show All', 'makeaholic' ),
				'by_id'                 => esc_html__( 'Manual Selection', 'makeaholic' ),
				'by_parent'             => esc_html__( 'By Parent', 'makeaholic' ),
				'current_subcategories' => esc_html__( 'Current Subcategories', 'makeaholic' ),
			],
			'label_block' => true,
		] );

		$categories = get_terms( [
			'taxonomy'   => self::PRODUCT_CATEGORY,
			'hide_empty' => false,
		] );

		$options = [];
		foreach ( $categories as $category ) {
			$options[ $category->term_id ] = $category->name;
		}

		$this->add_control( 'categories', [
			'label'       => esc_html__( 'Categories', 'makeaholic' ),
			'type'        => Controls_Manager::SELECT2,
			'options'     => $options,
			'default'     => [],
			'label_block' => true,
			'multiple'    => true,
			'condition'   => [
				'source' => 'by_id',
			],
		] );

		$parent_options = [ '0' => esc_html__( 'Only Top Level', 'makeaholic' ) ] + $options;
		$this->add_control(
			'parent', [
			'label'     => esc_html__( 'Parent', 'makeaholic' ),
			'type'      => Controls_Manager::SELECT,
			'default'   => '0',
			'options'   => $parent_options,
			'condition' => [
				'source' => 'by_parent',
			],
		] );

		$this->add_control( 'hide_empty', [
			'label'     => esc_html__( 'Hide Empty', 'makeaholic' ),
			'type'      => Controls_Manager::SWITCHER,
			'default'   => 'yes',
			'label_on'  => 'Hide',
			'label_off' => 'Show',
		] );

		$this->add_control( 'number', [
			'label'     => esc_html__( 'Categories Count', 'makeaholic' ),
			'type'      => Controls_Manager::NUMBER,
			'default'   => '4',
			'condition' => [
				'source!' => 'by_id',
			],
		] );

		$this->add_control( 'orderby', [
			'label'     => esc_html__( 'Order By', 'makeaholic' ),
			'type'      => Controls_Manager::SELECT,
			'default'   => 'name',
			'options'   => [
				'name'        => esc_html__( 'Name', 'makeaholic' ),
				'slug'        => esc_html__( 'Slug', 'makeaholic' ),
				'description' => esc_html__( 'Description', 'makeaholic' ),
				'count'       => esc_html__( 'Count', 'makeaholic' ),
			],
			'condition' => [
				'source!' => 'by_id',
			],
		] );

		$this->add_control( 'order', [
			'label'     => esc_html__( 'Order', 'makeaholic' ),
			'type'      => Controls_Manager::SELECT,
			'default'   => 'desc',
			'options'   => [
				'asc'  => esc_html__( 'ASC', 'makeaholic' ),
				'desc' => esc_html__( 'DESC', 'makeaholic' ),
			],
			'condition' => [
				'source!' => 'by_id',
			],
		] );

		$this->end_controls_section();
	}

	private function query_terms() {
		$settings = $this->get_settings_for_display();

		$attributes = [
			'taxonomy'   => self::PRODUCT_CATEGORY,
			'number'     => $settings['number'],
			'hide_empty' => ( 'yes' === $settings['hide_empty'] ) ? true : false,
		];

		switch ( $settings['source'] ) {
			case 'by_id':
				$attributes['include'] = $settings['categories'];
				$attributes['orderby'] = 'include';
				break;
			case 'by_parent' :
				$attributes['parent']  = $settings['parent'];
				$attributes['orderby'] = $settings['orderby'];
				$attributes['order']   = $settings['order'];
				break;
			case 'current_subcategories':
				$attributes['parent']  = get_queried_object_id();
				$attributes['orderby'] = $settings['orderby'];
				$attributes['order']   = $settings['order'];
				break;
			default:
				$attributes['orderby'] = $settings['orderby'];
				$attributes['order']   = $settings['order'];
				break;
		}

		$this->terms = get_terms( $attributes );
	}

	protected function render() {
		$settings = $this->get_settings_for_display();
		$this->query_terms();

		if ( empty( $this->terms ) ) {
			return;
		}

		$this->add_render_attribute( 'wrapper', 'class', 'makeaholic-product-categories-list makeaholic-product-categories-list--count-' . $settings['product_count_display'] );
		?>
		<div <?php $this->print_attributes_string( 'wrapper' ); ?>>
			<ul>
				<?php foreach ( $this->terms as $term ) : ?>
					<li>
						<a href="<?php echo esc_url( get_term_link( $term ) ); ?>">
							<?php echo esc_html( $term->name ); ?>
							<p class="category-count"><?php echo esc_html( $term->count ); ?></p>
						</a>
					</li>
				<?php endforeach; ?>
			</ul>
		</div>
		<?php
	}
}
