<?php
defined( 'ABSPATH' ) || exit;

/**
 * Enqueue custom styles.
 */
if ( ! class_exists( 'Makeaholic_Custom_Css' ) ) {
	class Makeaholic_Custom_Css {

		protected static $instance = null;

		public static function instance() {
			if ( null === self::$instance ) {
				self::$instance = new self();
			}

			return self::$instance;
		}

		public function initialize() {
			add_action( 'wp_enqueue_scripts', [ $this, 'frontend_root_css' ] );

			add_action( 'wp_enqueue_scripts', array( $this, 'extra_css' ) );
		}

		public function get_root_css() {
			$primary_color     = Makeaholic::setting( 'primary_color' );
			$primary_color_rgb = Makeaholic_Color::hex2rgb_string( $primary_color );
			$secondary_color   = Makeaholic::setting( 'secondary_color' );

			$button_colors          = Makeaholic::setting( 'button_color' );
			$button_hover_colors    = Makeaholic::setting( 'button_hover_color' );
			$form_colors            = Makeaholic::setting( 'form_input_color' );
			$form_focus_colors      = Makeaholic::setting( 'form_input_focus_color' );
			$text_color             = Makeaholic::setting( 'body_color' );
			$text_bit_lighten_color = '#7e7e7e';
			$text_lighten_color     = Makeaholic::setting( 'body_lighten_color' );
			$heading_color          = Makeaholic::setting( 'heading_color' );
			$link_color             = Makeaholic::setting( 'link_color' );
			$box_white_border       = '#ededed';
			$box_white_bg           = '#fff';
			$box_grey_bg            = '#f8f8f8';
			$box_light_grey_bg      = '#f9f9fb';
			$box_separator          = '#eee';
			$box_border             = '#eee';
			$box_border_lighten     = '#ededed';
			$sub_menu_background    = Makeaholic::setting( 'navigation_dropdown_bg_color' );
			$sub_menu_border        = '#ededed';

			$form_text             = $form_colors['color'];
			$form_border           = $form_colors['border'];
			$form_background       = $form_colors['background'];
			$form_focus_text       = $form_focus_colors['color'];
			$form_focus_border     = $form_focus_colors['border'];
			$form_focus_background = $form_focus_colors['background'];

			$button_text             = $button_colors['color'];
			$button_border           = $button_colors['border'];
			$button_background       = $button_colors['background'];
			$button_hover_text       = $button_hover_colors['color'];
			$button_hover_border     = $button_hover_colors['border'];
			$button_hover_background = $button_hover_colors['background'];

			$body_font        = Makeaholic::setting( 'typography_body' );
			$body_font_weight = $body_font['variant'];
			$body_font_weight = 'regular' === $body_font_weight ? 400 : $body_font_weight; // Fix regular is not valid weight.

			$heading_font = Makeaholic::setting( 'typography_heading' );

			$heading_font_family = '' === $heading_font['font-family'] ? 'inherit' : $heading_font['font-family'];
			$heading_font_weight = $heading_font['variant'];
			$heading_font_weight = 'regular' === $heading_font_weight ? 400 : $heading_font_weight; // Fix regular is not valid weight.

			$heading2_font = Makeaholic::setting( 'typography_heading2' );

			$heading2_font_family = '' === $heading2_font['font-family'] ? 'inherit' : $heading2_font['font-family'];
			$heading2_font_weight = $heading2_font['variant'];
			$heading2_font_weight = 'regular' === $heading2_font_weight ? 400 : $heading2_font_weight; // Fix regular is not valid weight.

			$css = ":root {
				--makeaholic-typography-body-font-family: {$body_font['font-family']};
				--makeaholic-typography-body-font-size: {$body_font['font-size']};
				--makeaholic-typography-body-font-weight: {$body_font_weight};
				--makeaholic-typography-body-line-height: {$body_font['line-height']};
				--makeaholic-typography-body-letter-spacing: {$body_font['letter-spacing']};
				--makeaholic-typography-headings-font-family: {$heading_font_family};
				--makeaholic-typography-headings-font-weight: {$heading_font_weight};
				--makeaholic-typography-headings-line-height: {$heading_font['line-height']};
				--makeaholic-typography-headings-letter-spacing: {$heading_font['letter-spacing']};
				--makeaholic-typography-headings-2-font-family: {$heading2_font_family};
				--makeaholic-typography-headings-2-font-weight: {$heading2_font_weight};
				--makeaholic-typography-headings-2-line-height: {$heading2_font['line-height']};
				--makeaholic-typography-headings-2-letter-spacing: {$heading2_font['letter-spacing']};
				--makeaholic-color-primary: {$primary_color};
				--makeaholic-color-primary-rgb: {$primary_color_rgb};
				--makeaholic-color-secondary: {$secondary_color};
				--makeaholic-color-text: {$text_color};
				--makeaholic-color-text-bit-lighten: {$text_bit_lighten_color};
				--makeaholic-color-text-lighten: {$text_lighten_color};
				--makeaholic-color-heading: {$heading_color};
				--makeaholic-color-link: {$link_color['normal']};
				--makeaholic-color-link-hover: {$link_color['hover']};
				--makeaholic-color-box-white-background: {$box_white_bg};
				--makeaholic-color-box-white-border: {$box_white_border};
				--makeaholic-color-box-grey-background: {$box_grey_bg};
				--makeaholic-color-box-light-grey-background: {$box_light_grey_bg};
				--makeaholic-color-box-fill-separator: {$box_separator};
				--makeaholic-color-box-border: {$box_border};
				--makeaholic-color-box-border-lighten: {$box_border_lighten};
				--makeaholic-color-button-text: {$button_text};
				--makeaholic-color-button-border: {$button_border};
				--makeaholic-color-button-background: {$button_background};
				--makeaholic-color-button-hover-text: {$button_hover_text};
				--makeaholic-color-button-hover-border: {$button_hover_border};
				--makeaholic-color-button-hover-background: {$button_hover_background};
				--makeaholic-color-form-text: {$form_text};
				--makeaholic-color-form-border: {$form_border};
				--makeaholic-color-form-background: {$form_background};
				--makeaholic-color-form-focus-text: {$form_focus_text};
				--makeaholic-color-form-focus-border: {$form_focus_border};
				--makeaholic-color-form-focus-background: {$form_focus_background};
				--makeaholic-color-sub-menu-border: {$sub_menu_border};
				--makeaholic-color-sub-menu-background: {$sub_menu_background};
			}";

			return $css;
		}

		public function frontend_root_css() {
			$css = $this->get_root_css();

			wp_add_inline_style( 'makeaholic-style', html_entity_decode( $css, ENT_QUOTES ) );
		}

		/**
		 * Responsive styles.
		 *
		 * @access public
		 */
		public function extra_css() {
			$extra_style = '';

			$custom_logo_width        = Makeaholic_Helper::get_post_meta( 'custom_logo_width', '' );
			$custom_sticky_logo_width = Makeaholic_Helper::get_post_meta( 'custom_sticky_logo_width', '' );

			if ( $custom_logo_width !== '' ) {
				$extra_style .= ".branding__logo img { 
                    width: {$custom_logo_width} !important; 
                }";
			}

			if ( $custom_sticky_logo_width !== '' ) {
				$extra_style .= ".headroom--not-top .branding__logo .sticky-logo { 
                    width: {$custom_sticky_logo_width} !important; 
                }";
			}

			$site_width = Makeaholic_Helper::get_post_meta( 'site_width', '' );
			if ( $site_width === '' ) {
				$site_width = Makeaholic::setting( 'site_width' );
			}

			if ( $site_width !== '' ) {
				$extra_style .= "
				.boxed
				{
	                max-width: $site_width;
	            }";
			}

			$site_top_spacing = Makeaholic_Helper::get_post_meta( 'site_top_spacing', '' );

			if ( $site_top_spacing !== '' ) {
				$extra_style .= "
				.boxed
				{
	                margin-top: {$site_top_spacing};
	            }";
			}

			$site_bottom_spacing = Makeaholic_Helper::get_post_meta( 'site_bottom_spacing', '' );

			if ( $site_bottom_spacing !== '' ) {
				$extra_style .= "
				.boxed
				{
	                margin-bottom: {$site_bottom_spacing};
	            }";
			}

			$tmp = '';

			$site_background_color = Makeaholic_Helper::get_post_meta( 'site_background_color', '' );
			if ( $site_background_color !== '' ) {
				$tmp .= "background-color: $site_background_color !important;";
			}

			$site_background_image = Makeaholic_Helper::get_post_meta( 'site_background_image', '' );
			if ( $site_background_image !== '' ) {
				$site_background_repeat = Makeaholic_Helper::get_post_meta( 'site_background_repeat', '' );
				$tmp                    .= "background-image: url( $site_background_image ) !important; background-repeat: $site_background_repeat !important;";
			}

			$site_background_position = Makeaholic_Helper::get_post_meta( 'site_background_position', '' );
			if ( $site_background_position !== '' ) {
				$tmp .= "background-position: $site_background_position !important;";
			}

			$site_background_size = Makeaholic_Helper::get_post_meta( 'site_background_size', '' );
			if ( $site_background_size !== '' ) {
				$tmp .= "background-size: $site_background_size !important;";
			}

			$site_background_attachment = Makeaholic_Helper::get_post_meta( 'site_background_attachment', '' );
			if ( $site_background_attachment !== '' ) {
				$tmp .= "background-attachment: $site_background_attachment !important;";
			}

			if ( $tmp !== '' ) {
				$extra_style .= "body { $tmp; }";
			}

			$tmp = '';

			$content_background_color = Makeaholic_Helper::get_post_meta( 'content_background_color', '' );
			if ( $content_background_color !== '' ) {
				$tmp .= "background-color: $content_background_color !important;";
			}

			$content_background_image = Makeaholic_Helper::get_post_meta( 'content_background_image', '' );
			if ( $content_background_image !== '' ) {
				$content_background_repeat = Makeaholic_Helper::get_post_meta( 'content_background_repeat', '' );
				$tmp                       .= "background-image: url( $content_background_image ) !important; background-repeat: $content_background_repeat !important;";
			}

			$content_background_position = Makeaholic_Helper::get_post_meta( 'content_background_position', '' );
			if ( $content_background_position !== '' ) {
				$tmp .= "background-position: $content_background_position !important;";
			}

			if ( $tmp !== '' ) {
				$extra_style .= ".site { $tmp; }";
			}

			$extra_style .= $this->primary_color_css();
			$extra_style .= $this->secondary_color_css();
			$extra_style .= $this->primary_bg_color_css();
			$extra_style .= $this->header_css();
			$extra_style .= $this->sidebar_css();
			$extra_style .= $this->title_bar_css();
			$extra_style .= $this->light_gallery_css();
			$extra_style .= $this->off_canvas_menu_css();
			$extra_style .= $this->mobile_menu_css();

			$extra_style = Makeaholic_Minify::css( $extra_style );

			wp_add_inline_style( 'makeaholic-style', html_entity_decode( $extra_style, ENT_QUOTES ) );
		}

		function header_css() {
			$header_type = Makeaholic_Global::instance()->get_header_type();
			$css         = '';

			$nav_bg_type = Makeaholic::setting( "header_style_{$header_type}_navigation_background_type" );

			if ( $nav_bg_type === 'gradient' ) {

				$gradient = Makeaholic::setting( "header_style_{$header_type}_navigation_background_gradient" );
				$_color_1 = $gradient['from'];
				$_color_2 = $gradient['to'];

				$css .= "
				.header-$header_type .header-bottom {
					background: {$_color_1};
                    background: -webkit-linear-gradient(-136deg, {$_color_2} 0%, {$_color_1} 100%);
                    background: linear-gradient(-136deg, {$_color_2} 0%, {$_color_1} 100%);
				}";
			}

			return $css;
		}

		function sidebar_css() {
			$css = '';

			$page_sidebar1  = Makeaholic_Global::instance()->get_sidebar_1();
			$page_sidebar2  = Makeaholic_Global::instance()->get_sidebar_2();
			$sidebar_status = Makeaholic_Global::instance()->get_sidebar_status();

			if ( 'none' !== $page_sidebar1 ) {

				if ( $sidebar_status === 'both' ) {
					$sidebars_breakpoint = Makeaholic::setting( 'both_sidebar_breakpoint' );
				} else {
					$sidebars_breakpoint = Makeaholic::setting( 'one_sidebar_breakpoint' );
				}

				$sidebars_below = Makeaholic::setting( 'sidebars_below_content_mobile' );

				if ( 'none' !== $page_sidebar2 ) {
					$sidebar_width  = floatval( apply_filters( 'makeaholic/page_sidebar/dual_width', Makeaholic::setting( 'dual_sidebar_width' ) ) );
					$sidebar_offset = apply_filters( 'makeaholic/page_sidebar/dual_offset', Makeaholic::setting( 'dual_sidebar_offset' ) );

					$content_width = 100 - $sidebar_width * 2;
				} else {
					$sidebar_width  = floatval( apply_filters( 'makeaholic/page_sidebar/single_width', Makeaholic::setting( 'single_sidebar_width' ) ) );
					$sidebar_offset = apply_filters( 'makeaholic/page_sidebar/single_offset', Makeaholic::setting( 'single_sidebar_offset' ) );

					$content_width = 100 - $sidebar_width;
				}

				$css .= "
				@media (min-width: {$sidebars_breakpoint}px) {
					.page-sidebar {
						flex: 0 0 $sidebar_width%;
						max-width: $sidebar_width%;
					}
					.page-main-content {
						flex: 0 0 $content_width%;
						max-width: $content_width%;
					}
				}";

				if ( is_rtl() ) {
					$css .= "@media (min-width: 1200px) {
						.page-sidebar-left .page-sidebar-inner {
							padding-left: $sidebar_offset;
						}
						.page-sidebar-right .page-sidebar-inner {
							padding-right: $sidebar_offset;
						}
					}";
				} else {
					$css .= "@media (min-width: 1200px) {
						.page-sidebar-left .page-sidebar-inner {
							padding-right: $sidebar_offset;
						}
						.page-sidebar-right .page-sidebar-inner {
							padding-left: $sidebar_offset;
						}
					}";
				}

				$_max_width_breakpoint = $sidebars_breakpoint - 1;

				if ( $sidebars_below === '1' ) {
					$css .= "
					@media (max-width: {$_max_width_breakpoint}px) {
						.page-sidebar {
							margin-top: 50px;
						}
					
						.page-main-content {
							-webkit-order: -1;
							-moz-order: -1;
							order: -1;
						}
					}";
				}
			}

			return $css;
		}

		function title_bar_css() {
			$css = $title_bar_tmp = $overlay_tmp = '';

			$type    = Makeaholic_Global::instance()->get_title_bar_type();
			$bg_type = Makeaholic::setting( "title_bar_{$type}_background_type" );

			if ( 'gradient' === $bg_type ) {
				$gradient_color = Makeaholic::setting( "title_bar_{$type}_background_gradient" );
				$color1         = $gradient_color['color_1'];
				$color2         = $gradient_color['color_2'];

				$css .= "
					.page-title-bar-bg
					{
						background-color: $color1;
						background-image: linear-gradient(-180deg, {$color1} 0%, {$color2} 100%);
					}
				";
			}

			$bg_color   = Makeaholic_Helper::get_post_meta( 'page_title_bar_background_color', '' );
			$bg_image   = Makeaholic_Helper::get_post_meta( 'page_title_bar_background', '' );
			$bg_overlay = Makeaholic_Helper::get_post_meta( 'page_title_bar_background_overlay', '' );

			if ( $bg_color !== '' ) {
				$title_bar_tmp .= "background-color: {$bg_color}!important;";
			}

			if ( '' !== $bg_image ) {
				$title_bar_tmp .= "background-image: url({$bg_image})!important;";
			}

			if ( '' !== $bg_overlay ) {
				$overlay_tmp .= "background-color: {$bg_overlay}!important;";
			}

			if ( '' !== $title_bar_tmp ) {
				$css .= ".page-title-bar-bg{ {$title_bar_tmp} }";
			}

			if ( '' !== $overlay_tmp ) {
				$css .= ".page-title-bar-bg:before{ {$overlay_tmp} }";
			}

			$bottom_spacing = Makeaholic_Helper::get_post_meta( 'page_title_bar_bottom_spacing', '' );
			if ( '' !== $bottom_spacing ) {
				$css .= "#page-title-bar{ margin-bottom: {$bottom_spacing}; }";
			}

			return $css;
		}

		function primary_color_css() {
			$color_selectors = "
				mark,
                .primary-color,
                .title-has-link a:hover,
                .growl-close:hover,
                .link-transition-02,
                .switcher-language-wrapper .wpml-ls .wpml-ls-sub-menu a:hover,
                .header-categories-nav .product-category-dropdown > li:hover > a,
                .tm-button.style-border,
                .tm-button.style-thick-border,
                .tm-button.style-text:hover .button-text,
                .tm-button.style-text .button-icon,
                .makeaholic-team-member-style-01 .social-networks a:hover,
				.makeaholic-infinite-loader,
				.elementor-widget-tm-icon-box.makeaholic-icon-box-style-01 .makeaholic-icon,
				.makeaholic-blog .post-title a:hover,
				.makeaholic-blog .post-categories a:hover,
				.makeaholic-blog-caption-style-03 .tm-button,
				.makeaholic-pricing .price-wrap,
				.makeaholic-timeline.style-01 .title,
				.makeaholic-timeline.style-01 .timeline-dot,
				.tm-google-map .style-signal .animated-dot,
				.makeaholic-list .marker,
				.makeaholic-pricing-style-02 .makeaholic-pricing .makeaholic-pricing-features li i,
				.tm-social-networks .link:hover,
				.tm-social-networks.style-solid-rounded-icon .link,
				.makeaholic-modern-carousel-style-02 .slide-button,
				.tm-slider a:hover .heading,
				.woosw-area .woosw-inner .woosw-content .woosw-content-bot .woosw-content-bot-inner .woosw-page a:hover,
				.woosw-continue:hover,
				.tm-menu .menu-price,
				.woocommerce-widget-layered-nav-list a:hover,
				.post-share a:hover,
				.blog-nav-links h6:before,
				.page-links > a:hover, .page-links > a:focus,
				.header-search-form .search-submit,
				.widget_search .search-submit:hover,
				.widget_product_search .search-submit:hover,
				.page-sidebar .widget_pages .current-menu-item > a,
				.page-sidebar .widget_nav_menu .current-menu-item > a,
				.page-sidebar .insight-core-bmw .current-menu-item > a,
				.makeaholic-wp-widget-posts .post-widget-title a:hover,
				.comment-list .comment-actions a:hover,
				.makeaholic-fake-select-wrap .makeaholic-fake-select li.selected:before,
				.elementor-widget-tm-icon-box.makeaholic-icon-box-style-01 .makeaholic-box:hover div.tm-button.style-text,
				.elementor-widget-tm-icon-box.makeaholic-icon-box-style-01 a.tm-button.style-text:hover,
				.tm-image-box.makeaholic-box:hover div.tm-button.style-text,
				.tm-image-box a.tm-button.style-text:hover";

			$bg_color_selectors = "
				.primary-background-color,
				.link-transition-02:after,
				input[type='checkbox']:checked:before,
				.wp-block-calendar #today,
				.entry-post-categories a:hover,
				.makeaholic-fake-select-wrap .makeaholic-fake-select li:hover,
				.makeaholic-link-animate-border .heading-primary a mark:after,
                .tm-button.style-flat:before,
                .tm-button.style-border:after,
                .tm-button.style-thick-border:after,
                .makeaholic-tab-nav-buttons button:hover,
                .makeaholic-blog-caption-style-03 .tm-button.style-bottom-line .button-content-wrapper:after,
                .hint--primary:after,
                [data-fp-section-skin='dark'] #fp-nav ul li a span,
                [data-fp-section-skin='dark'] .fp-slidesNav ul li a span,
                .page-scroll-up,
                .top-bar-01 .top-bar-button,
				.tm-social-networks.style-flat-rounded-icon .link:hover,
				.tm-swiper .swiper-pagination-progressbar .swiper-pagination-progressbar-fill,
				.tm-social-networks.style-flat-rounded-icon .link,
				.tm-social-networks.style-solid-rounded-icon .link:hover,
				.makeaholic-modern-carousel .slide-tag,
				.makeaholic-light-gallery .makeaholic-box .makeaholic-overlay,
				.makeaholic-accordion-style-02 .makeaholic-accordion .accordion-section.active .accordion-header,
				.makeaholic-accordion-style-02 .makeaholic-accordion .accordion-section:hover .accordion-header,
				.makeaholic-mailchimp-form-style-01 .form-submit,
				.makeaholic-modern-carousel-style-02 .slide-button:after,
				.tm-gradation .item:hover .count,
				.nav-links a:hover,
				.page-links .current,
				.page-sidebar .insight-core-bmw li:hover a,
				.page-sidebar .insight-core-bmw li.current-menu-item a,
				.post-share.style-01 .share-icon,
				.widget_calendar #today,
				.woocommerce .select2-container--default .select2-results__option--highlighted[aria-selected],
				.select2-container--default .select2-results__option[aria-selected=true],
				.select2-container--default .select2-results__option[data-selected=true],
				.makeaholic-blog .post-overlay-categories a:hover,
				.tm-button.style-flat.button-black:after
				";

			$bg_color_important_selectors = "
				.primary-background-color-important,
				.lg-progress-bar .lg-progress
				";

			$border_color_selectors = "
				input[type='checkbox']:hover:before,			
				.wp-block-quote,
				.wp-block-quote.has-text-align-right,
				.tm-button.style-border,
				.tm-button.style-thick-border,
				.makeaholic-tab-nav-buttons button:hover,
				.makeaholic-fake-select-wrap.focused .makeaholic-fake-select-current,
				.page-search-popup .search-field,
				.tm-social-networks.style-solid-rounded-icon .link,
				.tm-popup-video.type-button .video-play,
				.widget_pages .current-menu-item, 
				.widget_nav_menu .current-menu-item,
				.insight-core-bmw .current-menu-item,
				.page-sidebar .insight-core-bmw li:hover a,
				.page-sidebar .insight-core-bmw li.current-menu-item a
			";

			$border_color_important_selectors = "
				.lg-outer .lg-thumb-item.active, .lg-outer .lg-thumb-item:hover
			";

			$border_top_color_selectors = "
				.hint--primary.hint--top-left:before,
                .hint--primary.hint--top-right:before,
                .hint--primary.hint--top:before
			";

			$border_right_color_selectors = "
				.hint--primary.hint--right:before
			";

			$border_bottom_color_selectors = "
				.hint--primary.hint--bottom-left:before,
                .hint--primary.hint--bottom-right:before,
                .hint--primary.hint--bottom:before,
                .makeaholic-tabpanel.makeaholic-tabpanel-horizontal > .makeaholic-nav-tabs li.active a,
                .makeaholic-mailchimp-form-style-02 input[type='email']:focus
			";

			$border_left_color_selectors = "
				.hint--primary.hint--left:before,
                .tm-popup-video.type-button .video-play-icon:before,
                .elementor-widget-sidebar .insight-core-bmw a:hover,
                .elementor-widget-sidebar .insight-core-bmw li.current-menu-item a
			";

			$primary_selectors = [
				'color'                      => [ $color_selectors ],
				'background-color'           => [ $bg_color_selectors ],
				'background-color-important' => [ $bg_color_important_selectors ],
				'border-color'               => [ $border_color_selectors ],
				'border-color-important'     => [ $border_color_important_selectors ],
				'border-top-color'           => [ $border_top_color_selectors ],
				'border-right-color'         => [ $border_right_color_selectors ],
				'border-bottom-color'        => [ $border_bottom_color_selectors ],
				'border-left-color'          => [ $border_left_color_selectors ],
			];

			$primary_selectors = apply_filters( 'makeaholic/custom_css/primary_color_selectors', $primary_selectors );

			$color            = Makeaholic::setting( 'primary_color' );
			$color_alpha_80   = Makeaholic_Color::hex2rgba( $color, '0.8' );
			$color_alpha_70   = Makeaholic_Color::hex2rgba( $color, '0.7' );
			$color_alpha_50   = Makeaholic_Color::hex2rgba( $color, '0.5' );
			$color_alpha_10   = Makeaholic_Color::hex2rgba( $color, '0.1' );
			$color_lighten_10 = Makeaholic_Color::luminance( $color, 0.1 );
			$color_lighten_90 = Makeaholic_Color::luminance( $color, 0.9 );

			$css = "
				::-moz-selection { color: #fff; background-color: $color }
				::selection { color: #fff; background-color: $color }
			";

			foreach ( $primary_selectors as $key => $selectors ) {
				$css_selectors = implode( ',', $selectors );

				if ( ! empty( $css_selectors ) ) {
					$attr_name   = $key;
					$attr_suffix = '';

					if ( strpos( $key, 'important' ) !== false ) {
						$attr_name   = strstr( $key, '-important', true );
						$attr_suffix = '!important';
					}

					$css .= "{$css_selectors} { {$attr_name}: {$color}$attr_suffix; }";
				}
			}

			$css .= "
				.switcher-language-wrapper .wpml-ls .wpml-ls-sub-menu a:hover,
				.header-categories-nav .product-category-dropdown > li:hover > a
				{
					background-color: {$color_alpha_10};
				}";
			$css .= "
				.tm-button.style-bottom-line-winding .button-content-wrapper .line-winding svg path
				{
					fill: {$color_alpha_50};
				}";

			$css .= "
				.entry-post-feature.post-link
				{
					background-color: {$color_lighten_10};
				}";

			return $css;
		}

		function secondary_color_css() {
			$color          = Makeaholic::setting( 'secondary_color' );
			$color_alpha_60 = Makeaholic_Color::hex2rgba( $color, '0.6' );

			// Color.
			$css = "
				.secondary-color,
				.makeaholic-product-banner .price,
				.makeaholic-product-banner ins,
				.makeaholic-product-banner ins .amount,
				.woosc-table .price,
				.makeaholic-blog-zigzag .post-title
				{
					color: {$color} 
				}";

			// Background Color.
			$css .= "
				.hint--secondary:after,
				.makeaholic-product-categories.style-02 .category-name:after,
				.woocommerce-tabs .tabs li.active a:after,
				.single-product .woocommerce-Reviews-title:after
				{
					background-color: {$color};
				}";

			// Background Color.
			$css .= "
				.makeaholic-event .event-overlay-background,
				.makeaholic-event-carousel .event-overlay-background
				{
					background-color: {$color_alpha_60};
				}";

			// Border Top.
			$css .= "
                .hint--secondary.hint--top-left:before,
                .hint--secondary.hint--top-right:before,
                .hint--secondary.hint--top:before
                {
					border-top-color: {$color};
				}";

			// Border Right.
			$css .= "
                .hint--secondary.hint--right:before
                {
					border-right-color: {$color};
				}";

			// Border Bottom.
			$css .= "
                .hint--secondary.hint--bottom-left:before,
                .hint--secondary.hint--bottom-right:before,
                .hint--secondary.hint--bottom:before
                {
					border-bottom-color: {$color};
				}";

			// Border Left.
			$css .= "
                .hint--secondary.hint--left:before
                {
                    border-left-color: {$color};
                }";

			// Fill Color.
			$css .= "
				.tm-button.style-bottom-line-winding:hover .button-content-wrapper .line-winding svg path
				{
					fill: {$color};
				}";

			return $css;
		}

		function primary_bg_color_css() {
			$css   = '';
			$color = Makeaholic::setting( 'primary_bg_color' );

			// Background Color.
			$css .= "
				.entry-post-categories a,
				.makeaholic-blog .post-overlay-categories a,
				.woosw-list .button,
				.woosw-list .add_to_cart_button,
				.woosc-area .woosc-inner .woosc-table .woosc-table-inner .woosc-table-items .button
				{
					background-color: {$color};
				}";

			// Border Color.
			$css .= "
				.woosw-list .button,
				.woosw-list .add_to_cart_button,
				.woosc-area .woosc-inner .woosc-table .woosc-table-inner .woosc-table-items .button
				{
					border-color: {$color};
				}";

			return $css;
		}

		function light_gallery_css() {
			$css                    = '';
			$primary_color          = Makeaholic::setting( 'primary_color' );
			$secondary_color        = Makeaholic::setting( 'secondary_color' );
			$cutom_background_color = Makeaholic::setting( 'light_gallery_custom_background' );
			$background             = Makeaholic::setting( 'light_gallery_background' );

			$tmp = '';

			if ( $background === 'primary' ) {
				$tmp .= "background-color: {$primary_color} !important;";
			} elseif ( $background === 'secondary' ) {
				$tmp .= "background-color: {$secondary_color} !important;";
			} else {
				$tmp .= "background-color: {$cutom_background_color} !important;";
			}

			$css .= ".lg-backdrop { $tmp }";

			return $css;
		}

		function off_canvas_menu_css() {
			$css  = '';
			$type = Makeaholic::setting( 'navigation_minimal_01_background_type' );
			if ( $type === 'gradient' ) {
				$gradient = Makeaholic::setting( 'navigation_minimal_01_background_gradient_color' );

				$css .= ".popup-canvas-menu {
				    background-color: {$gradient['color_1']};
					background-image: linear-gradient(138deg, {$gradient['color_1']} 0%, {$gradient['color_2']} 100%);
				}";
			}

			return $css;
		}

		function mobile_menu_css() {
			$css  = '';
			$type = Makeaholic::setting( 'mobile_menu_background_type' );
			if ( $type === 'gradient' ) {
				$gradient = Makeaholic::setting( 'mobile_menu_background_gradient_color' );

				$css .= ".page-mobile-main-menu > .inner {
				    background-color: {$gradient['color_1']};
					background-image: linear-gradient(138deg, {$gradient['color_1']} 0%, {$gradient['color_2']} 100%);
				}";
			}

			return $css;
		}
	}

	Makeaholic_Custom_Css::instance()->initialize();
}
