<?php
defined( 'ABSPATH' ) || exit;

/**
 * Enqueue scripts and styles.
 */
if ( ! class_exists( 'Makeaholic_Enqueue' ) ) {
	class Makeaholic_Enqueue {

		protected static $instance = null;

		public static function instance() {
			if ( null === self::$instance ) {
				self::$instance = new self();
			}

			return self::$instance;
		}

		public function initialize() {
			// Set priority 4 to make it run before elementor register scripts.
			add_action( 'wp_enqueue_scripts', [ $this, 'register_swiper' ], 4 );

			add_action( 'wp_enqueue_scripts', [ $this, 'frontend_scripts' ] );
			add_action( 'elementor/frontend/before_register_scripts', [ $this, 'fix_out_date_smartmenus' ], 1 );

			/**
			 * Make it run after main style & components.
			 */
			add_action( 'wp_enqueue_scripts', [ $this, 'rtl_styles' ], 20 );

			// Disable all contact form 7 scripts.
			add_filter( 'wpcf7_load_js', '__return_false' );
			add_filter( 'wpcf7_load_css', '__return_false' );
		}

		/**
		 * Register swiper lib.
		 * Use on wp_enqueue_scripts action.
		 */
		public function register_swiper() {
			$min = $this->get_min_suffix();

			wp_register_style( 'swiper', MAKEAHOLIC_THEME_URI . '/assets/libs/swiper/css/swiper.min.css', null, '8.4.5' );
			wp_register_script( 'swiper', MAKEAHOLIC_THEME_URI . "/assets/libs/swiper/js/swiper{$min}.js", array(
				'jquery',
				'imagesloaded',
			), '8.4.5', true );

			wp_register_script( 'makeaholic-swiper-wrapper', MAKEAHOLIC_THEME_URI . "/assets/js/swiper-wrapper{$min}.js", array( 'swiper' ), MAKEAHOLIC_THEME_VERSION, true );

			$makeaholic_swiper_js = array(
				'prevText' => esc_html__( 'Prev', 'makeaholic' ),
				'nextText' => esc_html__( 'Next', 'makeaholic' ),
			);
			wp_localize_script( 'makeaholic-swiper-wrapper', '$makeaholicSwiper', $makeaholic_swiper_js );
		}

		/**
		 * Fix Elementor load out-date version 1.0.1
		 */
		public function fix_out_date_smartmenus() {
			wp_register_script( 'smartmenus', MAKEAHOLIC_THEME_URI . '/assets/libs/smartmenus/jquery.smartmenus.min.js', array( 'jquery' ), '1.1.1', true );
		}

		/**
		 * Enqueue scripts & styles for frond-end.
		 *
		 * @access public
		 */
		public function frontend_scripts() {
			$min = $this->get_min_suffix();
			$rtl = $this->get_rtl_suffix();

			/*
			 * Begin register scripts & styles to be enqueued later.
			 */
			/**
			 * We need remove font awesome soon for better performance.
			 * Change all css class font awesome to phosphor
			 */
			wp_register_style( 'font-awesome-pro', MAKEAHOLIC_THEME_URI . '/assets/fonts/awesome/css/fontawesome-all.min.css', null, '5.15.4' );
			wp_register_style( 'font-phosphor', MAKEAHOLIC_THEME_URI . '/assets/fonts/phosphor/css/phosphor.css', null, '1.2.0' );

			wp_register_style( 'justifiedGallery', MAKEAHOLIC_THEME_URI . '/assets/libs/justifiedGallery/css/justifiedGallery.min.css', null, '3.7.0' );
			wp_register_script( 'justifiedGallery', MAKEAHOLIC_THEME_URI . '/assets/libs/justifiedGallery/js/jquery.justifiedGallery.min.js', array( 'jquery' ), '3.7.0', true );

			wp_register_style( 'lightgallery', MAKEAHOLIC_THEME_URI . '/assets/libs/lightGallery/css/lightgallery.min.css', null, '1.6.12' );
			wp_register_script( 'lightgallery', MAKEAHOLIC_THEME_URI . '/assets/libs/lightGallery/js/lightgallery-all.min.js', array(
				'jquery',
			), '1.6.12', true );

			wp_register_style( 'magnific-popup', MAKEAHOLIC_THEME_URI . '/assets/libs/magnific-popup/magnific-popup.css' );
			wp_register_script( 'magnific-popup', MAKEAHOLIC_THEME_URI . '/assets/libs/magnific-popup/jquery.magnific-popup.js', array( 'jquery' ), MAKEAHOLIC_THEME_VERSION, true );

			wp_register_style( 'growl', MAKEAHOLIC_THEME_URI . '/assets/libs/growl/css/jquery.growl.min.css', null, '1.3.3' );
			wp_register_script( 'growl', MAKEAHOLIC_THEME_URI . '/assets/libs/growl/js/jquery.growl.min.js', array( 'jquery' ), '1.3.3', true );

			wp_register_script( 'matchheight', MAKEAHOLIC_THEME_URI . '/assets/libs/matchHeight/jquery.matchHeight-min.js', array( 'jquery' ), MAKEAHOLIC_THEME_VERSION, true );

			wp_register_script( 'smartmenus', MAKEAHOLIC_THEME_URI . '/assets/libs/smartmenus/jquery.smartmenus.min.js', array( 'jquery' ), '1.1.1', true );

			wp_register_script( 'smooth-scroll', MAKEAHOLIC_THEME_URI . '/assets/libs/smooth-scroll-for-web/SmoothScroll.min.js', array(
				'jquery',
			), '1.4.9', true );

			// Fix Wordpress old version not registered this script.
			if ( ! wp_script_is( 'imagesloaded', 'registered' ) ) {
				wp_register_script( 'imagesloaded', MAKEAHOLIC_THEME_URI . '/assets/libs/imagesloaded/imagesloaded.min.js', array( 'jquery' ), null, true );
			}

			$this->register_swiper();

			wp_register_script( 'sticky-kit', MAKEAHOLIC_THEME_URI . '/assets/js/jquery.sticky-kit.min.js', array(
				'jquery',
			), MAKEAHOLIC_THEME_VERSION, true );

			wp_register_script( 'picturefill', MAKEAHOLIC_THEME_URI . '/assets/libs/picturefill/picturefill.min.js', array( 'jquery' ), null, true );

			wp_register_script( 'mousewheel', MAKEAHOLIC_THEME_URI . '/assets/libs/mousewheel/jquery.mousewheel.min.js', array( 'jquery' ), MAKEAHOLIC_THEME_VERSION, true );

			$google_api_key = $this->get_google_api_key();
			if ( ! empty( $google_api_key ) ) {
				wp_register_script( 'makeaholic-gmap3', MAKEAHOLIC_THEME_URI . '/assets/libs/gmap3/gmap3.min.js', array( 'jquery' ), MAKEAHOLIC_THEME_VERSION, true );
				wp_register_script( 'makeaholic-maps', MAKEAHOLIC_PROTOCOL . '://maps.google.com/maps/api/js?key=' . $google_api_key . '&amp;language=en' );
			}

			wp_register_script( 'isotope-masonry', MAKEAHOLIC_THEME_URI . "/assets/js/isotope.pkgd{$min}.js", array( 'jquery' ), MAKEAHOLIC_THEME_VERSION, true );
			wp_register_script( 'isotope-packery', MAKEAHOLIC_THEME_URI . '/assets/libs/packery-mode/packery-mode.pkgd.js', array( 'jquery' ), MAKEAHOLIC_THEME_VERSION, true );

			wp_register_script( 'makeaholic-grid-layout', MAKEAHOLIC_THEME_ASSETS_URI . "/js/grid-layout{$min}.js", array(
				'jquery',
				'imagesloaded',
				'matchheight',
				'isotope-masonry',
				'isotope-packery',
			), null, true );

			wp_register_script( 'makeaholic-common-archive', MAKEAHOLIC_THEME_URI . "/assets/js/common-archive{$min}.js", [
				'jquery',
				'perfect-scrollbar',
			], MAKEAHOLIC_THEME_VERSION, true );

			wp_register_script( 'makeaholic-quantity-button', MAKEAHOLIC_THEME_URI . "/assets/js/woo/quantity-button{$min}.js", [ 'jquery' ], MAKEAHOLIC_THEME_VERSION, true );

			wp_register_script( 'makeaholic-tab-panel', MAKEAHOLIC_THEME_URI . "/assets/js/tab-panel{$min}.js", [ 'jquery' ], MAKEAHOLIC_THEME_VERSION, true );
			wp_register_script( 'makeaholic-accordion', MAKEAHOLIC_THEME_URI . "/assets/js/accordion{$min}.js", [ 'jquery' ], MAKEAHOLIC_THEME_VERSION, true );

			/*
			 * End register scripts
			 */

			wp_enqueue_style( 'font-phosphor' );
			/**
			 * Used only one Font Icon Lib for Better Performance
			 * Convert all icons exits to Phosphor
			 * Except FA-Brands
			 *
			 * @deprecated
			 */
			wp_enqueue_style( 'font-awesome-pro' );
			wp_enqueue_style( 'swiper' );
			wp_enqueue_style( 'lightgallery' );

			/*
			 * Enqueue the theme's style.css.
			 * This is recommended because we can add inline styles there
			 * and some plugins use it to do exactly that.
			 */
			wp_enqueue_style( 'makeaholic-style', get_template_directory_uri() . "/style{$rtl}.css" );

			if ( Makeaholic::setting( 'header_sticky_enable' ) ) {
				wp_enqueue_script( 'headroom', MAKEAHOLIC_THEME_URI . '/assets/js/headroom.min.js', array( 'jquery' ), MAKEAHOLIC_THEME_VERSION, true );
			}

			if ( Makeaholic::setting( 'smooth_scroll_enable' ) ) {
				wp_enqueue_script( 'smooth-scroll' );
			}

			wp_enqueue_script( 'lightgallery' );

			// Use waypoints lib edited by Elementor to avoid duplicate the script.
			if ( ! wp_script_is( 'elementor-waypoints', 'registered' ) ) {
				wp_register_script( 'elementor-waypoints', MAKEAHOLIC_THEME_URI . '/assets/libs/elementor-waypoints/jquery.waypoints.min.js', array( 'jquery' ), null, true );
			}

			wp_enqueue_script( 'elementor-waypoints' );

			wp_enqueue_script( 'jquery-smooth-scroll', MAKEAHOLIC_THEME_URI . '/assets/libs/smooth-scroll/jquery.smooth-scroll.min.js', array( 'jquery' ), MAKEAHOLIC_THEME_VERSION, true );

			wp_enqueue_script( 'makeaholic-swiper-wrapper' );

			wp_enqueue_script( 'makeaholic-grid-layout' );
			wp_enqueue_script( 'smartmenus' );

			wp_enqueue_style( 'perfect-scrollbar', MAKEAHOLIC_THEME_URI . '/assets/libs/perfect-scrollbar/css/perfect-scrollbar.min.css' );
			wp_enqueue_script( 'perfect-scrollbar', MAKEAHOLIC_THEME_URI . '/assets/libs/perfect-scrollbar/js/perfect-scrollbar.jquery.min.js', array( 'jquery' ), MAKEAHOLIC_THEME_VERSION, true );

			wp_enqueue_script( 'growl' );
			wp_enqueue_style( 'growl' );

			/*
			 * The comment-reply script.
			 */
			if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
				$post_type = get_post_type();

				switch ( $post_type ) {
					case 'post':
						if ( Makeaholic::setting( 'single_post_comment_enable' ) === '1' ) {
							wp_enqueue_script( 'comment-reply' );
						}
						break;
					default:
						wp_enqueue_script( 'comment-reply' );
						break;
				}
			}

			wp_enqueue_script( 'makeaholic-nice-select', MAKEAHOLIC_THEME_URI . "/assets/js/nice-select{$min}.js", array(
				'jquery',
			), MAKEAHOLIC_THEME_VERSION, true );

			/*
			 * Enqueue main JS
			 */
			wp_enqueue_script( 'makeaholic-script', MAKEAHOLIC_THEME_URI . "/assets/js/main{$min}.js", array(
				'jquery',
			), MAKEAHOLIC_THEME_VERSION, true );

			/*
			 * Enqueue custom variable JS
			 */
			if ( class_exists( 'WooCommerce' ) ) {
				$notice_cart_url = wc_get_cart_url();
			} else {
				$notice_cart_url = get_home_url( 'cart' );
			}

			$js_variables = array(
				'ajaxurl'                   => admin_url( 'admin-ajax.php' ),
				'nonce'                     => wp_create_nonce( 'makeaholic-security' ),
				'header_sticky_enable'      => Makeaholic::setting( 'header_sticky_enable' ),
				'header_sticky_behaviour'   => Makeaholic::setting( 'header_sticky_behaviour' ),
				'header_sticky_height'      => Makeaholic::setting( 'header_sticky_height' ),
				'scroll_top_enable'         => Makeaholic::setting( 'scroll_top_enable' ),
				'light_gallery_auto_play'   => Makeaholic::setting( 'light_gallery_auto_play' ),
				'light_gallery_download'    => Makeaholic::setting( 'light_gallery_download' ),
				'light_gallery_full_screen' => Makeaholic::setting( 'light_gallery_full_screen' ),
				'light_gallery_zoom'        => Makeaholic::setting( 'light_gallery_zoom' ),
				'light_gallery_thumbnail'   => Makeaholic::setting( 'light_gallery_thumbnail' ),
				'light_gallery_share'       => Makeaholic::setting( 'light_gallery_share' ),
				'mobile_menu_breakpoint'    => Makeaholic::setting( 'mobile_menu_breakpoint' ),
				'isSingle'                  => is_singular(),
				'postType'                  => get_post_type(),
				'productFeatureStyle'       => Makeaholic_Woo::instance()->get_single_product_image_style(),
				'alertTitle'                => esc_html__( 'Notice!', 'makeaholic' ),
				'noticeCookieEnable'        => Makeaholic::setting( 'notice_cookie_enable' ),
				'noticeCookieConfirm'       => isset( $_COOKIE['notice_cookie_confirm'] ) ? 'yes' : 'no',
				'noticeCookieMessages'      => Makeaholic_Notices::instance()->get_notice_cookie_messages(),
				'noticeCartUrl'             => esc_js( $notice_cart_url ),
				'noticeCartText'            => esc_js( esc_html__( 'View Cart', 'makeaholic' ) ),
				'noticeAddedCartText'       => esc_js( esc_html__( 'added to cart!', 'makeaholic' ) ),
			);
			wp_localize_script( 'makeaholic-script', '$makeaholic', $js_variables );

			/**
			 * Custom JS
			 */
			if ( Makeaholic::setting( 'custom_js_enable' ) == 1 ) {
				wp_add_inline_script( 'makeaholic-script', html_entity_decode( Makeaholic::setting( 'custom_js' ) ) );
			}
		}

		public function rtl_styles() {
			$min = $this->get_min_suffix();

			wp_register_style( 'makeaholic-style-rtl-custom', MAKEAHOLIC_THEME_URI . "/style-rtl-custom.css", null, MAKEAHOLIC_THEME_VERSION );

			if ( is_rtl() ) {
				wp_enqueue_style( 'makeaholic-style-rtl-custom' );
			}
		}

		public function get_google_api_key() {
			if ( defined( 'MAKEAHOLIC_GOOGLE_MAP_API_KEY' ) && ! empty( MAKEAHOLIC_GOOGLE_MAP_API_KEY ) ) {
				return MAKEAHOLIC_GOOGLE_MAP_API_KEY;
			}

			$google_api_key = Makeaholic::setting( 'google_api_key' );

			if ( ! empty( $google_api_key ) ) {
				return $google_api_key;
			}

			return false;
		}

		/**
		 * @return string
		 */
		public function get_min_suffix() {
			$min = '.min';

			if ( defined( 'SCRIPT_DEBUG' ) && true === SCRIPT_DEBUG ) {
				$min = '';
			}

			return $min;
		}

		public function get_rtl_suffix() {
			return is_rtl() ? '-rtl' : '';
		}
	}

	Makeaholic_Enqueue::instance()->initialize();
}
