<?php
defined( 'ABSPATH' ) || exit;

if ( ! class_exists( 'Makeaholic_Header' ) ) {

	class Makeaholic_Header {

		protected static $instance = null;

		public static function instance() {
			if ( null === self::$instance ) {
				self::$instance = new self();
			}

			return self::$instance;
		}

		public function initialize() {

		}

		/**
		 * @return array List header types include id & name.
		 */
		public function get_type() {
			return array(
				'01' => esc_html__( 'Center Logo', 'makeaholic' ),
				'02' => esc_html__( 'Center Nav - Wide', 'makeaholic' ),
				'03' => esc_html__( 'Below Nav - Colored', 'makeaholic' ),
				//'04' => esc_html__( 'Left Nav', 'makeaholic' ),
				'05' => esc_html__( 'Minimal', 'makeaholic' ),
				'06' => esc_html__( 'Center Nav - Include Off Siderbar', 'makeaholic' ),
				'07' => esc_html__( 'Transparent', 'makeaholic' ),
				'08' => esc_html__( 'Center Nav', 'makeaholic' ),
				'09' => esc_html__( 'Center Logo - Wide', 'makeaholic' ),
				'10' => esc_html__( 'Center Logo - Wide 02', 'makeaholic' ),
				'11' => esc_html__( 'Split - Logo Center Inside Menu', 'makeaholic' ),
			);
		}

		/**
		 * @param bool   $default_option Show or hide default select option.
		 * @param string $default_text   Custom text for default option.
		 *
		 * @return array A list of options for select field.
		 */
		public function get_list( $default_option = false, $default_text = '' ) {
			$headers = array(
				'none' => esc_html__( 'Hide', 'makeaholic' ),
			);

			$headers += $this->get_type();

			if ( $default_option === true ) {
				if ( $default_text === '' ) {
					$default_text = esc_html__( 'Default', 'makeaholic' );
				}

				$headers = array( '' => $default_text ) + $headers;
			}

			return $headers;
		}

		/**
		 * Get list of button style option for customizer.
		 *
		 * @return array
		 */
		public function get_button_style() {
			return array(
				'flat'         => esc_attr__( 'Flat', 'makeaholic' ),
				'border'       => esc_attr__( 'Border', 'makeaholic' ),
				'thick-border' => esc_attr__( 'Thick Border', 'makeaholic' ),
			);
		}

		public function get_button_kirki_output( $header_style, $header_skin, $hover = false ) {
			$prefix_selector = ".header-{$header_style}.header-{$header_skin} ";

			if ( $hover ) {
				$button_selector    = $prefix_selector . ".header-button:hover";
				$button_bg_selector = $prefix_selector . ".header-button:after";
			} else {
				$button_selector    = $prefix_selector . ".header-button";
				$button_bg_selector = $prefix_selector . ".header-button:before";
			}

			return array(
				array(
					'choice'   => 'color',
					'property' => 'color',
					'element'  => $button_selector,
				),
				array(
					'choice'   => 'border',
					'property' => 'border-color',
					'element'  => $button_selector,
				),
				array(
					'choice'   => 'background',
					'property' => 'background',
					'element'  => $button_bg_selector,
				),
			);
		}

		public function get_search_form_kirki_output( $header_style, $header_skin, $hover = false, $imporant = false ) {
			$prefix_selector = ".header-{$header_style}.header-{$header_skin} ";

			if ( $hover ) {
				$form_selector = $prefix_selector . '.search-field:focus';
			} else {
				$form_selector = $prefix_selector . '.search-field';
			}

			$default_args = [
				'element' => $form_selector,
			];

			if ( ! empty( $imporant ) ) {
				$default_args['suffix'] = '!important';
			}

			return array(
				array_merge( [
					'choice'   => 'color',
					'property' => 'color',
				], $default_args ),
				array_merge( [
					'choice'   => 'border',
					'property' => 'border-color',
				], $default_args ),
				array_merge( [
					'choice'   => 'background',
					'property' => 'background',
				], $default_args ),
			);
		}

		/**
		 * Add classes to the header.
		 *
		 * @var string $class Custom class.
		 */
		public function get_wrapper_class( $class = '' ) {
			$classes = array( 'page-header' );

			$header_type    = Makeaholic_Global::instance()->get_header_type();
			$header_overlay = Makeaholic_Global::instance()->get_header_overlay();
			$header_skin    = Makeaholic_Global::instance()->get_header_skin();

			$classes[] = "header-{$header_type}";

			if ( $header_overlay === '1' ) {
				$classes[] = 'header-layout-fixed';
			}

			$nav_bottom_line_style = Makeaholic::setting( "header_style_{$header_type}_navigation_item_line_style" );

			if ( $nav_bottom_line_style === 'wave' ) {
				$classes[] = ' nav-links-hover-style-02';
			} else {
				$classes[] = ' nav-links-hover-style-01';
			}

			$classes[] = "header-{$header_skin}";

			$_sticky_logo = Makeaholic::setting( "header_sticky_logo" );
			$classes[]    = " header-sticky-$_sticky_logo-logo";

			if ( ! empty( $class ) ) {
				if ( ! is_array( $class ) ) {
					$class = preg_split( '#\s+#', $class );
				}
				$classes = array_merge( $classes, $class );
			} else {
				// Ensure that we always coerce class to being an array.
				$class = array();
			}

			$classes = apply_filters( 'makeaholic/header/class', $classes, $class );

			echo 'class="' . esc_attr( join( ' ', $classes ) ) . '"';
		}

		/**
		 * Print WPML switcher html template.
		 *
		 * @var string $class Custom class.
		 */
		public function print_language_switcher() {
			$header_type = Makeaholic_Global::instance()->get_header_type();
			$enabled     = Makeaholic::setting( "header_style_{$header_type}_language_switcher_enable" );

			do_action( 'makeaholic_before_add_language_selector_header', $header_type, $enabled );

			if ( $enabled !== '1' || ! defined( 'ICL_SITEPRESS_VERSION' ) ) {
				return;
			}
			?>
			<div id="switcher-language-wrapper" class="switcher-language-wrapper">
				<?php do_action( 'wpml_add_language_selector' ); ?>
			</div>
			<?php
		}

		public function print_social_networks( $args = array() ) {
			$header_type   = Makeaholic_Global::instance()->get_header_type();
			$social_enable = Makeaholic::setting( "header_style_{$header_type}_social_networks_enable" );

			if ( '1' !== $social_enable ) {
				return;
			}

			$defaults = array(
				'style' => 'icons',
			);

			$args       = wp_parse_args( $args, $defaults );
			$el_classes = 'header-social-networks';

			if ( ! empty( $args['style'] ) ) {
				$el_classes .= " style-{$args['style']}";
			}
			?>
			<div class="<?php echo esc_attr( $el_classes ); ?>">
				<div class="inner">
					<?php
					$defaults = array(
						'tooltip_position' => 'bottom-left',
					);

					if ( 'light' === Makeaholic_Global::instance()->get_header_skin() ) {
						$defaults['tooltip_skin'] = 'white';
					}

					$args = wp_parse_args( $args, $defaults );

					Makeaholic_Templates::social_icons( $args );
					?>
				</div>
			</div>
			<?php
		}

		public function print_widgets() {
			$header_type = Makeaholic_Global::instance()->get_header_type();

			$enabled = Makeaholic::setting( "header_style_{$header_type}_widgets_enable" );
			if ( '1' === $enabled ) {
				?>
				<div class="header-widgets">
					<?php Makeaholic_Sidebar::instance()->generated_sidebar( 'header_widgets' ); ?>
				</div>
				<?php
			}
		}

		public function print_search() {
			$header_type = Makeaholic_Global::instance()->get_header_type();
			$search_type = Makeaholic::setting( "header_style_{$header_type}_search_enable" );

			if ( 'inline' === $search_type ) {
				makeaholic_load_template( 'header/components/search-form' );
			} elseif ( 'popup' === $search_type ) {
				makeaholic_load_template( 'header/components/search-popup' );
			}
		}

		public function print_login_button( $args = array() ) {
			$header_type  = Makeaholic_Global::instance()->get_header_type();
			$login_enable = Makeaholic::setting( "header_style_{$header_type}_login_enable" );

			// Do nothing if user option disabled.
			if ( '1' !== $login_enable ) {
				return;
			}

			$defaults = [
				'style' => 'icon',
			];

			$args = wp_parse_args( $args, $defaults );

			makeaholic_load_template( 'header/components/login-button', null, $args );
		}

		function print_mini_cart() {
			$header_type = Makeaholic_Global::instance()->get_header_type();
			$enabled     = Makeaholic::setting( "header_style_{$header_type}_cart_enable" );

			$args = [
				'enabled' => $enabled,
			];

			if ( Makeaholic_Woo::instance()->is_activated() && in_array( $enabled, array( '1', 'hide_on_empty' ) ) ) {
				makeaholic_load_template( 'header/components/mini-cart-button', null, $args );
			}
		}

		public function print_wishlist_button() {
			$header_type     = Makeaholic_Global::instance()->get_header_type();
			$wishlist_enable = Makeaholic::setting( "header_style_{$header_type}_wishlist_enable" );

			if ( '1' !== $wishlist_enable || ! class_exists( 'WPCleverWoosw' ) ) {
				return;
			}

			makeaholic_load_template( 'header/components/wishlist-button' );
		}

		public function print_button( $args = array() ) {
			$header_type = Makeaholic_Global::instance()->get_header_type();

			$button_style        = Makeaholic::setting( "header_style_{$header_type}_button_style" );
			$button_text         = Makeaholic::setting( "header_style_{$header_type}_button_text" );
			$button_link         = Makeaholic::setting( "header_style_{$header_type}_button_link" );
			$button_link_target  = Makeaholic::setting( "header_style_{$header_type}_button_link_target" );
			$button_link_rel     = Makeaholic::setting( "header_style_{$header_type}_button_link_rel" );
			$button_classes      = 'tm-button';
			$sticky_button_style = Makeaholic::setting( "header_sticky_button_style" );

			$icon_class = Makeaholic::setting( "header_style_{$header_type}_button_icon" );
			$icon_align = 'right';

			if ( $icon_class !== '' ) {
				$button_classes .= ' has-icon icon-right';
			}

			$defaults = array(
				'extra_class' => '',
				'style'       => '',
				'size'        => 'nm',
			);

			$args = wp_parse_args( $args, $defaults );

			if ( $args['extra_class'] !== '' ) {
				$button_classes .= " {$args['extra_class']}";
			}

			$header_button_classes = $button_classes . " tm-button-{$args['size']} header-button";
			$sticky_button_classes = $button_classes . ' tm-button-xs header-sticky-button';

			$header_button_classes .= " style-{$button_style}";
			$sticky_button_classes .= " style-{$sticky_button_style}";
			?>
			<?php if ( $button_link !== '' && $button_text !== '' ) : ?>

				<?php ob_start(); ?>

				<?php if ( $icon_class !== '' && $icon_align === 'right' ) { ?>
					<span class="button-icon">
						<i class="<?php echo esc_attr( $icon_class ); ?>"></i>
					</span>
				<?php } ?>

				<span class="button-text">
					<?php echo esc_html( $button_text ); ?>
				</span>

				<?php if ( $icon_class !== '' && $icon_align === 'right' ) { ?>
					<span class="button-icon">
						<i class="<?php echo esc_attr( $icon_class ); ?>"></i>
					</span>
				<?php } ?>

				<?php $button_content_html = ob_get_clean(); ?>

				<div class="header-buttons">
					<a class="<?php echo esc_attr( $header_button_classes ); ?>"
					   href="<?php echo esc_url( $button_link ); ?>"

						<?php if ( '1' === $button_link_target ) : ?>
							target="_blank"
						<?php endif; ?>

						<?php if ( ! empty ( $button_link_rel ) ) : ?>
							rel="<?php echo esc_attr( $button_link_rel ); ?>"
						<?php endif; ?>
					>
						<?php echo '' . $button_content_html; ?>
					</a>
					<a class="<?php echo esc_attr( $sticky_button_classes ); ?>"
					   href="<?php echo esc_url( $button_link ); ?>"

						<?php if ( '1' === $button_link_target ) : ?>
							target="_blank"
						<?php endif; ?>

						<?php if ( ! empty ( $button_link_rel ) ) : ?>
							rel="<?php echo esc_attr( $button_link_rel ); ?>"
						<?php endif; ?>
					>
						<?php echo '' . $button_content_html; ?>
					</a>
				</div>
			<?php endif;
		}

		public function print_open_mobile_menu_button( $args = array() ) {
			$defaults = [
				'style'     => '01',
				'direction' => 'left',
				'animation' => Makeaholic::setting( 'mobile_menu_open_animation' ),
			];

			$args = wp_parse_args( $args, $defaults );

			makeaholic_load_template( 'header/components/mobile-menu-button', null, $args );
		}

		public function print_open_off_sidebar() {
			$header_type = Makeaholic_Global::instance()->get_header_type();
			$enable      = Makeaholic::setting( "header_style_{$header_type}_off_sidebar_enable" );

			if ( '1' !== $enable ) {
				return;
			}

			makeaholic_load_template( 'header/components/off-sidebar-toggle' );
		}

		public function print_more_tools_button() {
			makeaholic_load_template( 'header/components/more-tools-toggle' );
		}

		public function print_open_canvas_menu_button( $args = array() ) {
			$defaults = array(
				'extra_class' => '',
				'style'       => '01',
			);
			$args     = wp_parse_args( $args, $defaults );

			makeaholic_load_template( 'header/components/canvas-menu-button', null, $args );
		}

		public function print_category_dropdown( $args = array() ) {
			if ( ! has_nav_menu( 'category-dropdown' ) ) {
				return;
			}

			$menu_class = 'product-category-dropdown menu__container sm sm-simple sm-vertical';

			if ( MAKEAHOLIC_IS_RTL ) {
				$menu_class .= ' sm-rtl';
			}

			$defaults = array(
				'theme_location' => 'category-dropdown',
				'container'      => 'ul',
				'menu_class'     => $menu_class,
				'extra_class'    => '',
			);

			$args = wp_parse_args( $args, $defaults );

			if ( ! empty( $args['extra_class'] ) ) {
				$args['menu_class'] .= ' ' . $args['extra_class'];
			}

			if ( has_nav_menu( 'category-dropdown' ) && class_exists( 'Makeaholic_Walker_Nav_Menu' ) ) {
				$args['walker'] = new Makeaholic_Walker_Nav_Menu;
			}

			$toggle_text = esc_html__( 'Browse Categories', 'makeaholic' );
			?>
			<div class="header-categories-nav">
				<a href="#" class="nav-toggle-btn" id="nav-toggle-btn">
					<span class="nav-toggle-bars far fa-bars"></span>
					<?php echo esc_html( $toggle_text ); ?>
					<span class="nav-toggle-icon"></span>
				</a>
				<nav class="category-menu">
					<?php wp_nav_menu( $args ); ?>
				</nav>
			</div>

			<?php
		}

		public function print_phone_number() {
			$header_type       = Makeaholic_Global::instance()->get_header_type();
			$phone_number_text = Makeaholic::setting( "header_style_{$header_type}_phone_number_text" );
			$phone_number_link = Makeaholic::setting( "header_style_{$header_type}_phone_number_link" );
			?>
			<?php if ( ! empty( $phone_number_text ) && ! empty( $phone_number_link ) ): ?>
				<div class="header-phone-number">
					<span class="icon fas fa-phone"></span>
					<span class="label"><?php esc_html_e( 'Hotline:', 'makeaholic' ); ?></span>
					<a href="<?php echo esc_url( $phone_number_link ); ?>"
					   class="text"><?php echo esc_html( $phone_number_text ); ?></a>
				</div>
			<?php endif; ?>

			<?php
		}
	}

	Makeaholic_Header::instance()->initialize();
}
