<?php
defined( 'ABSPATH' ) || exit;

if ( ! class_exists( 'Makeaholic_Metabox' ) ) {
	class Makeaholic_Metabox {

		protected static $instance = null;

		public static function instance() {
			if ( null === self::$instance ) {
				self::$instance = new self();
			}

			return self::$instance;
		}

		public function initialize() {
			add_filter( 'insight_core_meta_boxes', array( $this, 'register_meta_boxes' ) );
		}

		/**
		 * Register Metabox
		 *
		 * @param $meta_boxes
		 *
		 * @return array
		 */
		public function register_meta_boxes( $meta_boxes ) {
			$page_registered_sidebars = Makeaholic_Helper::get_registered_sidebars( true );

			$general_options = array(
				array(
					'title'  => esc_attr__( 'Layout', 'makeaholic' ),
					'fields' => array(
						array(
							'id'      => 'site_layout',
							'type'    => 'select',
							'title'   => esc_html__( 'Layout', 'makeaholic' ),
							'desc'    => esc_html__( 'Controls the layout of this page.', 'makeaholic' ),
							'options' => array(
								''      => esc_attr__( 'Default', 'makeaholic' ),
								'boxed' => esc_attr__( 'Boxed', 'makeaholic' ),
								'wide'  => esc_attr__( 'Wide', 'makeaholic' ),
							),
							'default' => '',
						),
						array(
							'id'    => 'site_width',
							'type'  => 'text',
							'title' => esc_html__( 'Site Width', 'makeaholic' ),
							'desc'  => esc_html__( 'Controls the site width for this page. Enter value including any valid CSS unit. For e.g: 1200px. Leave blank to use global setting.', 'makeaholic' ),
						),
						array(
							'id'    => 'site_top_spacing',
							'type'  => 'text',
							'title' => esc_html__( 'Site Top Spacing', 'makeaholic' ),
							'desc'  => esc_html__( 'Controls the top spacing of this page. Enter value including any valid CSS unit. For e.g: 50px. Leave blank to use global setting.', 'makeaholic' ),
						),
						array(
							'id'    => 'site_bottom_spacing',
							'type'  => 'text',
							'title' => esc_html__( 'Site Bottom Spacing', 'makeaholic' ),
							'desc'  => esc_html__( 'Controls the bottom spacing of this page. Enter value including any valid CSS unit. For e.g: 50px. Leave blank to use global setting.', 'makeaholic' ),
						),
						array(
							'id'    => 'site_class',
							'type'  => 'text',
							'title' => esc_html__( 'Body Class', 'makeaholic' ),
							'desc'  => esc_html__( 'Add a class name to body then refer to it in custom CSS.', 'makeaholic' ),
						),
					),
				),
				array(
					'title'  => esc_attr__( 'Background', 'makeaholic' ),
					'fields' => array(
						array(
							'id'      => 'site_background_message',
							'type'    => 'message',
							'title'   => esc_html__( 'Info', 'makeaholic' ),
							'message' => esc_html__( 'These options controls the background on boxed mode.', 'makeaholic' ),
						),
						array(
							'id'    => 'site_background_color',
							'type'  => 'color',
							'title' => esc_html__( 'Background Color', 'makeaholic' ),
							'desc'  => esc_html__( 'Controls the background color of the outer background area in boxed mode of this page.', 'makeaholic' ),
						),
						array(
							'id'    => 'site_background_image',
							'type'  => 'media',
							'title' => esc_html__( 'Background Image', 'makeaholic' ),
							'desc'  => esc_html__( 'Controls the background image of the outer background area in boxed mode of this page.', 'makeaholic' ),
						),
						array(
							'id'      => 'site_background_repeat',
							'type'    => 'select',
							'title'   => esc_html__( 'Background Repeat', 'makeaholic' ),
							'desc'    => esc_html__( 'Controls the background repeat of the outer background area in boxed mode of this page.', 'makeaholic' ),
							'options' => array(
								'no-repeat' => esc_attr__( 'No repeat', 'makeaholic' ),
								'repeat'    => esc_attr__( 'Repeat', 'makeaholic' ),
								'repeat-x'  => esc_attr__( 'Repeat X', 'makeaholic' ),
								'repeat-y'  => esc_attr__( 'Repeat Y', 'makeaholic' ),
							),
						),
						array(
							'id'      => 'site_background_attachment',
							'type'    => 'select',
							'title'   => esc_html__( 'Background Attachment', 'makeaholic' ),
							'desc'    => esc_html__( 'Controls the background attachment of the outer background area in boxed mode of this page.', 'makeaholic' ),
							'options' => array(
								''       => esc_attr__( 'Default', 'makeaholic' ),
								'fixed'  => esc_attr__( 'Fixed', 'makeaholic' ),
								'scroll' => esc_attr__( 'Scroll', 'makeaholic' ),
							),
						),
						array(
							'id'    => 'site_background_position',
							'type'  => 'text',
							'title' => esc_html__( 'Background Position', 'makeaholic' ),
							'desc'  => esc_html__( 'Controls the background position of the outer background area in boxed mode of this page.', 'makeaholic' ),
						),
						array(
							'id'    => 'site_background_size',
							'type'  => 'text',
							'title' => esc_html__( 'Background Size', 'makeaholic' ),
							'desc'  => esc_html__( 'Controls the background size of the outer background area in boxed mode of this page.', 'makeaholic' ),
						),
						array(
							'id'      => 'content_background_message',
							'type'    => 'message',
							'title'   => esc_html__( 'Info', 'makeaholic' ),
							'message' => esc_html__( 'These options controls the background of main content on this page.', 'makeaholic' ),
						),
						array(
							'id'    => 'content_background_color',
							'type'  => 'color',
							'title' => esc_html__( 'Background Color', 'makeaholic' ),
							'desc'  => esc_html__( 'Controls the background color of main content on this page.', 'makeaholic' ),
						),
						array(
							'id'    => 'content_background_image',
							'type'  => 'media',
							'title' => esc_html__( 'Background Image', 'makeaholic' ),
							'desc'  => esc_html__( 'Controls the background image of main content on this page.', 'makeaholic' ),
						),
						array(
							'id'      => 'content_background_repeat',
							'type'    => 'select',
							'title'   => esc_html__( 'Background Repeat', 'makeaholic' ),
							'desc'    => esc_html__( 'Controls the background repeat of main content on this page.', 'makeaholic' ),
							'options' => array(
								'no-repeat' => esc_attr__( 'No repeat', 'makeaholic' ),
								'repeat'    => esc_attr__( 'Repeat', 'makeaholic' ),
								'repeat-x'  => esc_attr__( 'Repeat X', 'makeaholic' ),
								'repeat-y'  => esc_attr__( 'Repeat Y', 'makeaholic' ),
							),
						),
						array(
							'id'    => 'content_background_position',
							'type'  => 'text',
							'title' => esc_html__( 'Background Position', 'makeaholic' ),
							'desc'  => esc_html__( 'Controls the background position of main content on this page.', 'makeaholic' ),
						),
					),
				),
				array(
					'title'  => esc_html__( 'Header', 'makeaholic' ),
					'fields' => array(
						array(
							'id'      => 'top_bar_type',
							'type'    => 'select',
							'title'   => esc_html__( 'Top Bar Type', 'makeaholic' ),
							'desc'    => esc_html__( 'Select top bar type that displays on this page.', 'makeaholic' ),
							'default' => '',
							'options' => Makeaholic_Top_Bar::instance()->get_list( true ),
						),
						array(
							'id'      => 'header_type',
							'type'    => 'select',
							'title'   => esc_attr__( 'Header Type', 'makeaholic' ),
							'desc'    => wp_kses(
								sprintf(
									__( 'Select header type that displays on this page. When you choose Default, the value in %s will be used.', 'makeaholic' ),
									'<a href="' . admin_url( '/customize.php?autofocus[section]=header' ) . '">Customize</a>'
								), 'makeaholic-a' ),
							'default' => '',
							'options' => Makeaholic_Header::instance()->get_list( true ),
						),
						array(
							'id'      => 'header_overlay',
							'type'    => 'select',
							'title'   => esc_attr__( 'Header Overlay', 'makeaholic' ),
							'default' => '',
							'options' => array(
								''  => esc_html__( 'Default', 'makeaholic' ),
								'0' => esc_html__( 'No', 'makeaholic' ),
								'1' => esc_html__( 'Yes', 'makeaholic' ),
							),
						),
						array(
							'id'      => 'header_skin',
							'type'    => 'select',
							'title'   => esc_attr__( 'Header Skin', 'makeaholic' ),
							'default' => '',
							'options' => array(
								''      => esc_html__( 'Default', 'makeaholic' ),
								'dark'  => esc_html__( 'Dark', 'makeaholic' ),
								'light' => esc_html__( 'Light', 'makeaholic' ),
							),
						),
						array(
							'id'      => 'menu_display',
							'type'    => 'select',
							'title'   => esc_html__( 'Primary menu', 'makeaholic' ),
							'desc'    => esc_html__( 'Select which menu displays on this page.', 'makeaholic' ),
							'default' => '',
							'options' => Makeaholic_Nav_Menu::get_all_menus(),
						),
						array(
							'id'      => 'menu_one_page',
							'type'    => 'switch',
							'title'   => esc_attr__( 'One Page Menu', 'makeaholic' ),
							'default' => '0',
							'options' => array(
								'0' => esc_attr__( 'Disable', 'makeaholic' ),
								'1' => esc_attr__( 'Enable', 'makeaholic' ),
							),
						),
						array(
							'id'      => 'custom_dark_logo',
							'type'    => 'media',
							'title'   => esc_html__( 'Custom Dark Logo', 'makeaholic' ),
							'desc'    => esc_html__( 'Select custom dark logo for this page.', 'makeaholic' ),
							'default' => '',
						),
						array(
							'id'      => 'custom_light_logo',
							'type'    => 'media',
							'title'   => esc_html__( 'Custom Light Logo', 'makeaholic' ),
							'desc'    => esc_html__( 'Select custom light logo for this page.', 'makeaholic' ),
							'default' => '',
						),
						array(
							'id'      => 'custom_logo_width',
							'type'    => 'text',
							'title'   => esc_html__( 'Custom Logo Width', 'makeaholic' ),
							'desc'    => esc_html__( 'Controls the width of logo. For e.g: 150px', 'makeaholic' ),
							'default' => '',
						),
						array(
							'id'      => 'custom_sticky_logo_width',
							'type'    => 'text',
							'title'   => esc_html__( 'Custom Sticky Logo Width', 'makeaholic' ),
							'desc'    => esc_html__( 'Controls the width of sticky logo. For e.g: 150px', 'makeaholic' ),
							'default' => '',
						),
					),
				),
				array(
					'title'  => esc_html__( 'Page Title Bar', 'makeaholic' ),
					'fields' => array(
						array(
							'id'      => 'page_title_bar_layout',
							'type'    => 'select',
							'title'   => esc_html__( 'Layout', 'makeaholic' ),
							'default' => '',
							'options' => Makeaholic_Title_Bar::instance()->get_list( true ),
						),
						array(
							'id'    => 'page_title_bar_bottom_spacing',
							'type'  => 'text',
							'title' => esc_html__( 'Spacing', 'makeaholic' ),
							'desc'  => esc_html__( 'Controls the bottom spacing of title bar of this page. Enter value including any valid CSS unit. For e.g: 50px. Leave blank to use global setting.', 'makeaholic' ),
						),
						array(
							'id'      => 'page_title_bar_background_color',
							'type'    => 'color',
							'title'   => esc_html__( 'Background Color', 'makeaholic' ),
							'default' => '',
						),
						array(
							'id'      => 'page_title_bar_background',
							'type'    => 'media',
							'title'   => esc_html__( 'Background Image', 'makeaholic' ),
							'default' => '',
						),
						array(
							'id'      => 'page_title_bar_background_overlay',
							'type'    => 'color',
							'title'   => esc_html__( 'Background Overlay', 'makeaholic' ),
							'default' => '',
						),
						array(
							'id'    => 'page_title_bar_custom_heading',
							'type'  => 'text',
							'title' => esc_html__( 'Custom Heading Text', 'makeaholic' ),
							'desc'  => esc_html__( 'Insert custom heading for the page title bar. Leave blank to use default.', 'makeaholic' ),
						),
					),
				),
				array(
					'title'  => esc_html__( 'Sidebars', 'makeaholic' ),
					'fields' => array(
						array(
							'id'      => 'page_sidebar_1',
							'type'    => 'select',
							'title'   => esc_html__( 'Sidebar 1', 'makeaholic' ),
							'desc'    => esc_html__( 'Select sidebar 1 that will display on this page.', 'makeaholic' ),
							'default' => 'default',
							'options' => $page_registered_sidebars,
						),
						array(
							'id'      => 'page_sidebar_2',
							'type'    => 'select',
							'title'   => esc_html__( 'Sidebar 2', 'makeaholic' ),
							'desc'    => esc_html__( 'Select sidebar 2 that will display on this page.', 'makeaholic' ),
							'default' => 'default',
							'options' => $page_registered_sidebars,
						),
						array(
							'id'      => 'page_sidebar_position',
							'type'    => 'switch',
							'title'   => esc_html__( 'Sidebar Position', 'makeaholic' ),
							'desc'    => wp_kses(
								sprintf(
									__( 'Select position of Sidebar 1 for this page. If sidebar 2 is selected, it will display on the opposite side. If you set as "Default" then the value in %s will be used.', 'makeaholic' ),
									'<a href="' . admin_url( '/customize.php?autofocus[section]=sidebars' ) . '">Customize -> Sidebar</a>'
								), 'makeaholic-a' ),
							'default' => 'default',
							'options' => Makeaholic_Helper::get_list_sidebar_positions( true ),
						),
					),
				),
				array(
					'title'  => esc_html__( 'Sliders', 'makeaholic' ),
					'fields' => array(
						array(
							'id'      => 'revolution_slider',
							'type'    => 'select',
							'title'   => esc_html__( 'Revolution Slider', 'makeaholic' ),
							'desc'    => esc_html__( 'Select the unique name of the slider.', 'makeaholic' ),
							'options' => Makeaholic_Helper::get_list_revslider(),
						),
						array(
							'id'      => 'slider_position',
							'type'    => 'select',
							'title'   => esc_html__( 'Slider Position', 'makeaholic' ),
							'default' => 'below',
							'options' => array(
								'above' => esc_attr__( 'Above Header', 'makeaholic' ),
								'below' => esc_attr__( 'Below Header', 'makeaholic' ),
							),
						),
					),
				),
				array(
					'title'  => esc_html__( 'Footer', 'makeaholic' ),
					'fields' => array(
						array(
							'id'      => 'footer_enable',
							'type'    => 'select',
							'title'   => esc_html__( 'Footer Enable', 'makeaholic' ),
							'default' => '',
							'options' => array(
								''     => esc_html__( 'Yes', 'makeaholic' ),
								'none' => esc_html__( 'No', 'makeaholic' ),
							),
						),
					),
				),
			);

			// Page
			$meta_boxes[] = array(
				'id'         => 'insight_page_options',
				'title'      => esc_html__( 'Page Options', 'makeaholic' ),
				'post_types' => array( 'page' ),
				'context'    => 'normal',
				'priority'   => 'high',
				'fields'     => array(
					array(
						'type'  => 'tabpanel',
						'items' => $general_options,
					),
				),
			);

			// Post
			$meta_boxes[] = array(
				'id'         => 'insight_post_options',
				'title'      => esc_html__( 'Page Options', 'makeaholic' ),
				'post_types' => array( 'post' ),
				'context'    => 'normal',
				'priority'   => 'high',
				'fields'     => array(
					array(
						'type'  => 'tabpanel',
						'items' => array_merge( array(
							array(
								'title'  => esc_html__( 'Post', 'makeaholic' ),
								'fields' => array(
									array(
										'id'    => 'post_gallery',
										'type'  => 'gallery',
										'title' => esc_html__( 'Gallery Format', 'makeaholic' ),
									),
									array(
										'id'    => 'post_video',
										'type'  => 'text',
										'title' => esc_html__( 'Video URL', 'makeaholic' ),
										'desc'  => esc_html__( 'Input the url of video vimeo or youtube. For e.g: https://www.youtube.com/watch?v=9No-FiEInLA', 'makeaholic' ),
									),
									array(
										'id'    => 'post_audio',
										'type'  => 'textarea',
										'title' => esc_html__( 'Audio Format', 'makeaholic' ),
									),
									array(
										'id'    => 'post_quote_text',
										'type'  => 'text',
										'title' => esc_html__( 'Quote Format - Source Text', 'makeaholic' ),
									),
									array(
										'id'    => 'post_quote_name',
										'type'  => 'text',
										'title' => esc_html__( 'Quote Format - Source Name', 'makeaholic' ),
									),
									array(
										'id'    => 'post_quote_url',
										'type'  => 'text',
										'title' => esc_html__( 'Quote Format - Source Url', 'makeaholic' ),
									),
									array(
										'id'    => 'post_link',
										'type'  => 'text',
										'title' => esc_html__( 'Link Format', 'makeaholic' ),
									),
								),
							),
						), $general_options ),
					),
				),
			);

			// Product
			$meta_boxes[] = array(
				'id'         => 'insight_product_options',
				'title'      => esc_html__( 'Page Options', 'makeaholic' ),
				'post_types' => array( 'product' ),
				'context'    => 'normal',
				'priority'   => 'high',
				'fields'     => array(
					array(
						'type'  => 'tabpanel',
						'items' => array_merge( array(
							array(
								'title'  => esc_html__( 'Product', 'makeaholic' ),
								'fields' => array(
									array(
										'id'      => 'single_product_image_style',
										'type'    => 'select',
										'title'   => esc_html__( 'Single Product Style', 'makeaholic' ),
										'desc'    => esc_html__( 'Select style of this single product page.', 'makeaholic' ),
										'default' => '',
										'options' => array(
											''       => esc_html__( 'Default', 'makeaholic' ),
											'slider' => esc_html__( 'Slider', 'makeaholic' ),
											'grid'   => esc_html__( 'Grid', 'makeaholic' ),
											'list'   => esc_html__( 'List', 'makeaholic' ),
										),
									),
								),
							),
						), $general_options ),
					),
				),
			);

			return $meta_boxes;
		}

	}

	Makeaholic_Metabox::instance()->initialize();
}
