<?php
defined( 'ABSPATH' ) || exit;

if ( ! class_exists( 'Makeaholic_Post' ) ) {
	class Makeaholic_Post extends Makeaholic_Post_Type {

		protected static $instance  = null;
		protected static $post_type = 'post';

		public static function instance() {
			if ( null === self::$instance ) {
				self::$instance = new self();
			}

			return self::$instance;
		}

		function initialize() {
			add_action( 'wp_ajax_post_infinite_load', array( $this, 'infinite_load' ) );
			add_action( 'wp_ajax_nopriv_post_infinite_load', array( $this, 'infinite_load' ) );

			add_filter( 'body_class', [ $this, 'body_class' ] );

			add_filter( 'post_class', array( $this, 'post_class' ) );

			add_filter( 'makeaholic/page_sidebar/class', [ $this, 'set_sidebar_class' ] );
			add_filter( 'makeaholic/page_sidebar/single_width', [ $this, 'set_single_sidebar_width' ] );
			add_filter( 'makeaholic/page_sidebar/single_offset', [ $this, 'set_single_sidebar_offset' ] );

			add_action( 'pre_get_posts', [ $this, 'change_post_query' ], 999 );
		}

		public function get_post_type() {
			return 'post';
		}

		/**
		 * Check if current page is category or tag pages
		 */
		function is_taxonomy() {
			return is_category() || is_tag();
		}

		public function is_archive() {
			return $this->is_taxonomy() || is_home() || is_author() || is_date() || is_post_type_archive( $this->get_post_type() );
		}

		public function set_single_sidebar_width( $width ) {
			if ( $this->is_archive() ) {
				$new_width = Makeaholic::setting( 'blog_archive_single_sidebar_width' );

				if ( '' !== $new_width ) {
					return $new_width;
				}
			}

			return $width;
		}

		public function set_single_sidebar_offset( $offset ) {
			if ( $this->is_archive() ) {
				$new_offset = Makeaholic::setting( 'blog_archive_single_sidebar_offset' );

				if ( '' !== $new_offset ) {
					return $new_offset;
				}
			}

			return $offset;
		}

		public function set_sidebar_class( $class ) {
			if ( $this->is_archive() ) {
				$sidebar_style = Makeaholic::setting( 'blog_archive_page_sidebar_style' );

				if ( ! empty( $sidebar_style ) ) {
					$class[] = 'style-' . $sidebar_style;
				}
			}

			return $class;
		}

		/**
		 * Adds custom classes to the array of body classes.
		 *
		 * @param array $classes Classes for the body element.
		 *
		 * @return array
		 */
		public function body_class( $classes ) {
			if ( $this->is_archive() ) {
				$blog_archive_style = Makeaholic::setting( 'blog_archive_style' );
				$classes[]          = "blog-archive-style-{$blog_archive_style}";

				$site_layout = Makeaholic::setting( 'blog_archive_site_layout' );
				$classes[]   = 'site-content-' . $site_layout;
			}

			return $classes;
		}

		function post_class( $classes ) {
			if ( ! has_post_thumbnail() ) {
				$classes[] = 'post-no-thumbnail';
			}

			return $classes;
		}

		/**
		 * @param WP_Query $query
		 */
		public function change_post_query( $query ) {
			if ( ! $query->is_main_query() || is_admin() || ! $this->is_archive() ) {
				return;
			}

			// Numbers per page.
			$numbers = Makeaholic::setting( 'blog_archive_posts_per_page', 10 );

			$layout_preset = isset( $_GET['blog_archive_preset'] ) ? Makeaholic_Helper::data_clean( $_GET['blog_archive_preset'] ) : false;

			// Hard set post per page. because override preset settings run after init hook.
			if ( $layout_preset ) {
				switch ( $layout_preset ) {
					case '03':
					case '04': // Grid Masonry
						$numbers = 9;
						break;
					case '05': // Grid Wide 4 Columns
						$numbers = 12;
						break;
					case '06': // List 01
					case '07': // List 02
						$numbers = 7;
						break;
				}
			}

			// Change post per page.
			$query->set( 'posts_per_page', apply_filters( 'makeaholic/archive_blog/posts_per_page', $numbers ) );
		}

		function infinite_load() {
			$source     = isset( $_POST['source'] ) ? $_POST['source'] : '';
			$query_vars = $_POST['query_vars'];

			if ( 'custom_query' === $source && isset( $query_vars['extra_tax_query'] ) ) {
				$query_vars = $this->build_extra_terms_query( $query_vars, $query_vars['extra_tax_query'] );
			}

			$makeaholic_query = new WP_Query( $query_vars );

			$settings = isset( $_POST['settings'] ) ? $_POST['settings'] : array();

			$response = array(
				'max_num_pages' => $makeaholic_query->max_num_pages,
				'found_posts'   => $makeaholic_query->found_posts,
				'count'         => $makeaholic_query->post_count,
			);

			ob_start();

			if ( $makeaholic_query->have_posts() ) :
				set_query_var( 'makeaholic_query', $makeaholic_query );
				set_query_var( 'settings', $settings );

				get_template_part( 'loop/widgets/blog/style', $settings['layout'] );

				wp_reset_postdata();
			endif;

			$template = ob_get_contents();
			ob_clean();

			$response['template'] = $template;

			echo json_encode( $response );

			wp_die();
		}

		function get_related_posts( $args ) {
			$defaults = array(
				'post_id'      => '',
				'number_posts' => 3,
			);
			$args     = wp_parse_args( $args, $defaults );
			if ( $args['number_posts'] <= 0 || $args['post_id'] === '' ) {
				return false;
			}

			$categories = get_the_category( $args['post_id'] );

			if ( ! $categories ) {
				return false;
			}

			foreach ( $categories as $category ) {
				if ( $category->parent === 0 ) {
					$term_ids[] = $category->term_id;
				} else {
					$term_ids[] = $category->parent;
					$term_ids[] = $category->term_id;
				}
			}

			// Remove duplicate values from the array.
			$unique_array = array_unique( $term_ids );

			$query_args = array(
				'post_type'      => self::$post_type,
				'orderby'        => 'date',
				'order'          => 'DESC',
				'posts_per_page' => $args['number_posts'],
				'post__not_in'   => array( $args['post_id'] ),
				'no_found_rows'  => true,
				'tax_query'      => array(
					array(
						'taxonomy'         => 'category',
						'terms'            => $unique_array,
						'include_children' => false,
					),
				),
			);

			$query = new WP_Query( $query_args );

			wp_reset_postdata();

			return $query;
		}

		function get_the_post_meta( $name = '', $default = '' ) {
			$post_meta = get_post_meta( get_the_ID(), 'insight_post_options', true );

			if ( ! empty( $post_meta ) ) {
				$post_options = maybe_unserialize( $post_meta );

				if ( $post_options !== false && isset( $post_options[ $name ] ) ) {
					return $post_options[ $name ];
				}
			}

			return $default;
		}

		function get_the_post_format() {
			$format = '';
			if ( get_post_format() !== false ) {
				$format = get_post_format();
			}

			return $format;
		}

		function the_categories( $args = array() ) {
			if ( ! has_category() ) {
				return;
			}

			$defaults = array(
				'classes'    => 'post-categories',
				'separator'  => ', ',
				'show_links' => true,
				'single'     => true,
			);
			$args     = wp_parse_args( $args, $defaults );
			?>
			<div class="<?php echo esc_attr( $args['classes'] ); ?>">
				<?php
				$categories = get_the_category();
				$loop_count = 0;
				foreach ( $categories as $category ) {
					if ( $loop_count > 0 ) {
						echo "{$args['separator']}";
					}

					if ( true === $args['show_links'] ) {
						printf(
							'<a href="%1$s"><span>%2$s</span></a>',
							esc_url( get_category_link( $category->term_id ) ),
							$category->name
						);
					} else {
						echo "<span>{$category->name}</span>";
					}

					$loop_count++;

					if ( true === $args['single'] ) {
						break;
					}
				}
				?>
			</div>
			<?php
		}

		/**
		 * @param array $args
		 *
		 * Render first category template of the post.
		 */
		function the_category( $args = array() ) {
			if ( ! has_category() ) {
				return;
			}

			$defaults = array(
				'classes'    => 'post-categories',
				'show_links' => true,
			);
			$args     = wp_parse_args( $args, $defaults );
			?>
			<div class="<?php echo esc_attr( $args['classes'] ); ?>">
				<?php
				$categories = get_the_category();
				$category   = $categories[0];

				if ( $args['show_links'] ) {
					$link = get_term_link( $category );
					printf( '<a href="%1$s" rel="category tag"><span>%2$s</span></a>', $link, $category->name );
				} else {
					echo "<span>{$category->name}</span>";
				}
				?>
			</div>
			<?php
		}

		function nav_page_links() {
			?>
			<div class="blog-nav-links">
				<div class="nav-list">
					<div class="nav-item prev">
						<div class="inner">
							<?php
							if ( get_previous_post() ) {
								$prev_post     = get_previous_post();
								$post_cat      = get_the_category( $prev_post->ID );
								$post_cat_html = '';
								if ( $post_cat ) {
									$post_cat_html = '<span class="nav-item--cat prev-cat">' . $post_cat[0]->name . '</span>';
								}

								previous_post_link( '%link', $post_cat_html . '<h6>%title</h6>' );
							}
							?>
						</div>
					</div>
					<div class="nav-item next">
						<div class="inner">
							<?php
							if ( get_next_post() ) {
								$next_post     = get_next_post();
								$post_cat      = get_the_category( $next_post->ID );
								$post_cat_html = '';
								if ( $post_cat ) {
									$post_cat_html = '<span class="nav-item--cat next-cat">' . $post_cat[0]->name . '</span>';
								}

								next_post_link( '%link', $post_cat_html . '<h6>%title</h6>' );
							}
							?>
						</div>
					</div>
				</div>
			</div>

			<?php
		}

		function meta_author_template() {
			?>
			<div class="post-author">
				<a href="<?php echo get_author_posts_url( get_the_author_meta( 'ID' ), get_the_author_meta( 'user_nicename' ) ); ?>">
					<?php echo get_avatar( get_the_author_meta( 'ID' ) ); ?>
					<span><?php esc_html_e( 'By', 'makeaholic' ); ?></span>
					<?php the_author(); ?>
				</a>
			</div>
			<?php
		}

		function meta_date_template() {
			?>
			<div class="post-date">
				<?php echo get_the_date(); ?>
			</div>
			<?php
		}

		function meta_view_count_template() {
			if ( function_exists( 'the_views' ) ) : ?>
				<div class="post-view">
					<?php the_views(); ?>
				</div>
			<?php
			endif;
		}

		function meta_comment_count_template() {
			?>
			<div class="post-comments">
				<?php
				$comment_count = get_comments_number();
				printf( _n( '%s comment', '%s comments', $comment_count, 'makeaholic' ), number_format_i18n( $comment_count ) );
				?>
			</div>
			<?php
		}

		function entry_meta_comment_count_template() {
			?>
			<div class="post-comments">
				<a href="#comments" class="smooth-scroll-link">
					<?php
					$comment_count = get_comments_number();
					printf( _n( '%s comment', '%s comments', $comment_count, 'makeaholic' ), number_format_i18n( $comment_count ) );
					?>
				</a>
			</div>
			<?php
		}

		function entry_categories() {
			if ( '1' !== Makeaholic::setting( 'single_post_categories_enable' ) || ! has_category() ) {
				return;
			}
			?>
			<div class="entry-post-categories">
				<?php the_category( ' ' ); ?>
			</div>
			<?php
		}

		function entry_tags() {
			if ( '1' !== Makeaholic::setting( 'single_post_tags_enable' ) || ! has_tag() ) {
				return;
			}
			?>
			<div class="entry-post-tags">
				<div class="tagcloud">
					<?php the_tags( '', '', '' ); ?>
				</div>
			</div>
			<?php
		}

		function entry_feature() {
			if ( '1' !== Makeaholic::setting( 'single_post_feature_enable' ) ) {
				return;
			}

			$post_format    = $this->get_the_post_format();
			$thumbnail_size = '770x400';

			/*if ( 'none' === Makeaholic_Global::instance()->get_sidebar_status() ) {
				$thumbnail_size = '1170x600';
			}*/

			switch ( $post_format ) {
				case 'gallery':
					$this->entry_feature_gallery( $thumbnail_size );
					break;
				case 'audio':
					$this->entry_feature_audio();
					break;
				case 'video':
					$this->entry_feature_video( $thumbnail_size );
					break;
				case 'quote':
					$this->entry_feature_quote();
					break;
				case 'link':
					$this->entry_feature_link();
					break;
				default:
					$this->entry_feature_standard( $thumbnail_size );
					break;
			}
		}

		private function entry_feature_standard( $size ) {
			if ( ! has_post_thumbnail() ) {
				return;
			}
			?>
			<div class="entry-post-feature post-thumbnail">
				<?php Makeaholic_Image::the_post_thumbnail( [ 'size' => $size, ] ); ?>
			</div>
			<?php
		}

		private function entry_feature_gallery( $size ) {
			$gallery = $this->get_the_post_meta( 'post_gallery' );
			if ( empty( $gallery ) ) {
				return;
			}
			?>
			<div class="entry-post-feature post-gallery tm-swiper tm-slider" data-nav="1" data-loop="1"
			     data-gutter-desktop="30">
				<div class="swiper-inner">
					<div class="swiper">
						<div class="swiper-wrapper">
							<?php foreach ( $gallery as $image ) { ?>
								<div class="swiper-slide">
									<?php Makeaholic_Image::the_attachment_by_id( array(
										'id'   => $image['id'],
										'size' => $size,
									) ); ?>
								</div>
							<?php } ?>
						</div>
					</div>
				</div>
			</div>
			<?php
		}

		private function entry_feature_audio() {
			$audio = Makeaholic_Post::instance()->get_the_post_meta( 'post_audio' );
			if ( empty( $audio ) ) {
				return;
			}

			if ( strrpos( $audio, '.mp3' ) !== false ) {
				echo do_shortcode( '[audio mp3="' . $audio . '"][/audio]' );
			} else {
				?>
				<div class="entry-post-feature post-audio">
					<?php if ( wp_oembed_get( $audio ) ) { ?>
						<?php echo Makeaholic_Helper::w3c_iframe( wp_oembed_get( $audio ) ); ?>
					<?php } ?>
				</div>
				<?php
			}
		}

		private function entry_feature_video( $size ) {
			$video = $this->get_the_post_meta( 'post_video' );
			if ( empty( $video ) ) {
				return;
			}
			?>
			<div class="entry-post-feature post-video tm-popup-video type-poster makeaholic-animation-zoom-in">
				<a href="<?php echo esc_url( $video ); ?>" class="video-link makeaholic-box link-secret">
					<div class="video-poster">
						<div class="makeaholic-image">
							<?php if ( has_post_thumbnail() ) { ?>
								<?php Makeaholic_Image::the_post_thumbnail( [ 'size' => $size, ] ); ?>
							<?php } ?>
						</div>
						<div class="video-overlay"></div>

						<div class="video-button">
							<div class="video-play video-play-icon">
								<span class="icon"></span>
							</div>
						</div>
					</div>
				</a>
			</div>
			<?php
		}

		private function entry_feature_quote() {
			$text = $this->get_the_post_meta( 'post_quote_text' );
			if ( empty( $text ) ) {
				return;
			}
			$name = $this->get_the_post_meta( 'post_quote_name' );
			$url  = $this->get_the_post_meta( 'post_quote_url' );
			?>
			<div class="entry-post-feature post-quote">
				<div class="post-quote-content">
					<h3 class="post-quote-text"><?php echo esc_html( '&ldquo;' . $text . '&rdquo;' ); ?></h3>
					<?php if ( ! empty( $name ) ) { ?>
						<?php $name = "- $name"; ?>
						<h6 class="post-quote-name">
							<?php if ( ! empty( $url ) ) { ?>
								<a href="<?php echo esc_url( $url ); ?>"
								   target="_blank"><?php echo esc_html( $name ); ?></a>
							<?php } else { ?>
								<?php echo esc_html( $name ); ?>
							<?php } ?>
						</h6>
					<?php } ?>
				</div>
			</div>
			<?php
		}

		private function entry_feature_link() {
			$link = $this->get_the_post_meta( 'post_link' );
			if ( empty( $link ) ) {
				return;
			}
			?>
			<div class="entry-post-feature post-link">
				<a href="<?php echo esc_url( $link ); ?>" target="_blank"><?php echo esc_html( $link ); ?></a>
			</div>
			<?php
		}

		function entry_share( $args = array() ) {
			if ( '1' !== Makeaholic::setting( 'single_post_share_enable' ) || ! class_exists( 'InsightCore' ) ) {
				return;
			}

			$social_sharing = Makeaholic::setting( 'social_sharing_item_enable' );
			if ( empty( $social_sharing ) ) {
				return;
			}
			?>
			<div class="entry-post-share">
				<div class="post-share style-01">
					<div class="share-label heading-color">
						<?php esc_html_e( 'Share:', 'makeaholic' ); ?>
					</div>
					<div class="share-media">
						<div class="share-list">
							<?php Makeaholic_Templates::get_sharing_list( $args ); ?>
						</div>
					</div>
				</div>
			</div>
			<?php
		}

		function loop_share( $args = array() ) {
			if ( ! class_exists( 'InsightCore' ) ) {
				return;
			}

			$social_sharing = Makeaholic::setting( 'social_sharing_item_enable' );
			if ( empty( $social_sharing ) ) {
				return;
			}
			?>
			<div class="post-share style-01">
				<div class="share-label">
					<?php esc_html_e( 'Share this post', 'makeaholic' ); ?>
				</div>
				<div class="share-media">
					<span class="share-icon fas fa-share-alt"></span>

					<div class="share-list">
						<?php Makeaholic_Templates::get_sharing_list( $args ); ?>
					</div>
				</div>
			</div>
			<?php
		}
	}

	Makeaholic_Post::instance()->initialize();
}
