<?php
defined( 'ABSPATH' ) || exit;

if ( ! class_exists( 'Makeaholic_Top_Bar' ) ) {

	class Makeaholic_Top_Bar {

		protected static $instance = null;

		public static function instance() {
			if ( null === self::$instance ) {
				self::$instance = new self();
			}

			return self::$instance;
		}

		public function initialize() {

		}

		/**
		 * @return array List top bar types include id & name.
		 */
		public function get_type() {
			return array(
				'01' => esc_html__( '01', 'makeaholic' ),
				'02' => esc_html__( '02', 'makeaholic' ),
				'03' => esc_html__( '03', 'makeaholic' ),
			);
		}

		/**
		 * @param bool   $default_option Show or hide default select option.
		 * @param string $default_text   Custom text for default option.
		 *
		 * @return array A list of options for select field.
		 */
		public function get_list( $default_option = false, $default_text = '' ) {
			$top_bars = array(
				'none' => esc_html__( 'Hide', 'makeaholic' ),
			);

			$top_bars += $this->get_type();

			if ( $default_option === true ) {
				if ( $default_text === '' ) {
					$default_text = esc_html__( 'Default', 'makeaholic' );
				}

				$top_bars = array( '' => $default_text ) + $top_bars;
			}

			return $top_bars;
		}

		public function get_support_components() {
			$list = [
				'widget'            => esc_html__( 'Widget', 'makeaholic' ),
				'text'              => esc_html__( 'Text', 'makeaholic' ),
				'language_switcher' => esc_html__( 'Language Switcher', 'makeaholic' ),
				'info_list'         => esc_html__( 'Info List', 'makeaholic' ),
				'user_link'         => esc_html__( 'User Link', 'makeaholic' ),
				'social_links'      => esc_html__( 'Social Links', 'makeaholic' ),
			];

			$list = apply_filters( 'makeaholic/top_bar/supported_components', $list );

			return $list;
		}

		/**
		 * Add classes to the top barr.
		 *
		 * @var string $class Custom class.
		 */
		public function get_wrapper_class( $class = '' ) {
			$classes = array( 'page-top-bar' );

			$type = Makeaholic_Global::instance()->get_top_bar_type();

			$classes[] = "top-bar-{$type}";

			if ( ! empty( $class ) ) {
				if ( ! is_array( $class ) ) {
					$class = preg_split( '#\s+#', $class );
				}
				$classes = array_merge( $classes, $class );
			} else {
				// Ensure that we always coerce class to being an array.
				$class = array();
			}

			$classes = apply_filters( 'makeaholic/top_bar/class', $classes, $class );

			echo 'class="' . esc_attr( join( ' ', $classes ) ) . '"';
		}

		public function render() {
			$type = Makeaholic_Global::instance()->get_top_bar_type();

			if ( 'none' !== $type ) {
				makeaholic_load_template( 'top-bar/top-bar', $type );
			}
		}

		public function get_active_components() {
			$type = Makeaholic_Global::instance()->get_top_bar_type();

			$layout = Makeaholic::setting( "top_bar_style_{$type}_layout" );

			$active_components = [];

			$left_components   = Makeaholic::setting( "top_bar_style_{$type}_left_components" );
			$center_components = Makeaholic::setting( "top_bar_style_{$type}_center_components" );
			$right_components  = Makeaholic::setting( "top_bar_style_{$type}_right_components" );
			$has_left_column   = $has_center_column = $has_right_column = false;

			switch ( $layout ) {
				case '1l':
					$has_left_column = true;
					break;
				case '1c':
					$has_center_column = true;
					break;
				case '1r':
					$has_right_column = true;
					break;
				case '2':
					$has_left_column  = true;
					$has_right_column = true;
					break;
				case '3':
					$has_left_column   = true;
					$has_center_column = true;
					$has_right_column  = true;
					break;
			}

			if ( $has_left_column ) {
				$active_components = array_merge( $active_components, $left_components );
			}

			if ( $has_center_column ) {
				$active_components = array_merge( $active_components, $center_components );
			}

			if ( $has_right_column ) {
				$active_components = array_merge( $active_components, $right_components );
			}

			return $active_components;
		}

		public function print_components( $position = 'left' ) {
			$type       = Makeaholic_Global::instance()->get_top_bar_type();
			$components = Makeaholic::setting( "top_bar_style_{$type}_{$position}_components" );

			if ( empty( $components ) ) {
				return;
			}

			foreach ( $components as $component ) {
				switch ( $component ) {
					case 'text' :
						$this->print_text();
						break;
					case 'widget' :
						$this->print_widgets();
						break;
					case 'language_switcher' :
						$this->print_language_switcher();
						break;
					case 'info_list' :
						$this->print_info_list();
						break;
					case 'user_link' :
						$this->print_user_link();
						break;
					case 'social_links' :
						$this->print_social_links();
						break;
					default:
						do_action( 'makeaholic/top_bar/print_components_' . $component );
						break;
				}
			}
		}

		public function print_text() {
			$type = Makeaholic_Global::instance()->get_top_bar_type();
			$text = Makeaholic::setting( "top_bar_style_{$type}_text" );

			makeaholic_load_template( 'top-bar/components/text', null, $args = [ 'text' => $text ] );
		}

		/**
		 * Print WPML switcher html template.
		 *
		 * @var string $class Custom class.
		 */
		public function print_language_switcher() {
			do_action( 'makeaholic_before_add_language_selector_top_bar' );

			if ( ! defined( 'ICL_SITEPRESS_VERSION' ) ) {
				return;
			}
			?>
			<div id="switcher-language-wrapper" class="switcher-language-wrapper">
				<?php do_action( 'wpml_add_language_selector' ); ?>
			</div>
			<?php
		}

		public function print_button( $type = '01' ) {
			$button_text        = Makeaholic::setting( "top_bar_style_{$type}_button_text" );
			$button_link        = Makeaholic::setting( "top_bar_style_{$type}_button_link" );
			$button_link_target = Makeaholic::setting( "top_bar_style_{$type}_button_link_target" );
			$button_classes     = 'top-bar-button';
			?>
			<?php if ( $button_link !== '' && $button_text !== '' ) : ?>
				<a class="<?php echo esc_attr( $button_classes ); ?>"
				   href="<?php echo esc_url( $button_link ); ?>"
					<?php if ( $button_link_target === '1' ) : ?>
						target="_blank"
					<?php endif; ?>
				>
					<?php echo esc_html( $button_text ); ?>
				</a>
			<?php endif;
		}

		public function print_user_link() {
			makeaholic_load_template( 'top-bar/components/user-links' );
		}

		public function print_social_links() {
			makeaholic_load_template( 'top-bar/components/socials' );
		}

		public function print_widgets() {
			makeaholic_load_template( 'top-bar/components/widgets' );
		}

		public function print_info_list() {
			$type      = Makeaholic_Global::instance()->get_top_bar_type();
			$info_list = Makeaholic::setting( "top_bar_style_{$type}_info_list" );

			if ( ! empty( $info_list ) ) {
				makeaholic_load_template( 'top-bar/components/info-list', null, $args = [ 'info_list' => $info_list ] );
			}
		}
	}

	Makeaholic_Top_Bar::instance()->initialize();
}
