<?php
defined( 'ABSPATH' ) || exit;

if ( ! class_exists( 'Makeaholic_Upload' ) ) {
	class Makeaholic_Upload {

		protected static $instance = null;

		static function instance() {
			if ( null === self::$instance ) {
				self::$instance = new self();
			}

			return self::$instance;
		}

		public function initialize() {
			add_action( 'wp_enqueue_scripts', [ $this, 'scripts' ] );

			add_action( 'after_switch_theme', [ $this, 'allows_customer_upload_avatar' ], 10, 2 );

			if ( class_exists( 'Metronet_Profile_Picture' ) ) {
				add_action( 'makeaholic/myaccount/after_avatar', array( $this, 'upload_icon' ), 5 );
				add_action( 'makeaholic/myaccount/before_info', array( $this, 'user_profile' ), 5 );

				add_action( 'wp_ajax_makeaholic_upload_avatar', array( $this, 'ajax_upload_avatar' ) );
				add_action( 'wp_ajax_makeaholic_remove_avatar', array( $this, 'ajax_remove_avatar' ) );

			}
		}

		/**
		 * @param string   $old_name
		 * @param WP_Theme $old_theme
		 */
		public function allows_customer_upload_avatar( $old_name, $old_theme ) {
			$subscriber = get_role( 'subscriber' );

			if ( $subscriber ) {
				$subscriber->add_cap( 'upload_files', true );
			}
		}

		public function scripts() {
			$min = Makeaholic_Enqueue::instance()->get_min_suffix();

			wp_register_script( 'makeaholic-upload', MAKEAHOLIC_THEME_URI . "/assets/js/upload{$min}.js", [
				'makeaholic-script',
			], '1.0.0', true );

			wp_enqueue_script( 'makeaholic-upload' );

			$js_variables = array(
				'image_loader'        => MAKEAHOLIC_THEME_IMAGE_URI . '/main-preloader.gif',
				'update_avatar_nonce' => wp_create_nonce( 'makeaholic-update-user-avatar' ),
			);

			wp_localize_script( 'makeaholic-upload', '$makeaholicUpload', $js_variables );
		}

		/**
		 * Gets a post id for the user - Creates a post if a post doesn't exist
		 *
		 * @param int $user_id User ID of the user.
		 *
		 * @return int post_id
		 */
		private function get_user_post_id( $user_id = 0 ) {
			$user = get_user_by( 'id', $user_id );

			// Get/Create Profile Picture Post.
			$post_args = array(
				'post_type'   => 'mt_pp',
				'author'      => $user_id,
				'post_status' => 'publish',
			);
			$posts     = get_posts( $post_args );
			if ( ! $posts ) {
				$post_id = wp_insert_post(
					array(
						'post_author' => $user_id,
						'post_type'   => 'mt_pp',
						'post_status' => 'publish',
						'post_title'  => $user->data->display_name,
					)
				);
			} else {
				$post    = end( $posts );
				$post_id = $post->ID;
			}

			return $post_id;
		}

		public function user_profile() {
			if ( ! current_user_can( 'upload_files' ) ) {
				return;
			}

			$current_user = wp_get_current_user();
			$user_id      = $current_user->ID;
			$post_id      = $this->get_user_post_id( $user_id );

			?>
			<div class="makeaholic-user-profile">
				<form action="" method="post" class="makeaholic-user-profile__form" enctype="multipart/form-data">
					<input type="file" accept="image/*" name="user_avatar" class="tm_user_avatar hidden">
					<input type="hidden" name="tm_user_id" class="tm_user_id"
					       value="<?php echo esc_attr( $user_id ); ?>">
					<input type="hidden" name="tm_user_post_id" class="tm_user_post_id"
					       value="<?php echo esc_attr( $post_id ); ?>">

					<div class="makeaholic-user-profile__action">
						<a href="#" class="upload_avatar">
							<span class="action-icon"><i class="ph-upload-simple"></i></span>
							<span class="action-text"><?php esc_html_e( 'Upload', 'makeaholic' ) ?></span>
						</a>
						<a href="#" class="remove_avatar">
							<span class="action-icon"><i class="ph-trash"></i></span>
							<span class="action-text"><?php esc_html_e( 'Remove', 'makeaholic' ) ?></span>
						</a>
					</div>
				</form>
			</div>
			<?php
		}

		public function upload_icon() {
			?>
			<a href="#" class="toggle_upload_action"><i class="ph-camera"></i></a>
			<?php
		}

		public function ajax_remove_avatar() {
			if ( ! current_user_can( 'upload_files' ) ) {
				wp_die();
			}

			$post_id = isset( $_POST['tm_user_post_id'] ) ? absint( $_POST['tm_user_post_id'] ) : 0;
			$user_id = isset( $_POST['tm_user_id'] ) ? absint( $_POST['tm_user_id'] ) : 0;

			if ( 0 === $post_id || 0 === $user_id ) {
				wp_die();
			}

			check_ajax_referer( 'makeaholic-update-user-avatar' );

			update_user_option( $user_id, 'metronet_image_id', 0 );
			delete_post_meta( $post_id, '_thumbnail_id' );

			$src = MAKEAHOLIC_THEME_IMAGE_URI . '/person.png';

			$post_thumbnail = sprintf( '<img src="%s" width="100" height="100" alt="">', esc_attr( $src ) );

			$response         = array();
			$response['html'] = $post_thumbnail;
			wp_send_json( $response );
		}

		public function ajax_upload_avatar() {
			if ( ! current_user_can( 'upload_files' ) ) {
				wp_die();
			}

			check_ajax_referer( 'makeaholic-update-user-avatar' );

			$post_id = isset( $_POST['tm_user_post_id'] ) ? absint( $_POST['tm_user_post_id'] ) : 0;
			$user_id = isset( $_POST['tm_user_id'] ) ? absint( $_POST['tm_user_id'] ) : 0;

			$media_id = media_handle_upload( 'user_avatar', $post_id );

			if ( $media_id ) {
				update_user_option( $user_id, 'metronet_post_id', $post_id );
				update_user_option( $user_id, 'metronet_image_id', $media_id );

				set_post_thumbnail( $post_id, $media_id );

				$thumb_src      = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'thumbnail', false, '' );
				$post_thumbnail = sprintf( '<img src="%s" width="100" height="100" alt=""/>', esc_url( $thumb_src[0] ) );

				$response         = array();
				$response['html'] = $post_thumbnail;
				wp_send_json( $response );
			} else {
				wp_die();
			}
		}
	}

	Makeaholic_Upload::instance()->initialize();
}
