<?php
defined( 'ABSPATH' ) || exit;

/**
 * Custom functions, filters, actions for WooCommerce.
 */
if ( ! class_exists( 'Makeaholic_Woo' ) ) {
	class Makeaholic_Woo extends Makeaholic_Post_Type {

		protected static $instance = null;
		const SIDEBAR_FILTERS = 'shop_filters';
		const MINIMUM_PLUGIN_VERSION = '4.0.2';

		public static $product_image_size_width = '';
		public static $product_image_size_height = '';
		public static $product_image_crop = true;

		public static function instance() {
			if ( null === self::$instance ) {
				self::$instance = new self();
			}

			return self::$instance;
		}

		public function define_constants() {
			define( 'MAKEAHOLIC_WOO_DIR', get_template_directory() . DIRECTORY_SEPARATOR . 'woocommerce' );
			define( 'MAKEAHOLIC_WOO_CORE_DIR', MAKEAHOLIC_FRAMEWORK_DIR . DIRECTORY_SEPARATOR . 'woocommerce' );
		}

		public function initialize() {
			$this->define_constants();

			// Do nothing if Woo plugin not activated.
			if ( ! $this->is_activated() ) {
				return;
			}

			makeaholic_require_file_once( MAKEAHOLIC_WOO_CORE_DIR . '/back-compatible.php' );
			makeaholic_require_file_once( MAKEAHOLIC_WOO_CORE_DIR . '/enqueue.php' );
			makeaholic_require_file_once( MAKEAHOLIC_WOO_CORE_DIR . '/ajax-handlers.php' );
			makeaholic_require_file_once( MAKEAHOLIC_WOO_CORE_DIR . '/sidebar.php' );
			makeaholic_require_file_once( MAKEAHOLIC_WOO_CORE_DIR . '/shop-layout-switcher.php' );
			makeaholic_require_file_once( MAKEAHOLIC_WOO_CORE_DIR . '/quick-view.php' );
			makeaholic_require_file_once( MAKEAHOLIC_WOO_CORE_DIR . '/fly-cart.php' );
			makeaholic_require_file_once( MAKEAHOLIC_WOO_CORE_DIR . '/discount.php' );
			makeaholic_require_file_once( MAKEAHOLIC_WOO_CORE_DIR . '/product-bought-together.php' );
			makeaholic_require_file_once( MAKEAHOLIC_WOO_CORE_DIR . '/trust-badge.php' );
			makeaholic_require_file_once( MAKEAHOLIC_WOO_CORE_DIR . '/shop-reviews.php' );
			//makeaholic_require_file_once( MAKEAHOLIC_WOO_CORE_DIR . '/sales-countdown-timer.php' );
			makeaholic_require_file_once( MAKEAHOLIC_WOO_CORE_DIR . '/customer.php' );
			makeaholic_require_file_once( MAKEAHOLIC_WOO_CORE_DIR . '/comments.php' );
			makeaholic_require_file_once( MAKEAHOLIC_WOO_CORE_DIR . '/archive-product.php' );
			makeaholic_require_file_once( MAKEAHOLIC_WOO_CORE_DIR . '/single-product.php' );
			makeaholic_require_file_once( MAKEAHOLIC_WOO_CORE_DIR . '/my-account.php' );
			makeaholic_require_file_once( MAKEAHOLIC_WOO_CORE_DIR . '/cart.php' );
			makeaholic_require_file_once( MAKEAHOLIC_WOO_CORE_DIR . '/checkout.php' );

			makeaholic_require_file_once( MAKEAHOLIC_WOO_CORE_DIR . '/product-question.php' );

			add_filter( 'makeaholic/custom_css/primary_color_selectors', [ $this, 'custom_css' ] );

			add_filter( 'woocommerce_add_to_cart_fragments', [ $this, 'header_add_to_cart_fragment' ] );

			/**
			 * Move regular price before sale price.
			 */
			add_filter( 'woocommerce_get_price_html', [ $this, 'add_wrap_for_price_html' ], 999, 2 );
			add_filter( 'woocommerce_format_price_range', [ $this, 'format_price_range' ], 999, 3 );

			add_action( 'wp_head', [ $this, 'wp_init' ] );

			// Move nav count to link.
			add_filter( 'woocommerce_layered_nav_term_html', [ $this, 'move_layered_nav_count_inside_link' ], 10, 4 );

			/**
			 * Begin hooks for single product.
			 */
			// Move product price before product title.
			remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_price', 10 );
			add_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_price', 4 );

			// Add Single Brands.
			add_action( 'woocommerce_product_meta_end', [ $this, 'template_single_custom_brands' ], 25 );

			// Add sharing list.
			add_action( 'woocommerce_product_meta_end', [ $this, 'entry_sharing' ], 25 );

			// Change review avatar size.
			add_filter( 'woocommerce_review_gravatar_size', [ $this, 'woocommerce_review_gravatar_size' ] );

			// Check old version installed.
			if ( defined( 'WOOSCP_VERSION' ) || ( defined( 'WOOSC_VERSION' ) && version_compare( WOOSC_VERSION, self::MINIMUM_PLUGIN_VERSION, '<' ) ) ) {
				add_action( 'admin_notices', [ $this, 'admin_notice_minimum_compare_plugin_version' ] );
			}

			// Hide default smart compare & smart wishlist button.
			add_filter( 'woosw_button_position_archive', '__return_false' );
			add_filter( 'woosw_button_position_single', '__return_false' );
			add_filter( 'woosc_button_position_archive', '__return_false' );
			add_filter( 'woosc_button_position_single', '__return_false' );

			// Add compare & wishlist button again.
			add_action( 'woocommerce_after_add_to_cart_button', [ $this, 'get_compare_button_template' ], 40 );
			add_action( 'woocommerce_after_add_to_cart_button', [ $this, 'get_wishlist_button_template' ], 40 );

			// Change compare button color on popup.
			add_filter( 'woosc_bar_btn_color_default', [ $this, 'change_compare_button_color' ] );

			// Add div tag wrapper quantity.
			add_action( 'woocommerce_before_add_to_cart_quantity', [ $this, 'add_quantity_open_wrapper' ] );
			add_action( 'woocommerce_after_add_to_cart_quantity', [ $this, 'add_quantity_close_wrapper' ] );
			/**
			 * End hooks for single product.
			 */

			/**
			 * Begin ajax requests.
			 */
			// Load more for widget Product.
			add_action( 'wp_ajax_product_infinite_load', [ $this, 'product_infinite_load' ] );
			add_action( 'wp_ajax_nopriv_product_infinite_load', [ $this, 'product_infinite_load' ] );
			/**
			 * End ajax requests.
			 */

			add_action( 'after_switch_theme', [ $this, 'change_product_image_size' ], 2 );
			add_action( 'after_setup_theme', [ $this, 'modify_theme_support' ], 10 );

			/**
			 * Fix Cart fragments issue with WC 7.8.0
			 */
			add_action( 'wp_enqueue_scripts', function() {
				wp_enqueue_script( 'wc-cart-fragments' );
			} );

			add_filter( 'woocommerce_resize_images', function() {
				return false;
			} );

			add_action( 'init', array( $this, 'remove_wc_register_blocks' ), 1 );
		}

		/**
		 * This WC action hook make Customize Preview loading freeze.
		 * Temp remove it in customize preview
		 *
		 * @return void
		 */
		public function remove_wc_register_blocks() {
			if( is_customize_preview() ) {
				makeaholic_remove_filters_for_anonymous_class('init', 'Automattic\WooCommerce\Blocks\BlockTypesController', 'register_blocks');
			}
		}

		/**
		 * Check woocommerce plugin active
		 *
		 * @return boolean true if plugin activated
		 */
		function is_activated() {
			if ( class_exists( 'WooCommerce' ) ) {
				return true;
			}

			return false;
		}

		public function custom_css( $selectors ) {
			$selectors['color'][] = "
				.widget_price_filter .ui-slider,
				.order-by .selected-order a,
				.makeaholic-product-price-filter .current-state,
				.woocommerce .product-badges .onsale,
				.cart-collaterals .order-total .amount,
				.woocommerce-mini-cart__empty-message .empty-basket,
				.woocommerce .cart.shop_table td.product-name a:hover,
				.woocommerce ul.product_list_widget li .product-title:hover,
				.button.btn-apply-coupon,
				.widget_price_filter .price_slider_amount .button,
				.woocommerce-review-rating-template .rating-average,
				.makeaholic-product .woocommerce-loop-product__title a:hover,
				.makeaholic-product .loop-product__category a:hover,
				.popup-product-quick-view .product_title a:hover,
				.makeaholic-wp-widget-product-brand-nav .chosen,
				.makeaholic-wp-widget-product-brand-nav .chosen a,
				.woosc-area .woosc-inner .woosc-table .woosc-table-inner .woosc-table-items table thead tr th a:hover
			";

			$selectors['background-color'][] = "
				.makeaholic-product.style-grid-01 .woocommerce_loop_add_to_cart_wrap a:hover,
				.makeaholic-product.style-grid-03 .woocommerce_loop_add_to_cart_wrap a:hover,
				.makeaholic-product .loop-product-stock .sold-bar,
				.widget_price_filter .price_slider_amount .button:hover,
				.woocommerce-info, .woocommerce-message,
				.woocommerce-MyAccount-navigation .is-active a,
				.woocommerce-MyAccount-navigation a:hover
			";

			$selectors['border-color'][] = "
				body.woocommerce-cart table.cart td.actions .coupon .input-text:focus,
				.woocommerce div.quantity .qty:focus,
				.woocommerce.single-product div.product .images .thumbnails .item img:hover
			";

			$selectors['border-bottom-color'][] = "
				.mini-cart .widget_shopping_cart_content,
				.woocommerce .select2-container .select2-choice
			";

			return $selectors;
		}

		/**
		 * @param WC_Product|WC_Product_Variable $product
		 * @param                                $price_amt
		 * @param                                $regular_price
		 * @param                                $sale_price
		 *
		 * @return string
		 */
		public function custom_price_html( $product, $price_amt, $regular_price, $sale_price ) {
			$html_price = '';

			if ( $product->is_on_sale() ) {
				if ( $sale_price === 0 ) {
					$html_price .= '<del>' . wc_price( $regular_price ) . '</del>';
					$html_price .= '<ins>' . esc_html__( 'Free!', 'makeaholic' ) . '</ins>';
				} else {
					$html_price .= '<del>' . wc_price( $regular_price ) . '</del>';
					$html_price .= '<ins>' . wc_price( $sale_price ) . '</ins>';
				}

			} else if ( ( $price_amt == $regular_price ) && ( $regular_price != 0 ) ) {
				$html_price .= wc_price( $regular_price );
			} else if ( $price_amt == $regular_price && $regular_price == 0 ) {
				$html_price .= '<ins>' . esc_html__( 'Free!', 'makeaholic' ) . '</ins>';
			}

			return $html_price;
		}

		/**
		 * Format a price range for display.
		 * Add wrap tag around price range separator
		 *
		 * @param string $from Price from.
		 * @param string $to Price to.
		 *
		 * @return string
		 */
		public function format_price_range( $price, $from, $to ) {
			$price = sprintf( _x( '%1$s <span class="wc-price-separator">&ndash;</span> %2$s', 'Price range: from-to', 'makeaholic' ), is_numeric( $from ) ? wc_price( $from ) : $from, is_numeric( $to ) ? wc_price( $to ) : $to );

			return $price;
		}

		/**
		 * Add div wrap around price html
		 *
		 * @param            $price
		 * @param WC_Product $product
		 *
		 * @return string
		 *
		 * @since 2.5.0
		 */
		public function add_wrap_for_price_html( $price, $product ) {
			return '<div class="price">' . $price . '</div>';
		}

		/**
		 * @param            $price
		 * @param WC_Product $product
		 *
		 * @return string
		 */
		public function simple_product_price_html( $price, $product ) {
			if ( $product->is_type( 'simple' ) ) {
				$regular_price = $product->get_regular_price();
				$sale_price    = $product->get_sale_price();
				$price_amt     = $product->get_price();

				$html_price = $this->custom_price_html( $product, $price_amt, $regular_price, $sale_price );
			} else {
				$html_price = $price;
			}

			if ( strpos( $html_price, 'class="price"' ) === false ) {
				$html_price = '<div class="price">' . $html_price . '</div>';
			}

			return $html_price;
		}

		public function product_price_html( $price, $variation ) {
			$variation_id = $variation->variation_id;
			//creating the product object
			$variable_product = new WC_Product( $variation_id );

			$regular_price = $variable_product->get_regular_price();
			$sale_price    = $variable_product->get_sale_price();
			$price_amt     = $variable_product->get_price();

			return $this->custom_price_html( $variable_product, $price_amt, $regular_price, $sale_price );
		}

		/**
		 * @param                     $price
		 * @param WC_Product_Variable $product
		 *
		 * @return string
		 */
		public function product_minmax_price_html( $price, $product ) {
			$variation_min_price         = $product->get_variation_price( 'min', true );
			$variation_max_price         = $product->get_variation_price( 'max', true );
			$variation_min_regular_price = $product->get_variation_regular_price( 'min', true );
			$variation_max_regular_price = $product->get_variation_regular_price( 'max', true );

			if ( ( $variation_min_price == $variation_min_regular_price ) && ( $variation_max_price == $variation_max_regular_price ) ) {
				$html_min_max_price = $price;
			} else {
				$html_price = '<del>' . wc_format_price_range( $variation_min_regular_price, $variation_max_regular_price ) . '</del>';
				$html_price .= '<ins>' . wc_format_price_range( $variation_min_price, $variation_max_price ) . '</ins>';

				$html_min_max_price = $html_price;
			}

			return $html_min_max_price;
		}

		public function add_quantity_open_wrapper() {
			?>
			<div class="quantity-button-wrapper">
			<label><?php esc_html_e( 'Quantity', 'makeaholic' ); ?></label>
			<?php
		}

		public function add_quantity_close_wrapper() {
			global $product;

			echo wc_get_stock_html( $product ); // WPCS: XSS ok.
			?>
			</div>
			<?php
		}

		function entry_sharing() {
			if ( Makeaholic::setting( 'single_product_sharing_enable' ) === '1' && class_exists( 'InsightCore' ) ) :
				$social_sharing = Makeaholic::setting( 'social_sharing_item_enable' );
				if ( ! empty( $social_sharing ) ) {
					?>
					<div class="entry-product-share meta-item">
						<label class="meta-label">
							<?php esc_html_e( 'Share:', 'makeaholic' ); ?>
						</label>
						<div class="meta-content">
							<?php Makeaholic_Templates::get_sharing_list(); ?>
						</div>
					</div>
					<?php
				}
			endif;
		}

		/*
		 * Change woocommerce product image size on first time switch to this theme.
		 */
		public function change_product_image_size() {
			global $pagenow;

			if ( ! isset( $_GET['activated'] ) || $pagenow != 'themes.php' ) {
				return;
			}

			$count = get_option( 'makeaholic_switch_theme_count' );

			// Do it for first time.
			if ( ! $count || $count < 2 ) {
				// Update single image width
				//update_option( 'woocommerce_single_image_width', 760 );

				// Update thumbnail image width.
				update_option( 'woocommerce_thumbnail_image_width', 480 );

				// Update thumbnail cropping ratio.
				update_option( 'woocommerce_thumbnail_cropping', 'custom' );
				update_option( 'woocommerce_thumbnail_cropping_custom_width', 4 );
				update_option( 'woocommerce_thumbnail_cropping_custom_height', 5 );
			}
		}

		/**
		 * Modify image width theme support.
		 */
		function modify_theme_support() {
			/*$theme_support                          = get_theme_support( 'woocommerce' );
			$theme_support                          = is_array( $theme_support ) ? $theme_support[0] : array();
			$theme_support['single_image_width']    = 760;
			$theme_support['thumbnail_image_width'] = 400;

			remove_theme_support( 'woocommerce' );*/
			add_theme_support( 'woocommerce' );
		}

		/**
		 * Returns true if on a page which uses WooCommerce templates exclude single product (cart and checkout are standard pages with shortcodes and which are also included)
		 *
		 * @access public
		 * @return bool
		 */
		function is_woocommerce_page_without_product() {
			if ( function_exists( 'is_shop' ) && is_shop() ) {
				return true;
			}

			if ( function_exists( 'is_product_taxonomy' ) && is_product_taxonomy() ) {
				return true;
			}

			if ( is_post_type_archive( 'product' ) ) {
				return true;
			}

			$the_id = get_the_ID();

			if ( $the_id !== false ) {
				$woocommerce_keys = array(
					'woocommerce_shop_page_id',
					'woocommerce_terms_page_id',
					'woocommerce_cart_page_id',
					'woocommerce_checkout_page_id',
					'woocommerce_pay_page_id',
					'woocommerce_thanks_page_id',
					'woocommerce_myaccount_page_id',
					'woocommerce_edit_address_page_id',
					'woocommerce_view_order_page_id',
					'woocommerce_change_password_page_id',
					'woocommerce_logout_page_id',
					'woocommerce_lost_password_page_id',
				);

				foreach ( $woocommerce_keys as $wc_page_id ) {
					if ( $the_id == get_option( $wc_page_id, 0 ) ) {
						return true;
					}
				}
			}

			return false;
		}

		/**
		 * Returns true if on a page which uses WooCommerce templates (cart and checkout are standard pages with shortcodes and which are also included)
		 *
		 * @access public
		 * @return bool
		 */
		function is_woocommerce_page() {
			if ( function_exists( 'is_woocommerce' ) && is_woocommerce() ) {
				return true;
			}

			$woocommerce_keys = array(
				"woocommerce_shop_page_id",
				"woocommerce_terms_page_id",
				"woocommerce_cart_page_id",
				"woocommerce_checkout_page_id",
				"woocommerce_pay_page_id",
				"woocommerce_thanks_page_id",
				"woocommerce_myaccount_page_id",
				"woocommerce_edit_address_page_id",
				"woocommerce_view_order_page_id",
				"woocommerce_change_password_page_id",
				"woocommerce_logout_page_id",
				"woocommerce_lost_password_page_id",
			);

			foreach ( $woocommerce_keys as $wc_page_id ) {
				if ( get_the_ID() == get_option( $wc_page_id, 0 ) ) {
					return true;
				}
			}

			return false;
		}

		/**
		 * Returns true if on a archive product pages.
		 *
		 * @access public
		 * @return bool
		 */
		public function is_product_archive() {
			return $this->is_shop() || $this->is_product_taxonomy() ? true : false;
		}

		public function is_shop() {
			return function_exists( 'is_shop' ) && is_shop() ? true : false;
		}

		public function is_product_taxonomy() {
			$taxonomies = get_object_taxonomies( 'product' );

			return empty( $taxonomies ) ? false : is_tax( $taxonomies );
		}

		public function template_single_custom_brands() {
			if ( ( Makeaholic::setting( 'single_product_brands_enable' ) !== '1' ) || ! class_exists( 'woo_brands' ) ) {
				return;
			}

			global $post;

			$get_terms = 'product_brand';
			$terms     = get_the_terms( $post->ID, $get_terms );

			if ( is_array( $terms ) && ! empty( $terms ) ) {
				$tax_text = get_option( 'pw_woocommerce_brands_text', '' );

				if ( empty( $tax_text ) ) {
					$taxonomy = get_taxonomy( $get_terms );
					$labels   = $taxonomy->labels;
					$tax_text = $labels->name . ':';
				}
				?>
				<div class="entry-product-brands meta-item">
					<label class="meta-label">
						<?php echo esc_html( $tax_text ); ?>
					</label>
					<div class="meta-content">
						<?php
						$total = count( $terms );
						$count = 1;
						foreach ( $terms as $term ) {
							$term_link = get_term_link( $term );
							?>
							<a href="<?php echo esc_url( $term_link ) ?>"><?php echo esc_html( $term->name ); ?></a>

							<?php if ( $count < $total ) {
								echo ', ';
							}
							$count ++; ?>
							<?php
						}
						?>
					</div>
				</div>
				<?php
			}
		}

		public function template_loop_product_category() {
			global $product;

			$cats = $product->get_category_ids();

			if ( ! empty( $cats ) ) {
				?>
				<div class="loop-product__category">
					<?php
					$first_cat = $cats[0];
					$cat       = get_term_by( 'id', $first_cat, 'product_cat' );

					if ( $cat instanceof \WP_Term ) {
						$link = get_term_link( $cat );
						echo '<a href="' . esc_url( $link ) . '">' . $cat->name . '</a>';
					}
					?>
				</div>
				<?php
			}
		}

		function woocommerce_review_gravatar_size() {
			return Makeaholic::COMMENT_AVATAR_SIZE;
		}

		function wp_init() {
			// Remove Cross Sells from default position at Cart. Then add them back UNDER the Cart Table.
			remove_action( 'woocommerce_cart_collaterals', 'woocommerce_cross_sell_display' );
			if ( Makeaholic::setting( 'shopping_cart_cross_sells_enable' ) === '1' ) {
				add_action( 'woocommerce_after_cart', 'woocommerce_cross_sell_display' );
			}

			/**
			 * Hook: woocommerce_before_shop_loop.
			 *
			 * @hooked wc_print_notices - 10
			 * @hooked woocommerce_result_count - 20
			 * @hooked woocommerce_catalog_ordering - 30
			 */
			// @hooked wc_print_notices - 10
			add_action( 'woocommerce_before_shop_loop', [ $this, 'add_shop_action_begin_wrapper' ], 15 );
			// @hooked woocommerce_result_count - 20
			add_action( 'woocommerce_before_shop_loop', [ $this, 'add_shop_action_right_toolbar_begin_wrapper' ], 25 );

			/**
			 * Change order template priority 30 -> 40.
			 */
			remove_action( 'woocommerce_before_shop_loop', 'woocommerce_catalog_ordering', 30 );

			if ( '1' === Makeaholic::setting( 'shop_archive_sorting' ) ) {
				add_action( 'woocommerce_before_shop_loop', 'woocommerce_catalog_ordering', 40 );
			}

			if ( '1' === Makeaholic::setting( 'shop_archive_filtering' ) && is_active_sidebar( self::SIDEBAR_FILTERS ) ) {
				add_action( 'woocommerce_before_shop_loop', [
					$this,
					'add_shop_action_right_toolbar_filter_button',
				], 40 );
			}

			add_action( 'woocommerce_before_shop_loop', [ $this, 'add_shop_action_right_toolbar_end_wrapper' ], 50 );

			if ( '1' === Makeaholic::setting( 'shop_archive_filtering' ) ) {
				add_action( 'woocommerce_before_shop_loop', [ $this, 'add_shop_action_filter_widgets' ], 90 );
			}

			add_action( 'woocommerce_before_shop_loop', [ $this, 'add_shop_action_end_wrapper' ], 70 );
		}

		public function get_shop_base_url() {
			if ( defined( 'SHOP_IS_ON_FRONT' ) ) {
				$link = home_url();
			} elseif ( is_shop() ) {
				$link = get_permalink( wc_get_page_id( 'shop' ) );
			} elseif ( is_product_category() ) {
				$link = get_term_link( get_query_var( 'product_cat' ), 'product_cat' );
			} elseif ( is_product_tag() ) {
				$link = get_term_link( get_query_var( 'product_tag' ), 'product_tag' );
			} else {
				$queried_object = get_queried_object();
				$link           = get_term_link( $queried_object->slug, $queried_object->taxonomy );
			}

			return $link;
		}

		public function add_shop_action_filter_widgets() {
			$filtering_enable = Makeaholic::setting( 'shop_archive_filtering' );

			if ( '1' === $filtering_enable && is_active_sidebar( self::SIDEBAR_FILTERS ) ) {
				?>
				<div id="archive-top-filter-widgets" class="col-md-12 archive-top-filter-widgets">
					<div class="inner">
						<div class="archive-top-filter-content">
							<?php dynamic_sidebar( self::SIDEBAR_FILTERS ); ?>
						</div>

						<?php
						$has_filters = isset( $_GET['filtering'] ) ? true : false;

						if ( $has_filters ) {
							$reset_link = $this->get_shop_base_url();

							Makeaholic_Templates::render_button( [
								'wrapper_class' => 'btn-reset-filters',
								'text'          => esc_html__( 'Clear filters', 'makeaholic' ),
								'link'          => [
									'url' => $reset_link,
								],
								'style'         => 'text',
								'icon'          => 'far fa-times',
								'size'          => 'xs',
							] );
						}
						?>
					</div>
				</div>
				<?php
			}
		}

		public function add_shop_action_right_toolbar_filter_button() {
			Makeaholic_Templates::render_button( [
				'wrapper_class' => 'btn-toggle-shop-filters',
				'extra_class'   => 'btn-toggle-archive-top-filters button-alt',
				'text'          => esc_html__( 'Filters', 'makeaholic' ),
				'link'          => [
					'url' => 'javascript:void(0)',
				],
				'icon'          => 'ph-funnel',
				'id'            => 'btn-toggle-archive-top-filters',
			] );
		}

		public function add_shop_action_begin_wrapper() {
			echo '<div id="archive-shop-actions" class="archive-shop-actions"><div class="archive-shop-actions-inner"><div class="container"><div class="row">';
		}

		public function add_shop_action_end_wrapper() {
			echo '</div></div></div></div>';
		}

		public function add_shop_action_right_toolbar_begin_wrapper() {
			echo '<div class="shop-actions-toolbar shop-actions-toolbar-right col-md-7"><div class="inner">';

			do_action( 'makeaholic/shop_archive/actions_toolbar_right/before' );
		}

		public function add_shop_action_right_toolbar_end_wrapper() {
			do_action( 'makeaholic/shop_archive/actions_toolbar_right/after' );

			echo '</div></div>';
		}

		/**
		 * Ensure cart contents update when products are added to the cart via AJAX
		 * ========================================================================
		 *
		 * @param $fragments
		 *
		 * @return mixed
		 */
		public function header_add_to_cart_fragment( $fragments ) {
			ob_start();
			$cart_html = $this->get_mini_cart();
			echo '' . $cart_html;
			$fragments['.mini-cart__button'] = ob_get_clean();

			return $fragments;
		}

		/**
		 * Get mini cart HTML
		 * ==================
		 *
		 * @return string
		 */
		public function get_mini_cart() {
			global $woocommerce;
			$cart_url = '/cart';
			if ( isset( $woocommerce ) ) {
				$cart_url = wc_get_cart_url();
			}

			$cart_html = '';
			$qty       = WC()->cart->get_cart_contents_count();
			$cart_html .= '<a href="' . esc_url( $cart_url ) . '" class="mini-cart__button header-icon" title="' . esc_attr__( 'View your shopping cart', 'makeaholic' ) . '">';
			$cart_html .= '<span class="mini-cart-icon" data-count="' . $qty . '"></span>';
			$cart_html .= '</a>';

			return $cart_html;
		}

		/**
		 * @param WC_Product|WC_Product_Variable $product
		 *
		 * @return string
		 */
		public function get_product_price_saving_amount( $product = null ) {
			if ( ! $product ) {
				global $product;
			}

			$saving_amount = 0;

			if ( $product->is_type( 'simple' ) || $product->is_type( 'external' ) || $product->is_type( 'woosb' ) ) {
				$regular_price = $product->get_regular_price();
				$sale_price    = $product->get_sale_price();

				$saving_amount = $regular_price - $sale_price;
			} elseif ( $product->is_type( 'variable' ) ) {
				$max_amount           = 0;
				$available_variations = $product->get_available_variations( 'objects' );
				foreach ( $available_variations as $variation ) {
					/**
					 * @var $variation WC_Product_Variable
					 */
					$regular_price = $variation->get_regular_price();
					$sale_price    = $variation->get_sale_price();

					if ( empty( $sale_price ) ) {
						continue;
					}

					$saving_amount = $regular_price - $sale_price;

					if ( $saving_amount > $max_amount ) {
						$max_amount = $saving_amount;
					}
				}

				return $max_amount;
			}

			return $saving_amount;
		}

		/**
		 * @param WC_Product|WC_Product_Variable $product
		 *
		 * @return string
		 */
		public function get_product_price_saving_percentage( $product = null ) {
			if ( ! $product ) {
				global $product;
			}

			$percentage = 0;

			if ( $product->is_type( 'simple' ) || $product->is_type( 'external' ) || $product->is_type( 'woosb' ) ) {
				$regular_price = $product->get_regular_price();
				$sale_price    = $product->get_sale_price();

				$percentage = round( ( ( $regular_price - $sale_price ) / $regular_price ) * 100 );
			} elseif ( $product->is_type( 'variable' ) ) {
				$max_percentage       = 0;
				$available_variations = $product->get_available_variations( 'objects' );
				foreach ( $available_variations as $variation ) {
					/**
					 * @var $variation WC_Product_Variable
					 */
					$regular_price = $variation->get_regular_price();
					$sale_price    = $variation->get_sale_price();

					if ( empty( $sale_price ) ) {
						continue;
					}

					$percentage = round( ( ( $regular_price - $sale_price ) / $regular_price ) * 100 );

					if ( $percentage > $max_percentage ) {
						$max_percentage = $percentage;
					}
				}

				return $max_percentage;
			}

			return $percentage;
		}

		public function get_product_sale_badge_text() {
			$percentage = $this->get_product_price_saving_percentage();

			if ( $percentage > 0 ) {
				return "-{$percentage}%";
			}

			return esc_html__( 'Sale !', 'makeaholic' );
		}

		public static function get_wishlist_button_template( $args = array() ) {
			if ( ( Makeaholic::setting( 'shop_archive_wishlist' ) !== '1' ) || ! class_exists( 'WPCleverWoosw' ) ) {
				return;
			}

			global $product;
			$product_id = $product->get_id();

			$defaults = array(
				'show_tooltip'     => false,
				'tooltip_position' => 'top',
				'tooltip_skin'     => '',
				'style'            => '02',
			);
			$args     = wp_parse_args( $args, $defaults );

			$_wrapper_classes = "product-action wishlist-btn style-{$args['style']}";

			if ( $args['show_tooltip'] === true ) {
				$_wrapper_classes .= ' hint--bounce';
				$_wrapper_classes .= " hint--{$args['tooltip_position']}";
				$_wrapper_classes .= " hint--{$args['tooltip_skin']}";
			}
			?>
			<div class="<?php echo esc_attr( $_wrapper_classes ); ?>"
			     data-hint="<?php esc_attr_e( 'Add to wishlist', 'makeaholic' ) ?>">
				<?php echo do_shortcode( '[woosw id="' . $product_id . '" type="link"]' ); ?>
			</div>
			<?php
		}

		public static function get_compare_button_template( $args = array() ) {
			if ( Makeaholic::setting( 'shop_archive_compare' ) !== '1' || wp_is_mobile() || ! class_exists( 'WPCleverWoosc' ) ) {
				return;
			}

			global $product;
			$product_id = $product->get_id();

			$defaults = array(
				'show_tooltip'     => false,
				'tooltip_position' => 'top',
				'tooltip_skin'     => '',
				'style'            => '02',
			);
			$args     = wp_parse_args( $args, $defaults );

			$_wrapper_classes = "product-action compare-btn style-{$args['style']}";

			if ( $args['show_tooltip'] === true ) {
				$_wrapper_classes .= ' hint--bounce';
				$_wrapper_classes .= " hint--{$args['tooltip_position']}";
				$_wrapper_classes .= " hint--{$args['tooltip_skin']}";
			}
			?>
			<div class="<?php echo esc_attr( $_wrapper_classes ); ?>"
			     data-hint="<?php esc_attr_e( 'Compare', 'makeaholic' ) ?>">
				<?php echo do_shortcode( '[woosc id="' . $product_id . '" type="link"]' ); ?>
			</div>
			<?php
		}

		public function change_compare_button_color() {
			$primary_color = Makeaholic::setting( 'primary_color' );

			return $primary_color;
		}

		public function get_quick_view_button_template( $args = array() ) {
			if ( Makeaholic::setting( 'shop_archive_quick_view' ) !== '1' ) {
				return;
			}

			if ( ( Makeaholic::setting( 'shop_archive_quick_view_on_mobile' ) !== '1' ) && wp_is_mobile() ) {
				return;
			}

			global $product;
			$product_id = $product->get_id();

			$defaults = array(
				'show_tooltip'     => true,
				'tooltip_position' => 'top',
				'tooltip_skin'     => '',
				'style'            => '02',
			);
			$args     = wp_parse_args( $args, $defaults );

			$_wrapper_classes = "product-action quick-view-btn style-{$args['style']}";

			if ( $args['show_tooltip'] === true ) {
				$_wrapper_classes .= ' hint--bounce';
				$_wrapper_classes .= " hint--{$args['tooltip_position']}";
				$_wrapper_classes .= " hint--{$args['tooltip_skin']}";
			}
			?>
			<div class="<?php echo esc_attr( $_wrapper_classes ); ?>"
			     data-hint="<?php esc_attr_e( 'Quick view', 'makeaholic' ) ?>"
			     data-pid="<?php echo esc_attr( $product_id ); ?>"
			     data-pnonce="<?php echo wp_create_nonce( 'woo_quick_view' ); ?>">
				<a class="quick-view-icon" href="#"></a>
			</div>
			<?php
		}

		public function custom_woo_reviews_summary() {
			global $product;
			$product_id       = $product->get_id();
			$get_rating_count = get_post_meta( $product_id, '_wc_rating_count', true );

			$total_rating = 0;

			for ( $i = 5; $i > 0; $i -- ) {
				$get_rating_count[ $i ] = isset( $get_rating_count[ $i ] ) ? intval( $get_rating_count[ $i ] ) : 0;
				$total_rating           += $get_rating_count[ $i ];
			}

			for ( $i = 5; $i > 0; $i -- ) {
				$percentage = 0;
				if ( $get_rating_count[ $i ] > 0 ) {
					$percentage = round( ( $get_rating_count[ $i ] / $total_rating ) * 100 );
				}
				?>
				<div class="reviews-bar">
					<label
						class="stars-title"><?php echo esc_html( sprintf( _n( '%s star', '%s stars', $i, 'makeaholic' ), $i ) ); ?></label>

					<div class="rating-graph" title="<?php printf( '%s%%', $percentage ); ?>">
						<div class="percentage bar"
						     style="width: <?php echo esc_attr( $percentage ); ?>%"></div>
					</div>

					<div class="rating-percentage">
						<?php echo esc_html( sprintf( __( '%1$d%%', 'makeaholic' ), $percentage ) ); ?>
					</div>
				</div> <?php
			} ?>
			<?php
		}

		public function product_infinite_load() {
			$source = isset( $_POST['source'] ) ? $_POST['source'] : '';

			if ( 'current_query' === $source ) {
				$query_vars                = $_POST['query_vars'];
				$query_vars['paged']       = $_POST['paged'];
				$query_vars['nopaging']    = false;
				$query_vars['post_status'] = 'publish';

				$makeaholic_query = new WP_Query( $query_vars );
			} else {
				$query_args = array(
					'post_type'      => $_POST['post_type'],
					'posts_per_page' => $_POST['posts_per_page'],
					'orderby'        => $_POST['orderby'],
					'order'          => $_POST['order'],
					'paged'          => $_POST['paged'],
					'post_status'    => 'publish',
				);

				if ( ! empty( $_POST['extra_taxonomy'] ) ) {
					$query_args = $this->build_extra_terms_query( $query_args, $_POST['extra_taxonomy'] );
				}

				$makeaholic_query = new WP_Query( $query_args );
			}

			$response = array(
				'max_num_pages' => $makeaholic_query->max_num_pages,
				'found_posts'   => $makeaholic_query->found_posts,
				'count'         => $makeaholic_query->post_count,
			);

			ob_start();

			if ( $makeaholic_query->have_posts() ) :

				while ( $makeaholic_query->have_posts() ) : $makeaholic_query->the_post();
					wc_get_template_part( 'content', 'product' );
				endwhile;

				wp_reset_postdata();

			endif;

			$template = ob_get_contents();
			ob_clean();

			$response['template'] = $template;

			echo json_encode( $response );

			wp_die();
		}

		public function get_loop_product_image( $args = array() ) {
			$defaults = array(
				'extra_class' => '',
			);

			$args = wp_parse_args( $args, $defaults );

			// Calculate product loop image size.
			if ( self::$product_image_size_width === '' ) {
				$width = 400;

				$shop_layout = Makeaholic::setting( 'shop_archive_layout' );
				if ( 'wide' === $shop_layout ) {
					$width = 540;
				}

				$cropping = get_option( 'woocommerce_thumbnail_cropping' );
				$height   = $width;

				if ( $cropping === 'custom' ) {
					$ratio_w = get_option( 'woocommerce_thumbnail_cropping_custom_width' );
					$ratio_h = get_option( 'woocommerce_thumbnail_cropping_custom_height' );

					$height = ( $width * $ratio_h ) / $ratio_w;
					$height = (int) $height;
				} elseif ( $cropping === 'uncropped' ) {
					self::$product_image_crop = false;
					$height                   = 9999;
				}

				self::$product_image_size_width  = $width;
				self::$product_image_size_height = $height;
			}

			$image_args = array(
				'id'     => $args['id'],
				'size'   => 'custom',
				'width'  => self::$product_image_size_width,
				'height' => self::$product_image_size_height,
				'crop'   => self::$product_image_crop,
			);

			if ( $args['extra_class'] !== '' ) {
				$image_args['class'] = $args['extra_class'];
			}

			Makeaholic_Image::the_attachment_by_id( $image_args );
		}

		/**
		 * @param WC_Product $product
		 *
		 * @return false|string
		 */
		public function get_product_image_id( $product ) {
			$image_id = 0;

			if ( $product_image_id = $product->get_image_id() ) {
				return $product_image_id;
			} elseif ( $product->get_parent_id() ) {
				$parent_product = wc_get_product( $product->get_parent_id() );
				if ( $parent_product ) {
					$image_id = $this->get_product_image_id( $parent_product );
				}
			}

			$placeholder_image = get_option( 'woocommerce_placeholder_image', 0 );
			if ( ! empty( $placeholder_image ) && is_numeric( $placeholder_image ) ) {
				$image_id = $placeholder_image;
			}

			return $image_id;
		}

		public function get_wc_product_image_placeholder_src() {
			return WC()->plugin_url() . '/assets/images/placeholder.png';
		}

		/**
		 * @param \WC_Product $product
		 * @param mixed       $size
		 *
		 * @return string
		 */
		public function get_product_image( $product, $size = 'full' ) {
			$image = '';
			if ( $product->get_image_id() ) {
				$image = Makeaholic_Image::get_attachment_by_id( [
					'id'   => $product->get_image_id(),
					'size' => $size,
				] );
			} elseif ( $product->get_parent_id() ) {
				$parent_product = wc_get_product( $product->get_parent_id() );
				if ( $parent_product ) {
					$image = Makeaholic_Image::get_attachment_by_id( [
						'id'   => $parent_product->get_image_id(),
						'size' => $size,
					] );
				}
			}

			return $image;
		}

		/**
		 * @param \WC_Product $product
		 * @param mixed       $size
		 *
		 * @return string
		 */
		public function get_product_image_url( $product, $size = 'full' ) {
			$image_src = '';
			if ( $product->get_image_id() ) {
				$image_src = Makeaholic_Image::get_attachment_url_by_id( [
					'id'   => $product->get_image_id(),
					'size' => $size,
				] );
			} elseif ( $product->get_parent_id() ) {
				$parent_product = wc_get_product( $product->get_parent_id() );
				if ( $parent_product ) {
					$image_src = Makeaholic_Image::get_attachment_url_by_id( [
						'id'   => $parent_product->get_image_id(),
						'size' => $size,
					] );
				}
			}

			return $image_src;
		}

		/**
		 * @param \WC_Product $product
		 *
		 * @return string
		 */
		public function get_product_notification_settings( $product ) {
			$notification_settings = [
				'image' => $this->get_product_image_url( $product, '80x80' ),
				'title' => $product->get_name(),
			];

			return wp_json_encode( $notification_settings );
		}

		public function move_layered_nav_count_inside_link( $term_html, $term, $link, $count ) {
			if ( $count > 0 ) {
				$term_html = str_replace( '</a>', '', $term_html );

				$find    = '</span>';
				$replace = '</span></a>';
				$pos     = strrpos( $term_html, $find );

				if ( $pos !== false ) {
					$term_html = substr_replace( $term_html, $replace, $pos, strlen( $find ) );
				}
			}

			return $term_html;
		}

		public function get_single_product_site_layout() {
			$layout = Makeaholic::setting( 'single_product_site_layout' );

			return $layout;
		}

		public function get_single_product_image_style() {
			$style = Makeaholic_Helper::get_post_meta( 'single_product_image_style' );

			if ( empty( $style ) ) {
				$style = Makeaholic::setting( 'single_product_image_style' );
			}

			return $style;
		}

		public function get_single_product_image_layout() {
			$layout = Makeaholic::setting( 'single_product_image_layout' );

			return $layout;
		}

		/**
		 * Get base shop page link
		 *
		 * @param bool $keep_query
		 *
		 * @return false|string|void|WP_Error
		 */
		public function get_shop_page_link( $keep_query = false ) {

			// Base Link decided by current page
			if ( defined( 'SHOP_IS_ON_FRONT' ) ) {
				$link = home_url();
			} elseif ( is_post_type_archive( 'product' ) || is_page( wc_get_page_id( 'shop' ) ) ) {
				$link = get_post_type_archive_link( 'product' );
			} elseif ( is_product_category() ) {
				$link = get_term_link( get_query_var( 'product_cat' ), 'product_cat' );
			} elseif ( is_product_tag() ) {
				$link = get_term_link( get_query_var( 'product_tag' ), 'product_tag' );
			} else {
				$link = get_term_link( get_query_var( 'term' ), get_query_var( 'taxonomy' ) );
			}

			if ( $keep_query ) {
				// Keep query string vars intact
				foreach ( $_GET as $key => $val ) {

					if ( 'orderby' === $key || 'submit' === $key ) {
						continue;
					}

					$link = add_query_arg( $key, $val, $link );
				}
			}

			return $link;
		}

		public function get_shop_layout() {
			if ( '1' === Makeaholic::setting( 'shop_archive_layout_switcher' ) && isset( $_COOKIE['shop_layout'] ) ) {
				return $_COOKIE['shop_layout'];
			}

			return Makeaholic::setting( 'shop_archive_layout' );
		}

		/**
		 * empty value for only products.
		 *
		 * @return string $shop_page_display
		 */
		public function get_shop_display() {
			/**
			 * Force mode for demo purpose.
			 */
			if ( ! empty( $_GET['shop_setting_preset'] ) ) {
				switch ( $_GET['shop_setting_preset'] ) {
					case '03':
						return 'both';
				}
			}

			return woocommerce_get_loop_display_mode();
		}

		/**
		 * Get coupon display HTML.
		 *
		 * @param string|WC_Coupon $coupon Coupon data or code.
		 *
		 * @see wc_cart_totals_coupon_html()
		 *
		 */
		public function cart_totals_coupon_html( $coupon ) {
			if ( is_string( $coupon ) ) {
				$coupon = new WC_Coupon( $coupon );
			}

			$discount_amount_html = '';

			$amount               = WC()->cart->get_coupon_discount_amount( $coupon->get_code(), WC()->cart->display_cart_ex_tax );
			$discount_amount_html = '-' . wc_price( $amount );

			if ( $coupon->get_free_shipping() && empty( $amount ) ) {
				$discount_amount_html = __( 'Free shipping coupon', 'makeaholic' );
			}

			$discount_amount_html = apply_filters( 'woocommerce_coupon_discount_amount_html', $discount_amount_html, $coupon );
			$coupon_html          = $discount_amount_html . ' <a href="' . esc_url( add_query_arg( 'remove_coupon', rawurlencode( $coupon->get_code() ), \Automattic\Jetpack\Constants::is_defined( 'WOOCOMMERCE_CHECKOUT' ) ? wc_get_checkout_url() : wc_get_cart_url() ) ) . '" class="fly-cart-remove-coupon" data-coupon="' . esc_attr( $coupon->get_code() ) . '">' . __( '[Remove]', 'makeaholic' ) . '</a>';

			echo wp_kses( apply_filters( 'woocommerce_cart_totals_coupon_html', $coupon_html, $coupon, $discount_amount_html ), array_replace_recursive( wp_kses_allowed_html( 'post' ), array( 'a' => array( 'data-coupon' => true ) ) ) ); // phpcs:ignore PHPCompatibility.PHP.NewFunctions.array_replace_recursiveFound
		}

		/**
		 * Reviews/Questions Summary
		 */
		public function reviews_summary( $product ) {
			if ( ! $product ) {
				return;
			}

			$product_id      = $product->get_id();
			$_rating_average = $product->get_average_rating();
			$count           = $product->get_review_count();

			$questions = get_comments( array(
				'type'    => 'question',
				'post_id' => $product_id,
				'status'  => 'approve',
			) );

			$question_count = count( $questions );

			?>
			<div class="reviews-summary">
				<div
					class="rating-average secondary-font primary-color"><?php echo esc_html( $_rating_average ); ?></div>

				<?php Makeaholic_Templates::render_rating( $_rating_average, [
					'wrapper_class' => 'entry-product-star-rating',
				] ); ?>

				<div class="reviews-count">
					<?php
					$reviews_count_text = sprintf( esc_html( _n( '%1$s Review', '%1$s Reviews', $count, 'makeaholic' ) ), $count );
					echo esc_html( $reviews_count_text );

					$question_count_text = _n( 'Q&#38;A', 'Q&#38;As', $question_count, 'makeaholic' );
					echo ', <span class="question-count">' . $question_count . '</span> ' . esc_html( $question_count_text );
					?>
				</div>

				<?php Makeaholic_Woo::instance()->custom_woo_reviews_summary(); ?>

				<div class="reviews-summary-buttons">
					<?php
					if ( comments_open() ) :
						Makeaholic_Templates::render_button( [
							'wrapper_class' => 'woocommerce-review-btn',
							'extra_class'   => 'button-alt',
							'text'          => esc_html__( 'Write a review', 'makeaholic' ),
							'link'          => [
								'url' => '#tab-reviews',
							],
							'icon'          => 'ph-pencil',
						] );

						Makeaholic_Templates::render_button( [
							'wrapper_class' => 'woocommerce-question-btn',
							'extra_class'   => 'button-alt',
							'text'          => esc_html__( 'Ask a Question', 'makeaholic' ),
							'link'          => [
								'url' => '#tab-questions',
							],
							'icon'          => 'ph-chats-circle',
						] );
					endif;
					?>
				</div>
			</div>
			<?php
		}

		public function admin_notice_minimum_compare_plugin_version() {
			makeaholic_notice_required_plugin_version( 'WPC Smart Compare for WooCommerce', '4.0.1' );
		}
	}

	Makeaholic_Woo::instance()->initialize();
}
