<?php

namespace Makeaholic\Woo;

defined( 'ABSPATH' ) || exit;

class Archive_Product {
	protected static $instance = null;

	public static function instance() {
		if ( null === self::$instance ) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	public function initialize() {
		add_filter( 'body_class', [ $this, 'body_classes' ] );

		add_filter( 'makeaholic/page_sidebar/single_width', [ $this, 'set_sidebar_single_width' ] );
		add_filter( 'makeaholic/page_sidebar/single_offset', [ $this, 'set_sidebar_single_offset' ] );

		add_filter( 'loop_shop_per_page', [ $this, 'loop_shop_per_page' ], 20 );

		add_filter( 'woocommerce_get_star_rating_html', [ $this, 'change_star_rating_html' ], 10, 3 );

		add_filter( 'woocommerce_catalog_orderby', [ $this, 'custom_product_sorting' ] );

		add_filter( 'woocommerce_pagination_args', [ $this, 'override_pagination_args' ] );

		// Remove thumbnail & sale flash. then use custom.
		remove_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash' );
		remove_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_product_thumbnail' );

		// Hide star rating.
		remove_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_rating', 5 );

		// Move price before title.
		remove_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_price', 10 );
		add_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_price', 10 );

		// Add link to the product title of loop.
		remove_action( 'woocommerce_shop_loop_item_title', 'woocommerce_template_loop_product_title', 10 );
		add_action( 'woocommerce_shop_loop_item_title', [ $this, 'template_loop_product_title' ], 10 );
	}

	public function body_classes( $classes ) {
		$classes[] = 'woocommerce';

		if ( '1' === \Makeaholic::setting( 'shop_archive_hide_add_to_cart_mobile' ) ) {
			$classes[] = ' hide-add-to-cart-on-mobile';
		}

		if ( \Makeaholic_Woo::instance()->is_product_archive() ) {
			$classes[] = 'archive-shop';

			$site_layout = \Makeaholic::setting( 'shop_archive_site_layout' );
			$classes[]   = 'site-content-' . $site_layout;
		}

		return $classes;
	}

	public function set_sidebar_single_width( $width ) {
		if ( \Makeaholic_Woo::instance()->is_product_archive() ) {
			$new_width = \Makeaholic::setting( 'product_archive_single_sidebar_width' );

			if ( '' !== $new_width ) {
				return $new_width;
			}
		}

		return $width;
	}

	public function set_sidebar_single_offset( $offset ) {
		if ( \Makeaholic_Woo::instance()->is_product_archive() ) {
			$new_offset = \Makeaholic::setting( 'product_archive_single_sidebar_offset' );

			if ( '' !== $new_offset ) {
				return $new_offset;
			}
		}

		return $offset;
	}

	public function loop_shop_per_page() {
		$number = \Makeaholic::setting( 'shop_archive_number_item' );

		// Hard set post per page. because override preset settings run after init hook.
		if ( isset( $_GET['shop_archive_preset'] ) ) {
			$layout_preset = wc_clean( $_GET['shop_archive_preset'] );

			switch ( $layout_preset ) {
				case '01':
					$number = 12;
					break;

				case '02':
				case '03':
					$number = 9;
					break;


				case '04':
					$number = 12;
					break;

				case '05':
					$number = 15;
					break;

				case '06':
					$number = 16;
					break;

				case '07':
					$number = 12;
					break;

				case '08':
					$number = 15;
					break;
			}
		}

		return isset( $_GET['product_per_page'] ) ? wc_clean( $_GET['product_per_page'] ) : $number;
	}

	public function change_star_rating_html( $rating_html, $rating, $count ) {
		$rating_html = \Makeaholic_Templates::render_rating( $rating, [ 'echo' => false ] );

		return $rating_html;
	}

	/**
	 * Change text of select options.
	 *
	 * @param $sorting_options
	 *
	 * @return mixed
	 */
	public function custom_product_sorting( $sorting_options ) {
		if ( isset( $sorting_options['menu_order'] ) ) {
			$sorting_options['menu_order'] = esc_html__( 'Default', 'makeaholic' );
		}

		if ( isset( $sorting_options['popularity'] ) ) {
			$sorting_options['popularity'] = esc_html__( 'Popularity', 'makeaholic' );
		}

		if ( isset( $sorting_options['rating'] ) ) {
			$sorting_options['rating'] = esc_html__( 'Average rating', 'makeaholic' );
		}

		if ( isset( $sorting_options['date'] ) ) {
			$sorting_options['date'] = esc_html__( 'Latest', 'makeaholic' );
		}

		if ( isset( $sorting_options['price'] ) ) {
			$sorting_options['price'] = esc_html__( 'Price: low to high', 'makeaholic' );
		}

		if ( isset( $sorting_options['price-desc'] ) ) {
			$sorting_options['price-desc'] = esc_html__( 'Price: high to low', 'makeaholic' );
		}

		return $sorting_options;
	}

	public function override_pagination_args( $args ) {
		$args['prev_text'] = \Makeaholic_Templates::get_pagination_prev_text();
		$args['next_text'] = \Makeaholic_Templates::get_pagination_next_text();

		return $args;
	}

	/**
	 * Custom product title instead of default product title
	 *
	 * @see woocommerce_template_loop_product_title()
	 */
	public function template_loop_product_title() {
		?>
		<h2 class="woocommerce-loop-product__title">
			<a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
		</h2>
		<?php
	}
}

Archive_Product::instance()->initialize();
