<?php

namespace Makeaholic\Woo;

defined( 'ABSPATH' ) || exit;

class Enqueue {
	protected static $instance = null;

	public static function instance() {
		if ( null === self::$instance ) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	public function initialize() {
		// Disable woocommerce all styles.
		add_filter( 'woocommerce_enqueue_styles', '__return_empty_array' );

		add_action( 'wp_enqueue_scripts', [ $this, 'frontend_scripts' ] );
	}

	public function frontend_scripts() {
		$min = \Makeaholic_Enqueue::instance()->get_min_suffix();
		$rtl = \Makeaholic_Enqueue::instance()->get_rtl_suffix();

		// Remove prettyPhoto, default light box of woocommerce.
		wp_dequeue_script( 'prettyPhoto' );
		wp_dequeue_script( 'prettyPhoto-init' );
		wp_dequeue_style( 'woocommerce_prettyPhoto_css' );

		// Remove font awesome from Yith Wishlist plugin.
		wp_dequeue_style( 'yith-wcwl-font-awesome' );

		// Remove hint from Woo Smart Compare plugin.
		wp_dequeue_style( 'hint' );

		// Remove feather font from Woo Smart Wishlist plugin.
		wp_dequeue_style( 'woosw-feather' );

		wp_register_style( 'makeaholic-woocommerce', MAKEAHOLIC_THEME_URI . "/woocommerce{$rtl}.css", null, MAKEAHOLIC_THEME_VERSION );

		wp_register_script( 'makeaholic-woo-general', MAKEAHOLIC_THEME_URI . "/assets/js/woo/general{$min}.js", [ 'jquery' ], MAKEAHOLIC_THEME_VERSION, true );
		wp_register_script( 'makeaholic-woo-checkout', MAKEAHOLIC_THEME_URI . "/assets/js/woo/checkout{$min}.js", [ 'jquery' ], MAKEAHOLIC_THEME_VERSION, true );
		wp_register_script( 'makeaholic-woo-single', MAKEAHOLIC_THEME_URI . "/assets/js/woo/single{$min}.js", [ 'jquery' ], MAKEAHOLIC_THEME_VERSION, true );
		wp_register_script( 'makeaholic-woo-questions', MAKEAHOLIC_THEME_URI . "/assets/js/woo/product-questions{$min}.js", [
			'jquery',
		], MAKEAHOLIC_THEME_VERSION, true );
		wp_register_script( 'makeaholic-woo-fly-cart', MAKEAHOLIC_THEME_URI . "/assets/js/woo/fly-cart{$min}.js", [
			'jquery',
			'makeaholic-quantity-button',
		], MAKEAHOLIC_THEME_VERSION, true );

		$woo_variables = array(
			'shopToolbarsSticky'     => \Makeaholic::setting( 'shop_archive_sticky_toolbars' ),
			'singleProductStickyBar' => \Makeaholic::setting( 'single_product_sticky_bar_enable' ),
			'wc_ajax_url'         => \WC_AJAX::get_endpoint( '%%endpoint%%' ),
			'apply_coupon_nonce'  => wp_create_nonce( 'apply-coupon' ),
			'remove_coupon_nonce' => wp_create_nonce( 'remove-coupon' ),
		);
		wp_localize_script( 'makeaholic-woo-general', '$makeaholicWoo', $woo_variables );

		wp_enqueue_style( 'makeaholic-woocommerce' );

		if ( '1' === \Makeaholic::setting( 'shop_archive_quick_view' ) ) {
			wp_enqueue_style( 'magnific-popup' );
			wp_enqueue_script( 'magnific-popup' );

			/**
			 * Enable ajax add to cart variation in Quick View popup on all pages.
			 */
			wp_enqueue_script( 'wc-add-to-cart-variation' );

			// Quick view need change quantity.
			wp_enqueue_script( 'makeaholic-quantity-button' );
		}

		wp_enqueue_script( 'makeaholic-woo-general' );
		wp_enqueue_script( 'makeaholic-woo-fly-cart' );

		if ( \Makeaholic_Woo::instance()->is_product_archive() ) {
			wp_enqueue_script( 'makeaholic-grid-layout' );
			wp_enqueue_script( 'makeaholic-common-archive' );
		}

		if ( is_cart() || is_product() ) {
			wp_enqueue_script( 'makeaholic-quantity-button' );
		}

		if ( is_checkout() ) {
			wp_enqueue_script( 'makeaholic-woo-checkout' );
		}

		if ( is_product() ) {
			if ( '1' === \Makeaholic::setting( 'single_product_sticky_enable' ) ) {
				wp_enqueue_script( 'sticky-kit' );
			}

			if ( 'grid' === \Makeaholic_Woo::instance()->get_single_product_image_style() ) {
				wp_enqueue_script( 'makeaholic-grid-layout' );
			}

			wp_enqueue_style( 'lightgallery' );
			wp_enqueue_script( 'lightgallery' );
			wp_enqueue_script( 'makeaholic-accordion' );

			wp_enqueue_script( 'makeaholic-woo-single' );

			wp_enqueue_script( 'makeaholic-woo-questions' );

			$single_product_variables = array(
				'i18n'                   => [
					'filesSelected' => sprintf( esc_html__( '%s files selected', 'makeaholic' ), '{count}' ),
					'readMore'      => esc_html__( 'Read more', 'makeaholic' ),
					'readLess'      => esc_html__( 'Read less', 'makeaholic' ),
				],
			);
			wp_localize_script( 'makeaholic-woo-single', '$makeaholicProductSingle', $single_product_variables );
		}
	}
}

Enqueue::instance()->initialize();
