<?php

namespace Makeaholic\Woo;

defined( 'ABSPATH' ) || exit;

class Fly_Cart {
	protected static $instance = null;

	public static function instance() {
		if ( null === self::$instance ) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	public function initialize() {
		add_action( 'wp_footer', [ $this, 'fly_cart_template' ] );

		/**
		 * We need calculate cart total value when removed a coupon.
		 * Priority 1 required to calculate before value set to session
		 *
		 * @hooked woocommerce_removed_coupon
		 * @see    \WC_Cart_Session::set_session()
		 */
		add_action( 'woocommerce_removed_coupon', [ $this, 'update_cart_total' ], 1 );

		/**
		 * Change button order.
		 */
		remove_action( 'woocommerce_widget_shopping_cart_buttons', 'woocommerce_widget_shopping_cart_button_view_cart', 10 );
		remove_action( 'woocommerce_widget_shopping_cart_buttons', 'woocommerce_widget_shopping_cart_proceed_to_checkout', 20 );

		add_action( 'woocommerce_widget_shopping_cart_buttons', 'woocommerce_widget_shopping_cart_proceed_to_checkout', 10 );
		add_action( 'woocommerce_widget_shopping_cart_buttons', [ $this, 'shopping_cart_button_view_cart' ], 20 );

		add_action( 'wp_ajax_makeaholic_update_product_quantity', [ $this, 'update_product_quantity' ] );
		add_action( 'wp_ajax_nopriv_makeaholic_update_product_quantity', [ $this, 'update_product_quantity' ] );
	}

	public function fly_cart_template() {
		?>
		<div id="popup-fly-cart" class="popup-fly-cart">
			<div class="inner">
				<div class="fly-cart-wrap">
					<div class="cart-header">
						<a href="javascript:void(0);" id="btn-close-fly-cart" class="btn-close-fly-cart">
							<i class="ph-x"></i>
						</a>
						<h3 class="mini-cart-title"><?php esc_html_e( 'Shopping bag', 'makeaholic' ); ?></h3>
					</div>

					<div class="popup-fly-cart-content">
						<div class="fly-cart-messages"></div>
						<div class="widget_shopping_cart_content"></div>
					</div>
				</div>
			</div>
		</div>
		<?php
	}

	public function shopping_cart_button_view_cart() {
		\Makeaholic_Templates::render_button( [
			'text'        => esc_html__( 'View cart', 'makeaholic' ),
			'link'        => [
				'url' => esc_url( wc_get_cart_url() ),
			],
			'extra_class' => 'view-cart',
			'style'       => 'text',
		] );
	}

	public function update_product_quantity() {
		if ( ! empty( $_POST['cart_item_key'] ) && isset( $_POST['cart_item_qty'] ) ) {
			if ( WC()->cart->get_cart_item( $_POST['cart_item_key'] ) ) {
				if ( (float) $_POST['cart_item_qty'] > 0 ) {
					WC()->cart->set_quantity( $_POST['cart_item_key'], (float) $_POST['cart_item_qty'] );
				} else {
					WC()->cart->remove_cart_item( $_POST['cart_item_key'] );
				}
			}

			echo json_encode( array( 'action' => 'update_qty' ) );
		}

		wp_die();
	}

	public function update_cart_total( $coupon ) {
		WC()->cart->calculate_totals();
	}
}

Fly_Cart::instance()->initialize();
