<?php

namespace Makeaholic\Woo;

defined( 'ABSPATH' ) || exit;

class Single_Product {
	protected static $instance = null;

	public static function instance() {
		if ( null === self::$instance ) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	public function initialize() {
		add_filter( 'body_class', [ $this, 'body_classes' ] );

		add_filter( 'makeaholic/page_sidebar/single_width', [ $this, 'set_sidebar_single_width' ] );
		add_filter( 'makeaholic/page_sidebar/single_offset', [ $this, 'set_sidebar_single_offset' ] );

		add_filter( 'woocommerce_output_related_products_args', [ $this, 'related_products_args' ] );

		add_action( 'wp_head', [ $this, 'wp_init' ] );

		add_filter( 'woocommerce_product_tabs', [ $this, 'move_reviews_out_of_tabs' ] );

		add_action( 'woocommerce_after_single_product', [ $this, 'add_bottom_tabs' ], 30 );

		add_filter( 'makeaholic/product/bottom_tabs', [ $this, 'add_default_bottom_tabs' ] );
		add_filter( 'makeaholic/product/bottom_tabs', 'woocommerce_sort_product_tabs', 99 );

		add_filter( 'comment_form_submit_button', array( $this, 'add_attachment_button' ) );

		// Action on attachment field
		add_filter( 'dco_ca_form_element_label', array( $this, 'remove_text_comment_form_attachment' ) );
		add_filter( 'dco_ca_form_element_upload_size', array( $this, 'remove_text_comment_form_attachment' ) );
		add_filter( 'dco_ca_form_element_file_types', array( $this, 'remove_text_comment_form_attachment' ) );
		add_filter( 'dco_ca_form_element_autoembed_links', array( $this, 'remove_text_comment_form_attachment' ) );
		add_filter( 'dco_ca_attachment_field', array( $this, 'remove_attachment_field' ) );
	}

	public function body_classes( $classes ) {
		if ( is_product() ) {
			$product_image_layout = \Makeaholic::setting( 'single_product_image_layout' );
			$classes[]            = "single-product-image-{$product_image_layout}";

			$product_image_style = \Makeaholic_Woo::instance()->get_single_product_image_style();
			$classes[]           = "single-product-{$product_image_style}";

			$site_layout = \Makeaholic::setting( 'single_product_site_layout' );
			$classes[]   = 'site-content-' . $site_layout;
		}

		return $classes;
	}

	public function set_sidebar_single_width( $width ) {
		if ( is_product() ) {
			$new_width = \Makeaholic::setting( 'product_page_single_sidebar_width' );

			if ( '' !== $new_width ) {
				return $new_width;
			}
		}

		return $width;
	}

	public function set_sidebar_single_offset( $offset ) {
		if ( is_product() ) {
			$new_offset = \Makeaholic::setting( 'product_page_single_sidebar_offset' );

			if ( '' !== $new_offset ) {
				return $new_offset;
			}
		}

		return $offset;
	}

	public function related_products_args( $args ) {
		$number = \Makeaholic::setting( 'product_related_number' );

		$args['posts_per_page'] = $number;

		return $args;
	}

	public function wp_init() {
		$tabs_display = \Makeaholic::setting( 'single_product_tabs_style' );
		remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_product_data_tabs', 10 );

		switch ( $tabs_display ) {
			case 'toggles':
				add_action( 'woocommerce_single_product_summary', [
					$this,
					'output_product_data_tabs_as_toggles',
				], 100 );
				break;

			case 'tabs':
				add_action( 'woocommerce_after_single_product', 'woocommerce_output_product_data_tabs', 10 );
				break;
		}

		/**
		 * Move Up-sell section below page content.
		 */
		remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_upsell_display', 15 );
		if ( '1' === \Makeaholic::setting( 'single_product_up_sells_enable' ) ) {
			$position = \Makeaholic::setting( 'single_product_up_sells_position' );
			$hook     = 'woocommerce_after_single_product';
			$callback = 'woocommerce_upsell_display';
			$priority = 15;

			switch ( $position ) {
				case 'after-reviews':
					$hook     = 'woocommerce_after_single_product';
					$priority = 90;
					break;
			}

			add_action( $hook, $callback, $priority );
		}

		remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_related_products', 20 );
		if ( '1' === \Makeaholic::setting( 'single_product_related_enable' ) ) {
			$position = \Makeaholic::setting( 'single_product_related_position' );
			$hook     = 'woocommerce_after_single_product';
			$priority = 20;

			switch ( $position ) {
				case 'after-reviews':
					$hook     = 'woocommerce_after_single_product';
					$priority = 100;
					break;
			}

			add_action( $hook, 'woocommerce_output_related_products', $priority );
		}
	}

	/**
	 * Move review of tabs
	 *
	 * @see woocommerce_default_product_tabs()
	 *
	 * @param $tabs
	 *
	 * @return array $tabs
	 */
	public function move_reviews_out_of_tabs( $tabs ) {
		unset( $tabs['reviews'] );

		return $tabs;
	}

	public function add_bottom_tabs() {
		wc_get_template( 'single-product/tabs/bottom-tabs.php' );
	}

	public function output_product_data_tabs_as_toggles() {
		wc_get_template( 'single-product/tabs/toggles.php' );
	}

	public function add_default_bottom_tabs( $tabs = array() ) {
		global $product;

		if ( comments_open() ) {
			$tabs['reviews'] = array(
				'title'    => __( 'Customer Reviews', 'makeaholic' ),
				'priority' => 10,
				'callback' => 'comments_template',
			);

			$tabs['questions'] = array(
				'title'    => __( 'Questions', 'makeaholic' ),
				'priority' => 20,
				'callback' => array( $this, 'product_question' ),
			);
		}

		return $tabs;
	}

	public function product_question() {
		wc_get_template( 'single-product-questions.php' );
	}

	// Keep button only on comment form attachment.
	public function remove_text_comment_form_attachment( $output ) {
		$output = '';
		return $output;
	}

	// Remove Attachment field on single post
	public function remove_attachment_field( $output ) {
		if ( 'product' != get_post_type() ) {
			return '';
		}

		return $output;
	}

	// Add a attachment button next to submit button
	public function add_attachment_button( $submit_button ) {
		if ( ! is_product() ) {
			return $submit_button;
		}

		$button = '<button type="button" class="comment-form__attachment-button attachment-button">';
		$button .= '<span class="button-icon svg-icon"><i class="ph-camera"></i></span>';
		$button .= '<span class="button-text">' . esc_html__( 'Add Photos', 'makeaholic' ) . '</span>';
		$button .= '</button>';

		return $button . $submit_button;
	}
}

Single_Product::instance()->initialize();
