<?php

namespace Makeaholic\Woo;

defined( 'ABSPATH' ) || exit;

class Trust_Badge {
	protected static $instance = null;

	public static function instance() {
		if ( null === self::$instance ) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	public function initialize() {
		// Product data tabs.
		add_action( 'admin_head', [ $this, 'custom_panel_style' ] );
		add_filter( 'woocommerce_product_data_tabs', [ $this, 'add_product_data_tab' ], 10, 1 );
		add_action( 'woocommerce_product_data_panels', [ $this, 'add_product_data_panel' ] );
		add_action( 'woocommerce_process_product_meta', [ $this, 'save_product_meta' ] );

		add_action( 'woocommerce_after_add_to_cart_button', [ $this, 'show_trust_badge_image' ] );
	}

	public function custom_panel_style() {
		?>
		<style>
			#woocommerce-product-data ul.wc-tabs li.makeaholic_trust_badge_options a:before {
				font-family: WooCommerce;
				content: '\e00c';
			}
		</style><?php
	}

	public function add_product_data_tab( $tabs ) {
		$tabs['makeaholic_trust_badge'] = array(
			'label'  => esc_html__( 'Trust Badge', 'makeaholic' ),
			'target' => 'makeaholic_trust_badge_settings',
		);

		return $tabs;
	}

	public function add_product_data_panel() {
		global $post;
		$post_id = $post->ID;
		?>
		<div id="makeaholic_trust_badge_settings" class="panel woocommerce_options_panel">
			<div class="options_group">
				<?php
				woocommerce_wp_select( array(
					'id'       => '_show_trust_badge',
					'label'    => esc_html__( 'Trust Badge', 'makeaholic' ),
					'desc_tip' => esc_html__( 'Show trust badge image below Add To Cart button.', 'makeaholic' ),
					'options'  => [
						''  => esc_html__( 'Default', 'makeaholic' ),
						'0' => esc_html__( 'Hide', 'makeaholic' ),
						'1' => esc_html__( 'Show', 'makeaholic' ),
					],
				) );
				?>
			</div>
		</div>
		<?php
	}

	public function save_product_meta( $post_id ) {
		if ( isset( $_POST['_show_trust_badge'] ) ) {
			update_post_meta( $post_id, '_show_trust_badge', sanitize_text_field( $_POST['_show_trust_badge'] ) );
		}
	}

	public function show_trust_badge_image() {
		global $product;

		$enable = get_post_meta( $product->get_id(), '_show_trust_badge', true );

		if ( '' === $enable ) {
			$enable = \Makeaholic::setting( 'single_product_trust_badge_enable' );
		}

		if ( '0' === $enable ) {
			return;
		}

		$trust_badge_image = \Makeaholic::setting( 'single_product_trust_badge_image' );

		if ( isset( $trust_badge_image['id'] ) ) {
			$trust_badge_image_url = \Makeaholic_Image::get_attachment_url_by_id( [
				'id'   => $trust_badge_image['id'],
				'size' => 'full',
			] );
		} else {
			$trust_badge_image_url = $trust_badge_image['url'];
		}
		?>
		<div class="makeaholic-product-trust-badge">
			<img src="<?php echo esc_url( $trust_badge_image_url ); ?>"
			     alt="<?php esc_attr_e( 'Trust Badge', 'makeaholic' ); ?>">
		</div>
		<?php
	}
}

Trust_Badge::instance()->initialize();
