<?php
/**
 * Template part for displaying blog content in home.php, archive.php.
 *
 * @link    https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Makeaholic
 * @since   1.0
 */
$style   = Makeaholic::setting( 'blog_archive_style', 'grid' );
$classes = [
	'makeaholic-main-post',
	'makeaholic-grid-wrapper',
	'makeaholic-blog',
	'makeaholic-animation-zoom-in',
	"makeaholic-blog-" . $style,
];

$is_grid = false;

if ( in_array( $style, [ 'grid' ], true ) ) {
	$is_grid    = true;
	$grid_class = 'makeaholic-grid';
	$lg_columns = intval( Makeaholic::setting( 'blog_archive_lg_columns' ) );
	$md_columns = Makeaholic::setting( 'blog_archive_md_columns' );
	$sm_columns = Makeaholic::setting( 'blog_archive_sm_columns' );

	$lg_gutter = Makeaholic::setting( 'blog_archive_lg_gutter', 30 );
	$md_gutter = Makeaholic::setting( 'blog_archive_md_gutter' );
	$sm_gutter = Makeaholic::setting( 'blog_archive_sm_gutter' );

	if ( 'none' !== Makeaholic_Global::instance()->get_sidebar_status() ) {
		$lg_columns--;
	}

	$grid_class .= " grid-lg-{$lg_columns}";
	$grid_class .= " grid-md-{$md_columns}";
	$grid_class .= " grid-sm-{$sm_columns}";

	$grid_options = [
		'type'          => ( '1' === Makeaholic::setting( 'blog_archive_masonry' ) ) ? 'masonry' : 'grid',
		'columns'       => $lg_columns,
		'columnsTablet' => $md_columns,
		'columnsMobile' => $sm_columns,
		'gutter'        => $lg_gutter,
	];

	if ( '' !== $md_gutter ) {
		$grid_options['gutterTablet'] = $md_gutter;
	}

	if ( '' !== $sm_gutter ) {
		$grid_options['gutterMobile'] = $sm_gutter;
	}
} else {
	$grid_class = 'makeaholic-grid grid-sm-1';
}

$template_part = $style;

if ( $is_grid ) {
	$caption_style = Makeaholic::setting( 'blog_archive_grid_caption_style' );
	$classes[]     = 'makeaholic-blog-caption-style-' . $caption_style;

	$template_part = 'grid-' . $caption_style;
}

if ( have_posts() ) : ?>
	<div class="<?php echo esc_attr( implode( ' ', $classes ) ); ?>"
		<?php if ( $is_grid ) : ?>
			data-grid="<?php echo esc_attr( wp_json_encode( $grid_options ) ); ?>"
		<?php endif; ?>
	>
		<div class="<?php echo esc_attr( $grid_class ); ?>">
			<?php if ( $is_grid ) : ?>
				<div class="grid-sizer"></div>
			<?php endif; ?>

			<?php while ( have_posts() ) : the_post();
				$classes = array( 'grid-item', 'post-item' );
				?>
				<div <?php post_class( implode( ' ', $classes ) ); ?>>
					<?php makeaholic_load_template( 'blog/content-blog', $template_part ); ?>
				</div>
			<?php endwhile; ?>
		</div>

		<div class="makeaholic-grid-pagination">
			<?php Makeaholic_Templates::paging_nav(); ?>
		</div>
	</div>

<?php else : makeaholic_load_template( 'content', 'none' ); ?>
<?php endif; ?>
