<?php
/**
 * Template part for displaying search product content
 *
 * @link    https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Makeaholic
 * @since   1.0
 */

$products_output = '';
$rest_output     = '';

if ( have_posts() ) : ?>
	<?php
	while ( have_posts() ) {
		the_post();

		$post_type = get_post_type();

		ob_start();

		if ( 'product' === $post_type ) {
			makeaholic_load_template( 'content-search-product' );

			$products_output .= ob_get_clean();
		} else {
			makeaholic_load_template( 'content-search-rest' );

			$rest_output .= ob_get_clean();
		}
	}
	?>

	<?php if ( ! empty( $products_output ) ): ?>
		<div class="search-results-section product-search-results">
			<h2 class="search-results-heading"><?php esc_html_e( 'We found some products for you.', 'makeaholic' ); ?></h2>
			<?php
			$classes = [
				'makeaholic-main-post',
				'makeaholic-grid-wrapper',
				'makeaholic-product',
				'group-style-01',
				'style-grid-01',
			];

			$grid_class = 'modern-grid';
			$sm_columns = intval( Makeaholic::setting( 'shop_archive_sm_columns', 2 ) );
			$md_columns = Makeaholic::setting( 'shop_archive_md_columns', 3 );
			$lg_columns = Makeaholic::setting( 'shop_archive_lg_columns', 4 );

			$sm_gutter = intval( Makeaholic::setting( 'shop_archive_sm_gutter', 10 ) );
			$md_gutter = Makeaholic::setting( 'shop_archive_md_gutter', 20 );
			$lg_gutter = Makeaholic::setting( 'shop_archive_lg_gutter', 30 );

			if ( 'none' !== Makeaholic_Global::instance()->get_sidebar_status() ) {
				$lg_columns --;
			}

			$grid_class .= " grid-lg-{$lg_columns}";
			$grid_class .= " grid-md-{$md_columns}";
			$grid_class .= " grid-xs-{$sm_columns}";
			?>
			<div class="<?php echo esc_attr( implode( ' ', $classes ) ); ?>">
				<div class="<?php echo esc_attr( $grid_class ); ?>"
				     style="--grid-gutter-desktop: <?php echo esc_attr( $lg_gutter ); ?>px;--grid-gutter-tablet: <?php echo esc_attr( $md_gutter ); ?>px;--grid-gutter-mobile: <?php echo esc_attr( $sm_gutter ); ?>px;">
					<?php echo '' . $products_output; ?>
				</div>
			</div>
		</div>
	<?php endif; ?>

	<?php if ( ! empty( $rest_output ) ) : ?>
		<div class="search-results-section all-search-results">
			<h2 class="search-results-heading"><?php esc_html_e( 'We found other results for you.', 'makeaholic' ); ?></h2>

			<?php
			$style   = 'grid';
			$classes = [
				'makeaholic-main-post',
				'makeaholic-grid-wrapper',
				'makeaholic-blog',
				'makeaholic-animation-zoom-in',
				"makeaholic-blog-" . $style,
				'makeaholic-blog-overlay-style-float-02',
			];

			$lg_columns = $md_columns = $sm_columns = 1;

			// Handle Columns
			switch ( $style ) {
				case 'grid':
					$lg_columns = 3;
					$md_columns = 2;
					$sm_columns = 1;
					break;
			}

			$grid_options = [
				'type'          => '1' === Makeaholic::setting( 'blog_archive_masonry' ) ? 'masonry' : 'grid',
				'columns'       => $lg_columns,
				'columnsTablet' => $md_columns,
				'columnsMobile' => $sm_columns,
				'gutter'        => 30,
			];

			$caption_style = Makeaholic::setting( 'blog_archive_grid_caption_style' );
			$classes[]     = 'makeaholic-blog-caption-style-' . $caption_style;
			?>
			<div class="<?php echo esc_attr( implode( ' ', $classes ) ); ?>"
			     data-grid="<?php echo esc_attr( wp_json_encode( $grid_options ) ); ?>"
			>
				<div class="makeaholic-grid">
					<?php if ( in_array( $style, array( 'grid', 'grid-02' ) ) ) : ?>
						<div class="grid-sizer"></div>
					<?php endif; ?>

					<?php echo '' . $rest_output; ?>
				</div>
			</div>
		</div>
	<?php endif; ?>

	<div class="makeaholic-grid-pagination">
		<?php Makeaholic_Templates::paging_nav(); ?>
	</div>
<?php else : makeaholic_load_template( 'content', 'none' ); ?>
<?php endif; ?>
