<?php
/**
 * Search form on header
 *
 * @package Makeaholic
 * @since   1.0.0
 * @version 1.0.0
 */

defined( 'ABSPATH' ) || exit;

$header_type     = Makeaholic_Global::instance()->get_header_type();
$content_type    = Makeaholic::setting( 'search_page_filter' );
$with_categories = Makeaholic::setting( "header_style_{$header_type}_search_categories_enable" );

$form_class = 'search-form';

if ( 'product' === $content_type ) {
	$form_class .= ' woocommerce-product-search';
}

if ( '1' === $with_categories ) {
	$form_class .= ' search-form-categories';
}
?>
<div class="header-search-form">
	<form role="search" method="get" class="<?php echo esc_attr( $form_class ); ?>"
	      action="<?php echo esc_url( home_url( '/' ) ); ?>">

		<?php
		if ( '1' === $with_categories ) {
			$args = array(
				'show_option_all' => esc_html__( 'Categories', 'makeaholic' ),
				'hierarchical'    => 1,
				'class'           => 'search-select',
				'echo'            => 1,
				'value_field'     => 'slug',
				'selected'        => 1,
			);

			$search_child_cats = apply_filters( 'makeaholic/header/search_form/child_cats', true );
			if ( ! $search_child_cats ) {
				$args['parent'] = 0;
			}

			$cat_query_var = 'category';

			if ( 'product' === $content_type ) {
				$args['taxonomy'] = 'product_cat';
				$args['name']     = 'product_cat';
				$cat_query_var    = 'product_cat';
			}

			$cat_query = get_query_var( $cat_query_var );
			$cat_query = esc_attr( $cat_query );

			if ( ! empty( $cat_query ) ) {
				$args['selected'] = $cat_query;
			}

			wp_dropdown_categories( $args );
		}
		?>
		<span class="screen-reader-text">
			<?php echo esc_html_x( 'Search for:', 'label', 'makeaholic' ); ?>
		</span>
		<input type="search" class="search-field"
		       placeholder="<?php echo esc_attr_x( 'Search&hellip;', 'placeholder', 'makeaholic' ); ?>"
		       value="<?php echo get_search_query() ?>" name="s"
		       title="<?php echo esc_attr_x( 'Search for:', 'label', 'makeaholic' ); ?>"/>
		<button type="submit" class="search-submit">
			<span class="search-btn-icon ph-magnifying-glass"></span>
			<span class="search-btn-text">
				<?php echo esc_html_x( 'Search', 'submit button', 'makeaholic' ); ?>
			</span>
		</button>
	</form>
</div>
