<?php
/**
 * Template part for display register form on popup.
 *
 * @link      https://codex.wordpress.org/Template_Hierarchy
 *
 * @package   Makeaholic
 * @since     1.0.0
 * @version   1.0.0
 */

defined( 'ABSPATH' ) || exit;
?>
<div class="popup-content-header">
	<div class="popup-title-shape">
		<img src="<?php echo esc_url( MAKEAHOLIC_THEME_IMAGE_URI . '/form-user-leaf.png' ); ?>"
		     alt="<?php esc_attr_e( 'Popup Shape', 'makeaholic' ); ?>"
		     class="shape-leaf"
		>
	</div>
	<h3 class="popup-title"><?php esc_html_e( 'Create Your Account', 'makeaholic' ); ?></h3>
	<p class="popup-description">
		<?php printf( esc_html__( 'Already have an account? %sLog in%s', 'makeaholic' ), '<a href="#" class="open-popup-login link-transition-01">', '</a>' ); ?>
	</p>
</div>

<div class="popup-content-body">
	<form id="makeaholic-register-form" class="makeaholic-register-form" method="post">

		<?php do_action( 'makeaholic/popup_user_register/before_form_fields' ); ?>

		<div class="form-group">
			<label for="ip_reg_fullname" class="form-label">
				<?php esc_html_e( 'Your Name', 'makeaholic' ); ?>
			</label>
			<input type="text" id="ip_reg_fullname" class="form-control form-input"
			       name="fullname" placeholder="<?php esc_attr_e( 'Your Name', 'makeaholic' ); ?>" required>
		</div>

		<div class="form-group">
			<label for="ip_reg_username"
			       class="form-label"><?php esc_html_e( 'Username', 'makeaholic' ); ?></label>
			<input type="text" id="ip_reg_username" class="form-control form-input"
			       name="username" placeholder="<?php esc_attr_e( 'Username', 'makeaholic' ); ?>" required/>
		</div>

		<div class="form-group">
			<label for="ip_reg_email"
			       class="form-label"><?php esc_html_e( 'Email', 'makeaholic' ); ?></label>
			<input type="email" id="ip_reg_email" class="form-control form-input"
			       name="email" placeholder="<?php esc_attr_e( 'Your Email', 'makeaholic' ); ?>" required/>
		</div>

		<div class="form-group">
			<label for="ip_reg_password"
			       class="form-label"><?php esc_html_e( 'Password', 'makeaholic' ); ?></label>
			<div class="form-input-group form-input-password">
				<input type="password" id="ip_reg_password" class="form-control form-input"
				       name="password" placeholder="<?php esc_attr_e( 'Password', 'makeaholic' ); ?>" required>
				<button type="button" class="btn-pw-toggle" data-toggle="0"
				        aria-label="<?php esc_attr_e( 'Show password', 'makeaholic' ); ?>">
				</button>
			</div>
		</div>

		<?php
		$privacy_page_id   = get_option( 'wp_page_for_privacy_policy', 0 );
		$privacy_link_html = esc_html__( 'Privacy Policy', 'makeaholic' );
		if ( $privacy_page_id ) {
			$privacy_link_html = sprintf( '<a href="%1$s" class="makeaholic-privacy-policy-link" target="_blank">%2$s</a>',
				esc_url( get_permalink( $privacy_page_id ) ),
				$privacy_link_html
			);
		}

		$terms_conditions_page_id   = Makeaholic::setting( 'page_for_terms_and_conditions', 0 );
		$terms_conditions_link_html = esc_html__( 'Terms', 'makeaholic' );
		if ( $terms_conditions_page_id ) {
			$terms_conditions_link_html = sprintf( '<a href="%1$s" class="makeaholic-terms-conditions-link" target="_blank">%2$s</a>',
				esc_url( get_permalink( $terms_conditions_page_id ) ),
				$terms_conditions_link_html
			);
		}
		?>
		<div class="form-group accept-account">
			<label class="form-label form-label-checkbox" for="ip_accept_account">
				<input type="checkbox" id="ip_accept_account" class="form-control"
				       name="accept_account" value="1">
				<?php printf( esc_html__( 'Accept the %1$s and %2$s', 'makeaholic' ), $terms_conditions_link_html, $privacy_link_html ); ?>
			</label>
		</div>

		<?php do_action( 'makeaholic/popup_user_register/after_form_fields' ); ?>

		<div class="form-response-messages"></div>

		<div class="form-group form-submit-wrap">
			<?php wp_nonce_field( 'user_register', 'user_register_nonce' ); ?>
			<input type="hidden" name="action" value="makeaholic_user_register">
			<button type="submit" class="button form-submit"><?php esc_html_e( 'Register', 'makeaholic' ); ?></button>
		</div>
	</form>
</div>
