<?php
defined( 'ABSPATH' ) || exit;

if ( ! class_exists( 'Makeaholic_WP_Widget_Linked_Products' ) ) {
	class Makeaholic_WP_Widget_Linked_Products extends Makeaholic_Widget {

		public function __construct() {
			$this->widget_id          = 'makeaholic-wp-widget-linked-products';
			$this->widget_cssclass    = 'makeaholic-wp-widget-linked-products';
			$this->widget_name        = esc_html__( '[Makeaholic] Linked Products', 'makeaholic' );
			$this->widget_description = esc_html__( 'Display linked products of current product. Used on single product page.', 'makeaholic' );
			$this->settings           = array(
				'title'  => array(
					'type'  => 'text',
					'std'   => esc_html__( 'Products', 'makeaholic' ),
					'label' => esc_html__( 'Title', 'makeaholic' ),
				),
				'number' => array(
					'type'  => 'number',
					'step'  => 1,
					'min'   => 1,
					'max'   => '',
					'std'   => 5,
					'label' => esc_html__( 'Number of products to show', 'makeaholic' ),
				),
				'source' => array(
					'type'    => 'select',
					'std'     => '',
					'label'   => esc_html__( 'Show', 'makeaholic' ),
					'options' => [
						'upsells' => esc_html__( 'Upsells Products', 'makeaholic' ),
						//'cross-sells' => esc_html__( 'Cross Sells Products', 'makeaholic' ),
						'related' => esc_html__( 'Related Products', 'makeaholic' ),
					],
				),
			);

			parent::__construct();
		}

		/**
		 * Output widget.
		 *
		 * @param array $args     Arguments.
		 * @param array $instance Widget instance.
		 *
		 * @see WP_Widget
		 */
		public function widget( $args, $instance ) {
			if ( ! is_product() ) {
				return;
			}

			global $product;

			if ( ! $product ) {
				return;
			}

			$products = $this->get_products( $args, $instance );

			if ( empty( $products ) ) {
				return;
			}

			$this->widget_start( $args, $instance );

			echo wp_kses_post( apply_filters( 'woocommerce_before_widget_product_list', '<ul class="product_list_widget">' ) );

			$template_args = array(
				'widget_id'   => isset( $args['widget_id'] ) ? $args['widget_id'] : $this->widget_id,
				'show_rating' => true,
			);

			foreach ( $products as $product ) {
				$post_object = get_post( $product->get_id() );
				setup_postdata( $GLOBALS['post'] = $post_object );

				wc_get_template( 'content-widget-product.php', $template_args );
			}
			wp_reset_postdata();

			echo wp_kses_post( apply_filters( 'woocommerce_after_widget_product_list', '</ul>' ) );

			$this->widget_end( $args );
		}

		public function get_products( $args, $instance ) {
			global $product;

			$source  = $this->get_value( $instance, 'source' );
			$limit   = $this->get_value( $instance, 'number' );
			$orderby = 'rand';
			$order   = 'desc';

			switch ( $source ) {
				case 'upsells':
					// Handle the legacy filter which controlled posts per page etc.


					// Get visible upsells then sort them at random, then limit result set.
					$upsells = wc_products_array_orderby( array_filter( array_map( 'wc_get_product', $product->get_upsell_ids() ), 'wc_products_array_filter_visible' ), $orderby, $order );
					$upsells = $limit > 0 ? array_slice( $upsells, 0, $limit ) : $upsells;

					return $upsells;
					break;

				case 'related':
					$related_products = array_filter( array_map( 'wc_get_product', wc_get_related_products( $product->get_id(), $limit, $product->get_upsell_ids() ) ), 'wc_products_array_filter_visible' );

					// Handle orderby.
					$related_products = wc_products_array_orderby( $related_products, $orderby, $order );

					return $related_products;
					break;
			}

			return false;
		}
	}
}
