<?php
/**
 * Mini-cart
 *
 * Contains the markup for the mini-cart, used by the cart widget.
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/cart/mini-cart.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 9.4.0
 */

defined( 'ABSPATH' ) || exit;

do_action( 'woocommerce_before_mini_cart' ); ?>

<?php if ( WC()->cart && ! WC()->cart->is_empty() ) : ?>
	<ul class="woocommerce-mini-cart cart_list product_list_widget <?php echo esc_attr( $args['list_class'] ); ?>">
		<?php
		do_action( 'woocommerce_before_mini_cart_contents' );

		foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ) {
			$_product   = apply_filters( 'woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key );
			$product_id = apply_filters( 'woocommerce_cart_item_product_id', $cart_item['product_id'], $cart_item, $cart_item_key );

			if ( $_product && $_product->exists() && $cart_item['quantity'] > 0 && apply_filters( 'woocommerce_widget_cart_item_visible', true, $cart_item, $cart_item_key ) ) {
				/**
				 * This filter is documented in woocommerce/templates/cart/cart.php.
				 *
				 * @since 2.1.0
				 */
				$product_name      = apply_filters( 'woocommerce_cart_item_name', $_product->get_name(), $cart_item, $cart_item_key );
				$thumbnail         = apply_filters( 'woocommerce_cart_item_thumbnail', $_product->get_image( 'thumbnail' ), $cart_item, $cart_item_key );
				$product_price     = apply_filters( 'woocommerce_cart_item_price', WC()->cart->get_product_price( $_product ), $cart_item, $cart_item_key );
				$product_permalink = apply_filters( 'woocommerce_cart_item_permalink', $_product->is_visible() ? $_product->get_permalink( $cart_item ) : '', $cart_item, $cart_item_key );
				?>
				<li class="woocommerce-mini-cart-item <?php echo esc_attr( apply_filters( 'woocommerce_mini_cart_item_class', 'mini_cart_item', $cart_item, $cart_item_key ) ); ?>">
					<?php
					echo apply_filters( // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
						'woocommerce_cart_item_remove_link',
						sprintf(
							'<a href="%s" class="remove remove_from_cart_button" aria-label="%s" data-product_id="%s" data-cart_item_key="%s" data-product_sku="%s" data-success_message="%s"><i class="ph-x"></i></a>',
							esc_url( wc_get_cart_remove_url( $cart_item_key ) ),
							esc_attr__( 'Remove this item', 'makeaholic' ),
							esc_attr( $product_id ),
							esc_attr( $cart_item_key ),
							esc_attr( $_product->get_sku() ),
							/* translators: %s is the product name */
							esc_attr( sprintf( __( '&ldquo;%s&rdquo; has been removed from your cart', 'makeaholic' ), wp_strip_all_tags( $product_name ) ) )
						),
						$cart_item_key
					);
					?>

					<div class="product-thumbnail">
						<?php if ( empty( $product_permalink ) ) : ?>
							<?php Makeaholic_Helper::e( $thumbnail ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>
						<?php else : ?>
							<a href="<?php echo esc_url( $product_permalink ); ?>">
								<?php Makeaholic_Helper::e( $thumbnail ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>
							</a>
						<?php endif; ?>
					</div>

					<div class="product-info">
						<div class="product-main-info">
							<h3 class="product-name">
								<?php if ( empty( $product_permalink ) ) : ?>
									<?php Makeaholic_Helper::e( $product_name ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>
								<?php else : ?>
									<a href="<?php echo esc_url( $product_permalink ); ?>">
										<?php Makeaholic_Helper::e( $product_name ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>
									</a>
								<?php endif; ?>
							</h3>
							<?php echo wc_get_formatted_cart_item_data( $cart_item ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>

							<?php
							if ( $_product->is_sold_individually() ) {
								$product_quantity = sprintf( '1 <input type="hidden" name="cart[%s][qty]" value="1" />', $cart_item_key );
							} else {
								$product_quantity = woocommerce_quantity_input(
									array(
										'input_name'   => $cart_item_key,
										'input_value'  => $cart_item['quantity'],
										'max_value'    => $_product->get_max_purchase_quantity(),
										'min_value'    => '0',
										'product_name' => $product_name,
									),
									$_product,
									false
								);
							}

							echo apply_filters( 'woocommerce_cart_item_quantity', $product_quantity, $cart_item_key, $cart_item ); // PHPCS: XSS ok.
							?>
						</div>
						<div class="product-price">
							<?php
							echo apply_filters( 'woocommerce_cart_item_price', WC()->cart->get_product_price( $_product ), $cart_item, $cart_item_key );
							?>
						</div>
					</div>
				</li>
				<?php
			}
		}

		do_action( 'woocommerce_mini_cart_contents' );
		?>
	</ul>

	<div class="cart-footer">
		<?php if ( wc_coupons_enabled() ) { ?>
			<form class="form-fly-cart-coupon" method="POST" action="">
				<label for="fly-cart-coupon_code"><?php esc_html_e( 'Coupon:', 'makeaholic' ); ?></label>
				<input type="text" name="coupon_code" class="input-text" id="fly-cart-coupon_code" value=""
				       placeholder="<?php esc_attr_e( 'Coupon code', 'makeaholic' ); ?>"/>
				<button type="submit" class="button makeaholic-coupon-check" name="apply_coupon"
				        value="<?php esc_attr_e( 'Apply', 'makeaholic' ); ?>"><?php esc_html_e( 'Apply', 'makeaholic' ); ?></button>
			</form>
		<?php } ?>

		<div class="fly-cart-totals fly-cart-subtotal">
			<div class="fly-cart-totals-label"><?php esc_html_e( 'Subtotal:', 'makeaholic' ); ?></div>
			<div class="fly-cart-totals-value"><?php wc_cart_totals_subtotal_html(); ?></div>
		</div>

		<?php
		$coupons = WC()->cart->get_coupons();
		?>
		<?php if ( ! empty( $coupons ) ) : ?>
			<div class="fly-cart-coupons">
				<?php foreach ( $coupons as $code => $coupon ) : ?>
					<div
						class="fly-cart-totals fly-cart-coupon cart-discount coupon-<?php echo esc_attr( sanitize_title( $code ) ); ?>">
						<div class="fly-cart-totals-label">
							<?php wc_cart_totals_coupon_label( $coupon ); ?>
						</div>
						<div class="fly-cart-totals-value">
							<?php Makeaholic_Woo::instance()->cart_totals_coupon_html( $coupon ); ?>
						</div>
					</div>
				<?php endforeach; ?>
			</div>
		<?php endif; ?>

		<div class="fly-cart-totals fly-cart-total">
			<?php WC()->cart->calculate_totals(); ?>
			<div class="fly-cart-totals-label"><?php esc_html_e( 'Total:', 'makeaholic' ); ?></div>
			<div class="fly-cart-totals-value"><?php wc_cart_totals_order_total_html(); ?></div>
		</div>

		<?php do_action( 'woocommerce_widget_shopping_cart_before_buttons' ); ?>

		<div class="woocommerce-mini-cart__buttons buttons">
			<?php do_action( 'woocommerce_widget_shopping_cart_buttons' ); ?>
		</div>
	</div>

<?php else : ?>

	<div class="woocommerce-mini-cart__empty-message">
		<div class="empty-basket">
			<span class="fal fa-dolly-flatbed-empty"></span>
		</div>

		<p class="empty-message"><?php esc_html_e( 'Your cart is empty', 'makeaholic' ); ?></p>

		<?php
		if ( wc_get_page_id( 'shop' ) > 0 ) : ?>
			<p class="return-to-shop">
				<a class="button wc-backward"
				   href="<?php echo esc_url( apply_filters( 'woocommerce_return_to_shop_redirect', wc_get_page_permalink( 'shop' ) ) ); ?>">
					<?php esc_html_e( 'Browse Shop', 'makeaholic' ); ?>
				</a>
			</p>
		<?php endif; ?>
	</div>

<?php endif; ?>

<?php do_action( 'woocommerce_after_mini_cart' ); ?>
