<?php
/**
 * The template for displaying product category thumbnails within loops
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/content-product_cat.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 4.7.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

$archive_categories_style = Makeaholic::setting( 'shop_archive_categories_style' );

if ( $archive_categories_style === 'carousel' ) {
	$column = 'swiper-slide';
} else {
	$column = 'col-md-3 col-sm-6 col-xs-6 product-cat-item';
}

$link         = get_term_link( $category, 'product_cat' );
$thumbnail_id = get_term_meta( $category->term_id, 'thumbnail_id', true );

if ( $thumbnail_id ) {
	$image = \Makeaholic_Image::get_attachment_by_id( [
		'id'   => $thumbnail_id,
		'size' => '270x450',
	] );
} else {
	$image = '<img src="' . wc_placeholder_img_src() . '" alt="' . $category->name . '" />';
}
?>
<div <?php wc_product_cat_class( $column, $category ); ?>>
	<a href="<?php echo esc_url( $link ); ?>" <?php wc_product_cat_class( 'cat-wrap makeaholic-box link-secret', $category ); ?>>
		<div class="makeaholic-image image">
			<?php echo '' . $image; ?>
		</div>
		<div class="category-info">
			<h5 class="category-name"><span><?php echo esc_html( $category->name ); ?></span></h5>

			<p class="category-count">
				<?php if ( $category->count > 0 ) {
					echo apply_filters( 'woocommerce_subcategory_count_html', ' ' . sprintf( _n( '%s item', '%s items', $category->count, 'makeaholic' ), $category->count ), $category );
				} ?>
			</p>

			<?php
			/**
			 * woocommerce_after_subcategory_title hook
			 */
			do_action( 'woocommerce_after_subcategory_title', $category );
			?>
		</div>
	</a>
</div>
