<?php
/**
 * The template for displaying product content in the single-product.php template
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/content-single-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates
 * @version 3.6.0
 */

defined( 'ABSPATH' ) || exit;

if ( '1' !== Makeaholic::setting( 'single_product_sticky_bar_enable' ) ) {
	return;
}

global $product;

if ( ! $product->is_purchasable() ) {
	return;
}
?>
<div id="sticky-product-bar" <?php wc_product_class( 'sticky-product cart-notification', $product ); ?>
     data-notification="<?php echo esc_attr( Makeaholic_Woo::instance()->get_product_notification_settings( $product ) ); ?>">
	<div class="sticky-product-bar-close">
		<span class="ph-x"></span>
	</div>
	<div class="container">
		<div class="row row-xs-center">
			<div class="col-md-6">
				<div class="sticky-product-info">
					<div class="sticky-product-thumbnail">
						<?php echo Makeaholic_Woo::instance()->get_product_image( $product, '70x90' ); ?>
					</div>
					<div class="sticky-product-summary">
						<h3 class="sticky-product-name post-title-1-row"><span><?php the_title(); ?></span></h3>
						<?php if ( $product->get_average_rating() ) : ?>
							<?php echo wc_get_rating_html( $product->get_average_rating() ); ?>
						<?php endif; ?>
					</div>
				</div>
			</div>

			<div class="col-md-6">
				<?php if ( $product->is_type( 'variable' ) ): ?>
					<div class="cart woocommerce-add-to-cart sticky-cart-form">
						<?php
						Makeaholic_Templates::render_button( [
							'text'        => esc_html__( 'Add to Cart', 'makeaholic' ),
							'link'        => [
								'url' => '#variation_form_anchor',
							],
							'extra_class' => 'sticky-product-add_to_cart_button smooth-scroll-link',
						] );
						?>
					</div>
				<?php else : ?>
					<form class="cart woocommerce-add-to-cart sticky-cart-form"
					      action="<?php echo esc_url( apply_filters( 'woocommerce_add_to_cart_form_action', $product->get_permalink() ) ); ?>"
					      method="post"
					      enctype="multipart/form-data">
						<?php if ( $product->is_in_stock() ) : ?>
							<div class="sticky-cart-form-quantity-wrap">
								<div class="product-qty-wrapper">
									<?php
									woocommerce_quantity_input(
										array(
											'min_value'   => apply_filters( 'woocommerce_quantity_input_min', $product->get_min_purchase_quantity(), $product ),
											'max_value'   => apply_filters( 'woocommerce_quantity_input_max', $product->get_max_purchase_quantity(), $product ),
											'input_value' => isset( $_POST['quantity'] ) ? wc_stock_amount( wp_unslash( $_POST['quantity'] ) ) : $product->get_min_purchase_quantity(),
											// WPCS: CSRF ok, input var ok.
										)
									);
									?>
								</div>

								<div class="sticky-product-price">
									<?php echo '' . $product->get_price_html(); ?>
								</div>
							</div>

							<input type="hidden" name="product_id" value="<?php echo absint( $product->get_id() ); ?>"/>
							<input type="hidden" name="variation_id" class="variation_id" value="0"/>

							<button type="submit" name="add-to-cart"
							        value="<?php echo esc_attr( $product->get_id() ); ?>"
							        class="sticky-product-add_to_cart_button single_add_to_cart_button ajax_add_to_cart button alt"><?php echo esc_html( $product->single_add_to_cart_text() ); ?></button>
						<?php endif; ?>
					</form>
				<?php endif; ?>
			</div>
		</div>
	</div>
</div>
