<?php
/**
 * Single Product Image
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/single-product/product-image.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 9.7.0
 */

defined( 'ABSPATH' ) || exit;

global $post, $product;

$attachment_ids = $product->get_gallery_image_ids();

if ( has_post_thumbnail() ) {
	$thumbnail_id = (int) get_post_thumbnail_id();
	array_unshift( $attachment_ids, $thumbnail_id );
}

if ( empty( $attachment_ids ) ) {
	echo apply_filters( 'woocommerce_single_product_image_html', sprintf( '<img src="%s" alt="%s" />', wc_placeholder_img_src(), esc_attr__( 'Placeholder', 'makeaholic' ) ), $post->ID );

	return;
}

$is_quick_view = apply_filters( 'makeaholic/quick_view/is_showing', false );

$wrapper_classes = 'woo-single-gallery';

$feature_style = Makeaholic_Woo::instance()->get_single_product_image_style();

if ( true === $is_quick_view ) {
	$feature_style = 'slider';
}

$thumbnail_size = '104x134';
$site_layout    = Makeaholic_Woo::instance()->get_single_product_site_layout();

switch ( $feature_style ) {
	case 'grid':
		$main_image_size = apply_filters( 'makeaholic/single_product/feature_grid/image_size', '450x608' );
		break;
	case 'list':
		$main_image_size = apply_filters( 'makeaholic/single_product/feature_list/image_size', '845x9999' );
		break;
	default: // Slider
		$image_size = '570x770';

		if ( 'wide' === $site_layout ) {
			$image_size     = '690x930';
			$thumbnail_size = '128x165';
		}

		$main_image_size = apply_filters( 'makeaholic/single_product/feature_slider/image_size', $image_size );

		if ( $is_quick_view ) {
			$main_image_size = apply_filters( 'makeaholic/product/quick_view/feature_slider/image_size', '470x540' );
		}
		break;
}

$thumb_image_size = apply_filters( 'makeaholic/single_product/feature_slider/thumbnail_size', $thumbnail_size );

$classes = "feature-style-$feature_style";

$open_gallery = apply_filters( 'makeaholic/single_product/open_gallery', true );
if ( $open_gallery ) {
	$classes .= ' makeaholic-light-gallery';
}
?>
<div class="<?php echo esc_attr( $classes ); ?>">
	<?php if ( 'slider' === $feature_style ) : ?>
		<?php
		$main_slider_slides_html   = '';
		$thumbs_slider_slides_html = '';

		$number_attachments = count( $attachment_ids );
		if ( $number_attachments > 1 ) {
			$wrapper_classes .= ' has-thumbs-slider';
		}
		?>
		<div class="<?php echo esc_attr( $wrapper_classes ); ?>">
			<?php
			foreach ( $attachment_ids as $attachment_id ) {
				$props = wc_get_product_attachment_props( $attachment_id, $post );

				if ( ! $props['url'] ) {
					continue;
				}

				$main_slider_slide_image_classes = array( 'zoom swiper-slide' );

				if ( isset( $thumbnail_id ) && $attachment_id == $thumbnail_id ) {
					$main_slider_slide_image_classes[] = 'product-main-image';
				}

				$attributes_string = 'class="' . esc_attr( implode( ' ', $main_slider_slide_image_classes ) ) . '"';

				if ( $open_gallery ) {
					$sub_html = '';

					if ( ! empty( $props['title'] ) ) {
						$sub_html .= "<h4>{$props['title']}</h4>";
					}

					if ( ! empty( $props['caption'] ) ) {
						$sub_html .= "<p>{$props['caption']}</p>";
					}

					if ( ! empty( $sub_html ) ) {
						$attributes_string .= ' data-sub-html="' . $sub_html . '"';
					}

					$attributes_string .= ' data-src="' . $props['url'] . '"';
				}

				$attributes_string .= ' data-image-id="' . $attachment_id . '"';

				$main_image_html         = Makeaholic_Image::get_attachment_by_id( array(
					'id'   => $attachment_id,
					'size' => $main_image_size,
				) );
				$main_slider_slides_html .= sprintf( '<div %s>%s</div>', $attributes_string, $main_image_html );

				$thumbs_image_html         = Makeaholic_Image::get_attachment_by_id( [
					'id'   => $attachment_id,
					'size' => $thumb_image_size,
				] );
				$thumbs_slider_slides_html .= '<div class="swiper-slide">' . $thumbs_image_html . '</div>';
			}
			?>
			<div class="tm-swiper makeaholic-main-swiper"
			     data-items-desktop="1"
			     data-gutter-desktop="30"
			     data-speed="1000"
			     data-effect="slide"
			     data-auto-height="1"
			>
				<div class="swiper-inner">
					<div class="swiper">
						<div class="swiper-wrapper">
							<?php echo '' . $main_slider_slides_html; ?>
						</div>
					</div>
				</div>
			</div>

			<?php if ( $number_attachments > 1 ) { ?>
				<div class="tm-swiper makeaholic-thumbs-swiper"
				     data-items-desktop="5"
				     data-gutter-desktop="10"
				     data-speed="1000"
				     data-effect="slide"
				     data-slide-to-clicked-slide="1"
				     data-freemode="1"
				>
					<div class="swiper-inner">
						<div class="swiper">
							<div class="swiper-wrapper">
								<?php echo '' . $thumbs_slider_slides_html; ?>
							</div>
						</div>
					</div>
				</div>
			<?php } ?>
		</div>
	<?php elseif ( 'grid' === $feature_style ) : ?>
		<?php
		$wrapper_classes .= ' makeaholic-main-post makeaholic-grid-wrapper';

		$grid_options = [
			'type'    => 'grid',
			'columns' => 2,
			'gutter'  => 30,
		];
		?>
		<div class="<?php echo esc_attr( $wrapper_classes ); ?>"
		     data-grid="<?php echo esc_attr( wp_json_encode( $grid_options ) ); ?>">
			<div class="makeaholic-grid grid-sm-2">
				<div class="grid-sizer"></div>

				<?php foreach ( $attachment_ids as $attachment_id ) : ?>
					<?php
					$props = wc_get_product_attachment_props( $attachment_id, $post );

					if ( ! $props['url'] ) {
						continue;
					}

					$grid_item_classes = array( 'grid-item' );

					if ( isset( $thumbnail_id ) && $attachment_id == $thumbnail_id ) {
						$grid_item_classes[] = 'product-main-image';
					}

					$attributes_string = 'class="' . esc_attr( implode( ' ', $grid_item_classes ) ) . '"';

					if ( $open_gallery ) {
						$sub_html = '';

						if ( ! empty( $props['title'] ) ) {
							$sub_html .= "<h4>{$props['title']}</h4>";
						}

						if ( ! empty( $props['caption'] ) ) {
							$sub_html .= "<p>{$props['caption']}</p>";
						}

						if ( ! empty( $sub_html ) ) {
							$attributes_string .= ' data-sub-html="' . $sub_html . '"';
						}

						$attributes_string .= ' data-src="' . $props['url'] . '"';
					}

					$attributes_string .= ' data-image-id="' . $attachment_id . '"';

					$main_image_html = Makeaholic_Image::get_attachment_by_id( array(
						'id'   => $attachment_id,
						'size' => $main_image_size,
					) );
					echo sprintf( '<div %s>%s</div>', $attributes_string, $main_image_html );
					?>
				<?php endforeach; ?>
			</div>
		</div>
	<?php else : ?>
		<?php foreach ( $attachment_ids as $attachment_id ) : ?>
			<?php
			$props = wc_get_product_attachment_props( $attachment_id, $post );

			if ( ! $props['url'] ) {
				continue;
			}

			$classes     = array( 'zoom' );
			$image_class = implode( ' ', $classes );

			$sub_html = '';

			if ( $props['title'] !== '' ) {
				$sub_html .= "<h4>{$props['title']}</h4>";
			}

			if ( $props['caption'] !== '' ) {
				$sub_html .= "<p>{$props['caption']}</p>";
			}

			$image = Makeaholic_Image::get_attachment_by_id( array(
				'id'   => $attachment_id,
				'size' => $main_image_size,
			) );

			$_link = $props['url'];

			if ( $open_gallery === false ) {
				$_link = get_the_permalink();
			}

			echo sprintf( '<a href="%s" class="%s" data-sub-html="%s">%s</a>', esc_url( $_link ), esc_attr( $image_class ), $sub_html, $image );
			?>
		<?php endforeach; ?>
	<?php endif; ?>
</div>
